# CHANGELOG

<!-- version list -->

## v6.2.0 (2026-03-26)

### Bug Fixes

- **docs**: Update error handling example for async usage
  ([#68](https://github.com/MountainGod2/cb-events/pull/68),
  [`adb2241`](https://github.com/MountainGod2/cb-events/commit/adb2241a88cf11076f85477f307bf6e82c5e43fa))

### Chores

- **examples-scripts**: Update dependency cb-events to v6.1.4
  ([`4b5ba54`](https://github.com/MountainGod2/cb-events/commit/4b5ba5468b4ae18b382270c01ff584913d345be7))

- **lock-file**: Lock file maintenance
  ([`cd99c2f`](https://github.com/MountainGod2/cb-events/commit/cd99c2f02d1c476f4138a0d1c19ffe460e1137c8))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.86.0
  ([`a95cde3`](https://github.com/MountainGod2/cb-events/commit/a95cde350ce9192110b026af97d967ee8af5242d))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.86.1
  ([`4814b48`](https://github.com/MountainGod2/cb-events/commit/4814b48c8866f413e1f099491e84f443911fe99f))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.86.2
  ([`c464c13`](https://github.com/MountainGod2/cb-events/commit/c464c1370f5b8790892cc69fd18dab6a6c3adef4))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.87.1
  ([`cd45896`](https://github.com/MountainGod2/cb-events/commit/cd4589683ab2f2e9471d25514730e1a62930a460))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.89.3
  ([`e399b70`](https://github.com/MountainGod2/cb-events/commit/e399b704dce2cdf74f3df7784d43156938a28b03))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.89.4
  ([`10b9e02`](https://github.com/MountainGod2/cb-events/commit/10b9e02b15fe1bddd40132ccb4d5b2c8db1ea6c1))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.91.4
  ([#68](https://github.com/MountainGod2/cb-events/pull/68),
  [`adb2241`](https://github.com/MountainGod2/cb-events/commit/adb2241a88cf11076f85477f307bf6e82c5e43fa))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.91.4
  ([`3b282bf`](https://github.com/MountainGod2/cb-events/commit/3b282bf1aead8c52603027c4ba45e9500a808c29))

- **python-dev-tools**: Update dependency ty to v0.0.25
  ([`1581c79`](https://github.com/MountainGod2/cb-events/commit/1581c7903c5913385435ba64fade051b4c5157ad))

### Continuous Integration

- Update job names and permissions ([#66](https://github.com/MountainGod2/cb-events/pull/66),
  [`0b1a77b`](https://github.com/MountainGod2/cb-events/commit/0b1a77b9988cf7ad7c461e314f107ce81f1043f3))

### Features

- **docs**: Add additional doc pages for config and installation
  ([#68](https://github.com/MountainGod2/cb-events/pull/68),
  [`adb2241`](https://github.com/MountainGod2/cb-events/commit/adb2241a88cf11076f85477f307bf6e82c5e43fa))


## v6.1.4 (2026-03-22)

### Bug Fixes

- **ci**: Add GPG signing to publish steps in CI/CD
  ([#64](https://github.com/MountainGod2/cb-events/pull/64),
  [`056ec1c`](https://github.com/MountainGod2/cb-events/commit/056ec1c53975bf863f15e69d1060cf8acacff1d6))

### Chores

- **examples-scripts**: Update dependency cb-events to v6.1.3
  ([`7ffc6f9`](https://github.com/MountainGod2/cb-events/commit/7ffc6f94ab75aef8ca7a2fc63112630c10b9e8dc))

- **python-dev-tools**: Update dependency pytest-cov to v7.1.0
  ([`a4e16bd`](https://github.com/MountainGod2/cb-events/commit/a4e16bdf437e4287e941b2c259d56dcb9e3f3e5f))


## v6.1.3 (2026-03-21)

### Bug Fixes

- **ci**: Update GitHub Actions to use GH_PAT for token
  ([#63](https://github.com/MountainGod2/cb-events/pull/63),
  [`599dece`](https://github.com/MountainGod2/cb-events/commit/599dece4b24d58f5c56aa75b5b6ffa9cfb9df4c2))

- **client**: Improve error handling and logging in EventClient
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

### Chores

- **ci-github-actions**: Update github/codeql-action digest to 3869755
  ([`5ed5a5d`](https://github.com/MountainGod2/cb-events/commit/5ed5a5d29d0193c8c6579595df1eb0270cd1f8a1))

- **docker-images**: Update docker-images
  ([`c5a7939`](https://github.com/MountainGod2/cb-events/commit/c5a7939c7910292e496c9e935d95251ceb4b8e49))

- **examples-scripts**: Update dependency cb-events to v6.1.2
  ([`4ddb17e`](https://github.com/MountainGod2/cb-events/commit/4ddb17edbd339482716c890fdb9b11cb3ce49eff))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.84.2
  ([`466611a`](https://github.com/MountainGod2/cb-events/commit/466611afa8502cbd8de9a96e7db11b38373433f1))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.9.9
  ([`3d11a54`](https://github.com/MountainGod2/cb-events/commit/3d11a54b0dd17810b9ae08e69a442d181b9ff3fe))

### Continuous Integration

- Add environment variable for Node.js actions
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- Update Trivy action version in workflow ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

### Documentation

- Refactor documentation and configuration
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- **client**: Update module docstring and add parameter descriptions
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- **index**: Improve event types and properties formatting
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

### Refactoring

- **config**: Remove redundant attribute documentation
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- **docs**: Simplify docs dependency list ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- **docs**: Update Sphinx configuration settings
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- **exceptions**: Remove redundant attribute documentation
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- **models**: Improve BaseEventModel documentation
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))

- **models**: Remove redundant attribute documentation
  ([#62](https://github.com/MountainGod2/cb-events/pull/62),
  [`79f9248`](https://github.com/MountainGod2/cb-events/commit/79f92487298eb6a57c531fd7fef8bc7049580066))


## v6.1.2 (2026-03-20)

### Bug Fixes

- **semantic-release**: Update commit author for GitHub Actions
  ([`6a93c8a`](https://github.com/MountainGod2/cb-events/commit/6a93c8addc781cb461232b643d221ed6f014b6d1))


## v6.1.1 (2026-03-20)

### Bug Fixes

- **semantic-release**: Add commit author for GitHub Actions
  ([`717c94c`](https://github.com/MountainGod2/cb-events/commit/717c94c5cb5738ea3bdf314ad431757dad420fa6))

### Chores

- **ci-github-actions**: Update github/codeql-action digest to c6f9311
  ([`9414195`](https://github.com/MountainGod2/cb-events/commit/9414195fa0f880ca3ee5c43fd8ea721a15c14895))

- **examples-scripts**: Update dependency cb-events to v6.1.0
  ([`f2f24a7`](https://github.com/MountainGod2/cb-events/commit/f2f24a7caf7a5488e834d16265daf8cd37e9571a))

- **pre-commit**: Update pre-commit hook gitleaks/gitleaks to v8.30.1
  ([`5084ea0`](https://github.com/MountainGod2/cb-events/commit/5084ea0bf6a55772dd3ee5eaab1938e3bbbf9f01))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.83.1
  ([`bb4371e`](https://github.com/MountainGod2/cb-events/commit/bb4371e84af6e5044106bfada8bb35c8a76e8a22))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.84.0
  ([`30a7fe2`](https://github.com/MountainGod2/cb-events/commit/30a7fe2ca3b1ecd3d4cc35953142547ecd53b1e5))


## v6.1.0 (2026-03-20)

### Chores

- **ci-github-actions**: Update ci-github-actions
  ([`1add124`](https://github.com/MountainGod2/cb-events/commit/1add1244a2df8453d6cc6fe5a79ca7f5852faed1))

- **ci-github-actions**: Update codecov/codecov-action digest to 1af5884
  ([`9650ba6`](https://github.com/MountainGod2/cb-events/commit/9650ba6c66617b564f5f45ea4fd9eb040bf60ce1))

- **deps**: Lock file maintenance
  ([`b09701d`](https://github.com/MountainGod2/cb-events/commit/b09701de3e92d4f4087aa40256e01cacde9a73ef))

- **deps**: Update dependency cb-events to v6
  ([#60](https://github.com/MountainGod2/cb-events/pull/60),
  [`6b4de7f`](https://github.com/MountainGod2/cb-events/commit/6b4de7f834f3aac24fa85f58f6b52e6df005d91d))

- **docs**: Add note about token permission
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **LICENSE**: Update copyright year
  ([`b948dce`](https://github.com/MountainGod2/cb-events/commit/b948dcec0e49e43ed2950c99d94cebaca05e9133))

- **pre-commit**: Update pre-commit
  ([`8f28138`](https://github.com/MountainGod2/cb-events/commit/8f28138d4d607feed20a16495a6ca6b300a1c64b))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.76.2
  ([`d90a7f2`](https://github.com/MountainGod2/cb-events/commit/d90a7f22d5e368677347a2dbf44367834d1aafa6))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.76.3
  ([`776b0dc`](https://github.com/MountainGod2/cb-events/commit/776b0dc44df436958083e18662ed2b8a6dc5f023))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.77.7
  ([`899a199`](https://github.com/MountainGod2/cb-events/commit/899a1994a52046e42cb9d486b5972150b2c4d441))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.77.8
  ([`25e637c`](https://github.com/MountainGod2/cb-events/commit/25e637c2c76e9af1214e03d5704101dfb35020e9))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.78.0
  ([`717e349`](https://github.com/MountainGod2/cb-events/commit/717e349ebe2e759af3a76b26769b4f75906ec7f2))

- **python-dev-tools**: Update dependency pyrefly to v0.57.0
  ([`e56e31d`](https://github.com/MountainGod2/cb-events/commit/e56e31d08b0e0719f4cbc92edcbfe2f49d446e56))

- **python-dev-tools**: Update dependency pyrefly to v0.57.1
  ([`dc4c4f1`](https://github.com/MountainGod2/cb-events/commit/dc4c4f177c189d14e3b02a5c95ae9b9caa0c1a03))

- **python-dev-tools**: Update python-dev-tools
  ([`6990b3b`](https://github.com/MountainGod2/cb-events/commit/6990b3bd7dadc0d2b4ae6ba26048d173a39896af))

- **renovate**: Update configuration for dependency management
  ([#57](https://github.com/MountainGod2/cb-events/pull/57),
  [`4754915`](https://github.com/MountainGod2/cb-events/commit/47549156098afaafe498c3042cb231424a951d85))

### Documentation

- **models**: Add warning about untrusted user input in event data
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

- **README**: Update badges and notes formatting
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **README**: Update note on generating API token
  ([`4c2400f`](https://github.com/MountainGod2/cb-events/commit/4c2400fa3b026bdc371eed63d5e2400dd120ace6))

- **README**: Update token generation instructions
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

- **tests**: Clarify masking behavior in _mask_url docstring
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

### Features

- **pre-commit**: Add gitleaks secret scan hook
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

- **pre-commit**: Add redact argument to gitleaks hook
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

### Refactoring

- Update type annotations and immutabilty ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **client**: Change AUTH_ERRORS and RETRY_STATUS_CODES to frozenset
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **client**: Fully mask api token in logs
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

- **client**: Update docstrings for error handling and token masking
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **client, exceptions, tests**: Mask tokens fully in logs and repr
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

- **config**: Change model_config to use ConfigDict
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **models**: Simplify imports and type annotations
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **pytest**: Rename pytest section to ini_options
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **renovate**: Reorganize package rules ([#58](https://github.com/MountainGod2/cb-events/pull/58),
  [`e51d770`](https://github.com/MountainGod2/cb-events/commit/e51d770dc05a6253013eccce7970dff9fb17dfdf))

- **renovate**: Reorganize package rules and restore breaking update handling
  ([#58](https://github.com/MountainGod2/cb-events/pull/58),
  [`e51d770`](https://github.com/MountainGod2/cb-events/commit/e51d770dc05a6253013eccce7970dff9fb17dfdf))

- **router**: Change Handler to type alias
  ([#59](https://github.com/MountainGod2/cb-events/pull/59),
  [`1c4f2f3`](https://github.com/MountainGod2/cb-events/commit/1c4f2f3aeafb9858734c9329de89e56faa2e663f))

- **tests**: Add type hints to test parameters
  ([#57](https://github.com/MountainGod2/cb-events/pull/57),
  [`4754915`](https://github.com/MountainGod2/cb-events/commit/47549156098afaafe498c3042cb231424a951d85))

- **tests**: Consolidate and improve test structure
  ([#57](https://github.com/MountainGod2/cb-events/pull/57),
  [`4754915`](https://github.com/MountainGod2/cb-events/commit/47549156098afaafe498c3042cb231424a951d85))

- **tests**: Consolidate tests and helpers
  ([#57](https://github.com/MountainGod2/cb-events/pull/57),
  [`4754915`](https://github.com/MountainGod2/cb-events/commit/47549156098afaafe498c3042cb231424a951d85))

### Testing

- **client**: Correct testbed URL pattern in mock responses
  ([#58](https://github.com/MountainGod2/cb-events/pull/58),
  [`e51d770`](https://github.com/MountainGod2/cb-events/commit/e51d770dc05a6253013eccce7970dff9fb17dfdf))

- **exceptions**: Add AuthError test for status codes
  ([#57](https://github.com/MountainGod2/cb-events/pull/57),
  [`4754915`](https://github.com/MountainGod2/cb-events/commit/47549156098afaafe498c3042cb231424a951d85))

- **exceptions**: Add test for EventsError response_text truncation
  ([#61](https://github.com/MountainGod2/cb-events/pull/61),
  [`10d5651`](https://github.com/MountainGod2/cb-events/commit/10d5651392cc71773a433451cbc3c647774113ec))

- **tests**: Improve test coverage for polling and exceptions
  ([#58](https://github.com/MountainGod2/cb-events/pull/58),
  [`e51d770`](https://github.com/MountainGod2/cb-events/commit/e51d770dc05a6253013eccce7970dff9fb17dfdf))


## v6.0.0 (2026-03-15)

### Chores

- **build-release**: Update dependency hatchling to v1.29.0
  ([`4895cbd`](https://github.com/MountainGod2/cb-events/commit/4895cbd7455802c760b3cb309026b440968f018f))

- **ci-github-actions**: Update actions/attest-build-provenance action to v4
  ([`e35517b`](https://github.com/MountainGod2/cb-events/commit/e35517b1a025bcf9aeda7b67eed6fc05fde1885d))

- **ci-github-actions**: Update actions/attest-build-provenance digest to a2bbfa2
  ([`97503fa`](https://github.com/MountainGod2/cb-events/commit/97503fabbe363c1770f8cd743b109841dccf1b44))

- **ci-github-actions**: Update actions/download-artifact digest to 3e5f45b
  ([`a09b324`](https://github.com/MountainGod2/cb-events/commit/a09b3246910d709a37ff87f5275837bd84ab683d))

- **ci-github-actions**: Update astral-sh/setup-uv digest to 5a095e7
  ([`8d025f1`](https://github.com/MountainGod2/cb-events/commit/8d025f1b616490e4d84e8c141bdfa3a68b7b5da7))

- **ci-github-actions**: Update astral-sh/setup-uv digest to 6ee6290
  ([`5ad310e`](https://github.com/MountainGod2/cb-events/commit/5ad310e6208d0ce281c9a33862a9e1351bcf9834))

- **ci-github-actions**: Update astral-sh/setup-uv digest to e06108d
  ([`f0c2b48`](https://github.com/MountainGod2/cb-events/commit/f0c2b482c308a094fc13f912ccdc20f7821eefa6))

- **ci-github-actions**: Update ci-github-actions
  ([`0c32354`](https://github.com/MountainGod2/cb-events/commit/0c32354874e1dfa520b5c9cd5cb2825e3769beaa))

- **ci-github-actions**: Update github/codeql-action digest to 0d579ff
  ([`53b1720`](https://github.com/MountainGod2/cb-events/commit/53b1720c252f79d3b2a7e2bf98abddee99257252))

- **ci-github-actions**: Update github/codeql-action digest to 89a39a4
  ([`15c8856`](https://github.com/MountainGod2/cb-events/commit/15c8856987c5ddc4785806c0935adca3754a8e35))

- **ci-github-actions**: Update github/codeql-action digest to c793b71
  ([`8405211`](https://github.com/MountainGod2/cb-events/commit/840521156e8c511b8ff3fae3a102d067062274cd))

- **dependencies**: Replace tenacity with stamina for retry logic
  ([#56](https://github.com/MountainGod2/cb-events/pull/56),
  [`7f260c1`](https://github.com/MountainGod2/cb-events/commit/7f260c12fdf63e5ee20bee6836f2524a55fac3ed))

- **deps**: Lock file maintenance
  ([`d9fccd8`](https://github.com/MountainGod2/cb-events/commit/d9fccd88ede579c9cdb0a2715bd6bc8a60dc36d2))

- **deps**: Lock file maintenance
  ([`eeba928`](https://github.com/MountainGod2/cb-events/commit/eeba9285873111afce7e65bc856e472c7e58c371))

- **docker-images**: Update docker-images
  ([`eca8182`](https://github.com/MountainGod2/cb-events/commit/eca8182a6c6fb5e47593245ea48c92f5f588113f))

- **docker-images**: Update docker-images
  ([`8ec2f1c`](https://github.com/MountainGod2/cb-events/commit/8ec2f1cdc26b56d20c143a00f0f0152a6dc61588))

- **docker-images**: Update docker-images
  ([`ae445bc`](https://github.com/MountainGod2/cb-events/commit/ae445bc7e2078b830478a3b78f19bfd32bc8b875))

- **docker-images**: Update docker-images
  ([`e238bca`](https://github.com/MountainGod2/cb-events/commit/e238bca0a5506a193e571642d9b3ddbafc18b9b7))

- **examples-deps**: Update dependency python-dotenv to v1.2.2
  ([`bbd88c1`](https://github.com/MountainGod2/cb-events/commit/bbd88c17140ffc368692d0c0dd3773e1b5aa96bd))

- **examples-deps**: Update dependency rich to v14.3.3
  ([`9d291f6`](https://github.com/MountainGod2/cb-events/commit/9d291f6d2cc660bf3fcefd2ceb7c48ae4f085cf9))

- **examples-scripts**: Update dependency cb-events to v5.9.1
  ([`9a8b63e`](https://github.com/MountainGod2/cb-events/commit/9a8b63ec78e09911746155274833469be171ed89))

- **examples-scripts**: Update dependency python-dotenv to v1.2.2
  ([`121f381`](https://github.com/MountainGod2/cb-events/commit/121f38139df28acdff468c3a4605037a1b83dd58))

- **pre-commit**: Update pre-commit
  ([`14e6c97`](https://github.com/MountainGod2/cb-events/commit/14e6c97a532fb1461860fec4c3b9fce91aa36763))

- **pre-commit**: Update pre-commit
  ([`b19da65`](https://github.com/MountainGod2/cb-events/commit/b19da6587b8465f6d29a537f0c66c72c84a487dd))

- **pre-commit**: Update pre-commit
  ([`9484745`](https://github.com/MountainGod2/cb-events/commit/9484745b1a26b014e6d39d4404b08d4ba3858020))

- **pre-commit**: Update pre-commit
  ([`d358769`](https://github.com/MountainGod2/cb-events/commit/d3587694340de244835a584dbd876a4f1f0e3c90))

- **pre-commit**: Update pre-commit
  ([`43eecfe`](https://github.com/MountainGod2/cb-events/commit/43eecfe5769f595ee96246aee77ef2f38b39864f))

- **pre-commit**: Update pre-commit
  ([`80f7860`](https://github.com/MountainGod2/cb-events/commit/80f78605a9fb3a33ba24704b823de25129aef951))

- **pre-commit**: Update pre-commit
  ([`1915459`](https://github.com/MountainGod2/cb-events/commit/1915459b83142ddde3a85191d464d496d6025ee1))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.25.11
  ([`324df9d`](https://github.com/MountainGod2/cb-events/commit/324df9d5d813260e407a585043df6fd25044a9e0))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.26.4
  ([`c932951`](https://github.com/MountainGod2/cb-events/commit/c932951039d7159f39e6acb366cbadc39795d876))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.27.0
  ([`ff1b52a`](https://github.com/MountainGod2/cb-events/commit/ff1b52a7c849e0b7fcd8ed7560e67c66b83c5532))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.29.2
  ([`6bf400a`](https://github.com/MountainGod2/cb-events/commit/6bf400ae349f5b2e8dc757c1777e0acce08bdc30))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.31.0
  ([`fe682c2`](https://github.com/MountainGod2/cb-events/commit/fe682c222e16c8dd2d0244b662c60041b76ae846))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.31.1
  ([`94553d9`](https://github.com/MountainGod2/cb-events/commit/94553d91ad3a1bcc995571fe36ceeb1355ac6d23))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.31.7
  ([`441baf2`](https://github.com/MountainGod2/cb-events/commit/441baf28e053450b10996a6952ae1ef9eb02bd97))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.33.1
  ([`12eaeb7`](https://github.com/MountainGod2/cb-events/commit/12eaeb77e7258f12a99886ced4ccceb32c6a281f))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.39.2
  ([`a962a9f`](https://github.com/MountainGod2/cb-events/commit/a962a9fdd194bdbccfa7ad7409eaaf0c21d999af))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.46.0
  ([`4419115`](https://github.com/MountainGod2/cb-events/commit/441911598dbb4b6c114f9306a4eab9a4ecdc3b2f))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.49.0
  ([`b600793`](https://github.com/MountainGod2/cb-events/commit/b600793f7be0c0ad5124caae003756b4b83d0946))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.52.0
  ([`90760af`](https://github.com/MountainGod2/cb-events/commit/90760af6dc6eb3ba0a43929d605b821950d37941))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.56.0
  ([`00e0bac`](https://github.com/MountainGod2/cb-events/commit/00e0bac72a8c8a6fdd6567eeec36bdcef6510d59))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.59.2
  ([`1d04001`](https://github.com/MountainGod2/cb-events/commit/1d040014744715694a6c04080bd399d2d6ea292c))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.59.3
  ([`ddae0b9`](https://github.com/MountainGod2/cb-events/commit/ddae0b9e8feaa71fa2818eb9e0a41605abda0415))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.59.4
  ([`940d344`](https://github.com/MountainGod2/cb-events/commit/940d3446ac19f1a51058422a0b1fb24533966f56))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.60.4
  ([`e09093b`](https://github.com/MountainGod2/cb-events/commit/e09093be917a108cf6118810ea572f11336e47dd))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.60.5
  ([`dadf9bf`](https://github.com/MountainGod2/cb-events/commit/dadf9bfae60f07af8c615783e727c8e1137613ce))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.61.7
  ([`df83a72`](https://github.com/MountainGod2/cb-events/commit/df83a7285fe443f97e72338f89a885a5dadf60c9))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.64.2
  ([`bf76647`](https://github.com/MountainGod2/cb-events/commit/bf76647a641c81c8a6782d28fff39b5eda863614))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.76.1
  ([`73dfb59`](https://github.com/MountainGod2/cb-events/commit/73dfb594af05823af135dfc52fd3992ee584aaa9))

- **python-dev-tools**: Update dependency bandit to v1.9.4
  ([`bfb912b`](https://github.com/MountainGod2/cb-events/commit/bfb912b9b4ab5fa3f5f8128991bac7f262b87fa2))

- **python-dev-tools**: Update dependency pylint to v4.0.5
  ([`fa2bd4d`](https://github.com/MountainGod2/cb-events/commit/fa2bd4d557818d5040ff0e3987bdc8663cb5301e))

- **python-dev-tools**: Update dependency pyrefly to v0.54.0
  ([`fb9c790`](https://github.com/MountainGod2/cb-events/commit/fb9c790abdaf6713f767d5166549aec48973bd08))

- **python-dev-tools**: Update dependency pyrefly to v0.55.0
  ([`3dd29e6`](https://github.com/MountainGod2/cb-events/commit/3dd29e60410de48997f968e2b1beb8f8f005e9da))

- **python-dev-tools**: Update dependency ruff to v0.15.2
  ([`7684c1b`](https://github.com/MountainGod2/cb-events/commit/7684c1b89612f91e144bb84500728662cec5ac94))

- **python-dev-tools**: Update dependency ty to v0.0.18
  ([`fae3a91`](https://github.com/MountainGod2/cb-events/commit/fae3a91f32576f87aca08f3ab034e2a8891bf19f))

- **python-dev-tools**: Update dependency ty to v0.0.20
  ([`aa8b564`](https://github.com/MountainGod2/cb-events/commit/aa8b564e7e2fce59b21ae008925f31edd624edc1))

- **python-dev-tools**: Update python-dev-tools
  ([`571eb0f`](https://github.com/MountainGod2/cb-events/commit/571eb0f393030701a8d90fe97dd977e38d111428))

- **python-dev-tools**: Update python-dev-tools
  ([#55](https://github.com/MountainGod2/cb-events/pull/55),
  [`25325bb`](https://github.com/MountainGod2/cb-events/commit/25325bb6a5f4c73a7ead415470cd30a6721505c5))

- **python-dev-tools**: Update python-dev-tools
  ([`5570eb3`](https://github.com/MountainGod2/cb-events/commit/5570eb335b9d679c1775717c71442765473db3db))

- **python-dev-tools**: Update python-dev-tools
  ([`f9f3cea`](https://github.com/MountainGod2/cb-events/commit/f9f3cead17735c6ccc9d412dee754e4dd1668926))

- **python-docs**: Update dependency sphinx-autoapi to v3.8.0
  ([`65d23d5`](https://github.com/MountainGod2/cb-events/commit/65d23d551792b5b02f7fd5c46bbb208924a85e49))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.7.0
  ([`f9eea30`](https://github.com/MountainGod2/cb-events/commit/f9eea309db7ca90459944051549c58ee462cbf54))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.8.0
  ([`150c25c`](https://github.com/MountainGod2/cb-events/commit/150c25c1c484e26e7185a69e368b0f3b4b73af04))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.9.3
  ([`06617eb`](https://github.com/MountainGod2/cb-events/commit/06617eb70cd19c9a4986966ad6038ed2b287cbff))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.9.5
  ([`340db44`](https://github.com/MountainGod2/cb-events/commit/340db44b1ce5eb74227b75ceddb0d39011c535f3))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.9.6
  ([`bf3798a`](https://github.com/MountainGod2/cb-events/commit/bf3798abc41d710c2fc712053b54d76744e0055b))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.9.7
  ([`382aae1`](https://github.com/MountainGod2/cb-events/commit/382aae151e236272e0eef64b3552a87716458925))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.9.8
  ([`e368172`](https://github.com/MountainGod2/cb-events/commit/e368172d409d5070c09d030db7e945cd6da1899f))

### Documentation

- **README**: Correct license badge formatting
  ([#54](https://github.com/MountainGod2/cb-events/pull/54),
  [`ffb73a1`](https://github.com/MountainGod2/cb-events/commit/ffb73a18713194f3fa1d8a951fa53f9199133892))

- **README**: Update license badge ([#54](https://github.com/MountainGod2/cb-events/pull/54),
  [`ffb73a1`](https://github.com/MountainGod2/cb-events/commit/ffb73a18713194f3fa1d8a951fa53f9199133892))

### Features

- **dependencies**: Replace tenacity with stamina for retry logic
  ([#56](https://github.com/MountainGod2/cb-events/pull/56),
  [`7f260c1`](https://github.com/MountainGod2/cb-events/commit/7f260c12fdf63e5ee20bee6836f2524a55fac3ed))

### Refactoring

- **client**: Add HTTP metadata to _TransientError
  ([#56](https://github.com/MountainGod2/cb-events/pull/56),
  [`7f260c1`](https://github.com/MountainGod2/cb-events/commit/7f260c12fdf63e5ee20bee6836f2524a55fac3ed))

- **client**: Handle None for status_code and response_text
  ([#56](https://github.com/MountainGod2/cb-events/pull/56),
  [`7f260c1`](https://github.com/MountainGod2/cb-events/commit/7f260c12fdf63e5ee20bee6836f2524a55fac3ed))

### Testing

- **client**: Add test for exponential backoff logic
  ([#56](https://github.com/MountainGod2/cb-events/pull/56),
  [`7f260c1`](https://github.com/MountainGod2/cb-events/commit/7f260c12fdf63e5ee20bee6836f2524a55fac3ed))

- **conftest**: Change reset_stamina_state return type to Iterator[None]
  ([#56](https://github.com/MountainGod2/cb-events/pull/56),
  [`7f260c1`](https://github.com/MountainGod2/cb-events/commit/7f260c12fdf63e5ee20bee6836f2524a55fac3ed))


## v5.9.1 (2026-02-19)

### Bug Fixes

- **deps**: Update dependency tenacity to v9.1.4
  ([#52](https://github.com/MountainGod2/cb-events/pull/52),
  [`1296a3b`](https://github.com/MountainGod2/cb-events/commit/1296a3b37d62b68bbd543d3d768dfc48215a51b3))

### Chores

- **ci-github-actions**: Update actions/checkout digest to de0fac2
  ([`9ead9b6`](https://github.com/MountainGod2/cb-events/commit/9ead9b6c54c0d49b2976b2b1d6bd480cc106ff3c))

- **ci-github-actions**: Update astral-sh/setup-uv digest to 803947b
  ([`cd4e01d`](https://github.com/MountainGod2/cb-events/commit/cd4e01df457f31a053a4a1491a5c70b1ab6ca899))

- **ci-github-actions**: Update astral-sh/setup-uv digest to eac588a
  ([`ccd7495`](https://github.com/MountainGod2/cb-events/commit/ccd74958b413186d4ba13fadece6d649ed1a82d4))

- **ci-github-actions**: Update github/codeql-action digest to 19b2f06
  ([`4aa6e58`](https://github.com/MountainGod2/cb-events/commit/4aa6e58a3f58ce8451acf192e3f2e57b39ea5410))

- **ci-github-actions**: Update github/codeql-action digest to 45cbd0c
  ([`52584a3`](https://github.com/MountainGod2/cb-events/commit/52584a3eeec1bc5f20e8d53d65e0b314235c9a48))

- **ci-github-actions**: Update github/codeql-action digest to 6bc82e0
  ([`13aa7a4`](https://github.com/MountainGod2/cb-events/commit/13aa7a4e7acb38adc332c27542b6c72de4b9b104))

- **ci-github-actions**: Update github/codeql-action digest to 9e907b5
  ([`b571aea`](https://github.com/MountainGod2/cb-events/commit/b571aea639592ab1135ea9ad4837b9bb1e3bf3c1))

- **ci-github-actions**: Update github/codeql-action digest to b20883b
  ([`ee74a6a`](https://github.com/MountainGod2/cb-events/commit/ee74a6a203fe0649c7d72cf99e7e62fc577dbda8))

- **deps**: Lock file maintenance
  ([`c65093f`](https://github.com/MountainGod2/cb-events/commit/c65093f11d2f4147de717a662e283729a226e3bc))

- **deps**: Lock file maintenance
  ([`8e5333a`](https://github.com/MountainGod2/cb-events/commit/8e5333a7474d7a11c997359b97039d5abef9337f))

- **deps**: Lock file maintenance
  ([`2b3346d`](https://github.com/MountainGod2/cb-events/commit/2b3346dd4fc656ed484080c3252f51f5bc972e3d))

- **deps**: Lock file maintenance
  ([`af0628e`](https://github.com/MountainGod2/cb-events/commit/af0628ea8d06fc6870084c120f6bba7ace2dbb85))

- **deps**: Lock file maintenance
  ([`43b09ba`](https://github.com/MountainGod2/cb-events/commit/43b09ba1141b0b76ca2af300d8d7dc0eaca4aea3))

- **deps**: Update pre-commit hook renovatebot/pre-commit-hooks to v43
  ([#51](https://github.com/MountainGod2/cb-events/pull/51),
  [`ef74d9e`](https://github.com/MountainGod2/cb-events/commit/ef74d9e616c28ad4b0af4360fd90b19cdb666c3a))

- **docker-images**: Update docker-images
  ([`f421c47`](https://github.com/MountainGod2/cb-events/commit/f421c47d69b2eaf386731e8e1d7195640e0fd3ff))

- **docker-images**: Update docker-images
  ([`9c75721`](https://github.com/MountainGod2/cb-events/commit/9c75721f9817f697b85bcee9b02ea235facd7071))

- **docker-images**: Update docker-images
  ([`ed64390`](https://github.com/MountainGod2/cb-events/commit/ed64390073c986a4e47332ca09383ba3a7d37ae2))

- **docker-images**: Update docker-images
  ([`9ef5090`](https://github.com/MountainGod2/cb-events/commit/9ef5090cd23353b5e370525b28bc7602e6373565))

- **docker-images**: Update docker-images
  ([`0eff9ac`](https://github.com/MountainGod2/cb-events/commit/0eff9acd06cd1d8a1667a63450922e0c6ea7e475))

- **docker-images**: Update docker-images
  ([`6cf7fb4`](https://github.com/MountainGod2/cb-events/commit/6cf7fb4da8cc394fdafc5677273549503388f9b0))

- **examples-deps**: Update dependency rich to v14.3.0
  ([`80359bd`](https://github.com/MountainGod2/cb-events/commit/80359bd64120ce3c363d64eac0901c39e3676b35))

- **examples-deps**: Update dependency rich to v14.3.1
  ([`1d6d16f`](https://github.com/MountainGod2/cb-events/commit/1d6d16f030381bf4e4463afe89acfd4662cd90b0))

- **examples-deps**: Update dependency rich to v14.3.2
  ([`e9929e9`](https://github.com/MountainGod2/cb-events/commit/e9929e9b7f3f0012aecbb9e9048db35b033347a6))

- **examples-scripts**: Update dependency cb-events to v5.9.0
  ([`0ae3431`](https://github.com/MountainGod2/cb-events/commit/0ae34318581a5f5aa4c90cb7dddcff76885350c4))

- **pre-commit**: Update pre-commit
  ([`bd09706`](https://github.com/MountainGod2/cb-events/commit/bd09706bdcc5d43f458fd06b94f81353e899e077))

- **pre-commit**: Update pre-commit
  ([`9def64b`](https://github.com/MountainGod2/cb-events/commit/9def64b0b1c10c8ef1efca1c91ccb2cdaa4e5c88))

- **pre-commit**: Update pre-commit
  ([`0d42b81`](https://github.com/MountainGod2/cb-events/commit/0d42b8143af52d874ecd7de9af7ba8db4422e93c))

- **pre-commit**: Update pre-commit
  ([`ca90b72`](https://github.com/MountainGod2/cb-events/commit/ca90b7264b8d9b24356773cad69221f29253fe96))

- **pre-commit**: Update pre-commit
  ([`280af7e`](https://github.com/MountainGod2/cb-events/commit/280af7efe494c744f19fe82a7cb4a6e12efed29a))

- **pre-commit**: Update pre-commit
  ([`af0a4a8`](https://github.com/MountainGod2/cb-events/commit/af0a4a80e4d5d1e64eeb9d0a7cb602ec8eacd184))

- **pre-commit**: Update pre-commit
  ([`94021d6`](https://github.com/MountainGod2/cb-events/commit/94021d658d55f7b300b99ad03fa25ebf2d8d7802))

- **pre-commit**: Update pre-commit
  ([`4daa6b9`](https://github.com/MountainGod2/cb-events/commit/4daa6b9a9e5c877c9a0d8f47e248c27843ceeed4))

- **pre-commit**: Update pre-commit
  ([`282d92f`](https://github.com/MountainGod2/cb-events/commit/282d92f67ff216fedc75d0dbd413f5f491de8ff9))

- **pre-commit**: Update pre-commit
  ([`d4004f7`](https://github.com/MountainGod2/cb-events/commit/d4004f71df4a341be39b632d84bc44069dd5c3c9))

- **pre-commit**: Update pre-commit hook adhtruong/mirrors-typos to v1.42.1
  ([`10060f8`](https://github.com/MountainGod2/cb-events/commit/10060f8e30169168d12349ed27f33dac4bdf6283))

- **pre-commit**: Update pre-commit hook adhtruong/mirrors-typos to v1.42.3
  ([`2fb5dba`](https://github.com/MountainGod2/cb-events/commit/2fb5dba035bc1b2cd505e84473585c8645067dee))

- **pre-commit**: Update pre-commit hook adhtruong/mirrors-typos to v1.43.2
  ([`ec213eb`](https://github.com/MountainGod2/cb-events/commit/ec213eba62f2778939bd3b66a5067fcc74b3c9e3))

- **pre-commit**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.14.14
  ([`538e873`](https://github.com/MountainGod2/cb-events/commit/538e8734d2ae9209b13fa57aa9ecd56498180284))

- **pre-commit**: Update pre-commit hook pycqa/bandit to v1.9.3
  ([`d925614`](https://github.com/MountainGod2/cb-events/commit/d9256148bbe882f828ce7cad35c442a50be4c421))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.81.2
  ([`10d6696`](https://github.com/MountainGod2/cb-events/commit/10d6696dd2b7476d8809e798a0273b20c562b41e))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.81.3
  ([`fd4ad1f`](https://github.com/MountainGod2/cb-events/commit/fd4ad1f6cedbd880556aa1a0ad305d650202229d))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.81.6
  ([`99bce9b`](https://github.com/MountainGod2/cb-events/commit/99bce9b3db0ef6d642d2e74a8994319e84b2128a))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.81.8
  ([`7828749`](https://github.com/MountainGod2/cb-events/commit/782874905a50c0247b27c8608c2f8c45ad641232))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.83.0
  ([`4612d39`](https://github.com/MountainGod2/cb-events/commit/4612d39627ececb65763e84b27994f1282d17f70))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.83.1
  ([`767cc79`](https://github.com/MountainGod2/cb-events/commit/767cc7901f508c613aa59df7559a935e6985bf89))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.84.0
  ([`f129214`](https://github.com/MountainGod2/cb-events/commit/f1292145b3b3f1f22e704cc1b5c58c4e6e91f496))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.93.1
  ([`dff8cce`](https://github.com/MountainGod2/cb-events/commit/dff8cce7f041b3bc8855a19a051d20c801d7946e))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.95.1
  ([`2d38db1`](https://github.com/MountainGod2/cb-events/commit/2d38db10d0e675f7c7ea20a30fb4fbe3be9b8df6))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.10.2
  ([`34fa37a`](https://github.com/MountainGod2/cb-events/commit/34fa37a7d3980057b020a4f6e5c6ecc45e09d44d))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.14.1
  ([`eaf6fa0`](https://github.com/MountainGod2/cb-events/commit/eaf6fa006eba15d8234e5ce6380e027f7ce2af5b))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.15.0
  ([`02f8c75`](https://github.com/MountainGod2/cb-events/commit/02f8c7582530f21ce3b9ffa70bc72dbf056d3f9b))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.15.1
  ([`8aaff5d`](https://github.com/MountainGod2/cb-events/commit/8aaff5dd2c3d4e016e2e3a283a1289b7a9f1d116))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.19.2
  ([`1179f63`](https://github.com/MountainGod2/cb-events/commit/1179f6338183a94dc3e2f2441f591f82bae6b46c))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.3.4
  ([`76a75cd`](https://github.com/MountainGod2/cb-events/commit/76a75cdc5641a996186bdc13a9e565d6c1d5ba04))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.4.0
  ([`90a6ca3`](https://github.com/MountainGod2/cb-events/commit/90a6ca3e227eb26313dc5ab39f0255712f88f39d))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.4.3
  ([`ffcd73d`](https://github.com/MountainGod2/cb-events/commit/ffcd73d61ad2070880028c6ef008df5f375e2dba))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.5.4
  ([`22bef3e`](https://github.com/MountainGod2/cb-events/commit/22bef3ecca33e65f0740989bda3b362552deb1fa))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.8.2
  ([`738cbb8`](https://github.com/MountainGod2/cb-events/commit/738cbb84f44a345d14f753656be8744f0b7f4888))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v43.8.5
  ([`5cff272`](https://github.com/MountainGod2/cb-events/commit/5cff272203a12d479d4e438a29c195341cf40a0a))

- **python-dev-tools**: Update dependency bandit to v1.9.3
  ([`adf0700`](https://github.com/MountainGod2/cb-events/commit/adf0700476154977ca19af744231f7ec09a062fa))

- **python-dev-tools**: Update dependency pyrefly to v0.48.2
  ([`0bd8e18`](https://github.com/MountainGod2/cb-events/commit/0bd8e18f8220fe761fa439bd547c0ba10e348688))

- **python-dev-tools**: Update dependency pyrefly to v0.49.0
  ([`690f345`](https://github.com/MountainGod2/cb-events/commit/690f345c10c75a14f348890803e05e900924173b))

- **python-dev-tools**: Update dependency pyrefly to v0.50.1
  ([`669b670`](https://github.com/MountainGod2/cb-events/commit/669b6701b72ec69a9269b214c9966bae3ee8c652))

- **python-dev-tools**: Update dependency pyrefly to v0.51.0
  ([`4e96691`](https://github.com/MountainGod2/cb-events/commit/4e9669169ab0f6d9ad60bddf0c99699074ceeeac))

- **python-dev-tools**: Update dependency pyrefly to v0.51.1
  ([`123ce12`](https://github.com/MountainGod2/cb-events/commit/123ce12cf4caee225d63717f9bcdcbc3b67e2ad7))

- **python-dev-tools**: Update dependency pyrefly to v0.51.2
  ([`57b874d`](https://github.com/MountainGod2/cb-events/commit/57b874d96cd33d133d2c742b8ea31a0e046e3f12))

- **python-dev-tools**: Update dependency pyrefly to v0.52.0
  ([`8302c37`](https://github.com/MountainGod2/cb-events/commit/8302c37b4ebff4e489bf8b88083b64782d3aa23f))

- **python-dev-tools**: Update dependency pyrefly to v0.53.0
  ([`ebe3fb4`](https://github.com/MountainGod2/cb-events/commit/ebe3fb4a71a79d4185e585dea92dc6c5b32f8bb1))

- **python-dev-tools**: Update dependency ruff to v0.14.14
  ([`a079c69`](https://github.com/MountainGod2/cb-events/commit/a079c6993f5f74a2bcc636f32b390997cacc8eb1))

- **python-dev-tools**: Update dependency ruff to v0.15.0
  ([`6274e3d`](https://github.com/MountainGod2/cb-events/commit/6274e3d90b74d82b66cad0a199b6b7ed03517777))

- **python-dev-tools**: Update dependency ty to v0.0.12
  ([`a58c7ed`](https://github.com/MountainGod2/cb-events/commit/a58c7edc8dfe3e0210349792bd8043bb67f73a9a))

- **python-dev-tools**: Update dependency ty to v0.0.13
  ([`6b4945f`](https://github.com/MountainGod2/cb-events/commit/6b4945f17f4c1654e9a0f5c1256758b2342173df))

- **python-dev-tools**: Update dependency ty to v0.0.15
  ([`be81b95`](https://github.com/MountainGod2/cb-events/commit/be81b95ef6437c013e6c7f3b0856f8789cf9e821))

- **python-dev-tools**: Update dependency ty to v0.0.16
  ([`2bb8582`](https://github.com/MountainGod2/cb-events/commit/2bb85826f80427813a23b6bf958da1a28058a90a))

- **python-dev-tools**: Update python-dev-tools
  ([#53](https://github.com/MountainGod2/cb-events/pull/53),
  [`ed84828`](https://github.com/MountainGod2/cb-events/commit/ed8482854f76c18fe7a0d69489e956bd6320c387))

- **python-dev-tools**: Update python-dev-tools
  ([`d8b98eb`](https://github.com/MountainGod2/cb-events/commit/d8b98eb91f963dbf1adba5af95dce6111b940cf7))

- **python-dev-tools**: Update python-dev-tools
  ([`9101a62`](https://github.com/MountainGod2/cb-events/commit/9101a62f73f08b1f93a1fbe09c3c30683e9713cc))

- **python-docs**: Update dependency sphinx-autoapi to v3.7.0
  ([`849d691`](https://github.com/MountainGod2/cb-events/commit/849d691eafea4f90618002b2bfa5eaf6c4fb9908))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.6.3
  ([`ca5adf2`](https://github.com/MountainGod2/cb-events/commit/ca5adf2de64725309a4aac5000f365b43f2fe4ba))

### Continuous Integration

- Update codecov action and add report types
  ([`3114fc3`](https://github.com/MountainGod2/cb-events/commit/3114fc372ff6ec6575d14e30abdf1afb61426b43))

### Testing

- **client**: Use pytest.approx for floating point assertions
  ([`b5817d6`](https://github.com/MountainGod2/cb-events/commit/b5817d677f5fa922e89f822c0e0b5b8607678af3))


## v5.9.0 (2026-01-14)

### Bug Fixes

- **models**: Change extra field behavior to ignore unknown fields
  ([`7216b19`](https://github.com/MountainGod2/cb-events/commit/7216b198dd586f292a0aaebed9c06771ad375576))

### Chores

- **ci-github-actions**: Update github/codeql-action digest to cdefb33
  ([`9b75430`](https://github.com/MountainGod2/cb-events/commit/9b754305035ed42b3e15765137c3da71aaffd29b))

- **deps**: Lock file maintenance
  ([`96332d1`](https://github.com/MountainGod2/cb-events/commit/96332d16d9c88e49421f74110fad4cbfb58a84d7))

- **docker-images**: Update dhi.io/python:3.14-alpine3.23-dev docker digest to 314cee7
  ([`1872b89`](https://github.com/MountainGod2/cb-events/commit/1872b891634606f503d6da00a88ae11568e69713))

- **docker-images**: Update dhi.io/python:3.14-alpine3.23-dev docker digest to 4a6cdb0
  ([`56909d9`](https://github.com/MountainGod2/cb-events/commit/56909d9ce312ab03970ed8f72c05ca9a98cc7ef9))

- **docker-images**: Update dhi.io/python:3.14-alpine3.23-dev docker digest to d182abb
  ([`378c749`](https://github.com/MountainGod2/cb-events/commit/378c749f22b6b69a3c31a2bbc17d14d796e8e45a))

- **docker-images**: Update docker-images
  ([`bff1f7a`](https://github.com/MountainGod2/cb-events/commit/bff1f7a4104352095b6602d807a4b448b46119de))

- **examples-scripts**: Update dependency cb-events to v5.8.2
  ([`c11a0c0`](https://github.com/MountainGod2/cb-events/commit/c11a0c0e95289acef50a984b0a517afaede1696c))

- **pre-commit**: Update pre-commit
  ([`4e31e74`](https://github.com/MountainGod2/cb-events/commit/4e31e74cf519b86cb701d76e348dd3226a689b13))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.74.2
  ([`c8c92a8`](https://github.com/MountainGod2/cb-events/commit/c8c92a8a0396f1d81b3f59b1e94cc68d8aa864b7))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.76.4
  ([`74a64e6`](https://github.com/MountainGod2/cb-events/commit/74a64e6b4268615f26e11a02c4cdfea8682c2edb))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.78.0
  ([`4457070`](https://github.com/MountainGod2/cb-events/commit/44570706214b57b7052adfadfac5a6bebdc16432))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.78.1
  ([`1d1f807`](https://github.com/MountainGod2/cb-events/commit/1d1f807de38edb3ca9e724c18981c5e6366028c1))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.78.2
  ([`9d64ba4`](https://github.com/MountainGod2/cb-events/commit/9d64ba4f0663d589ab6bee9e8f42e39725fe1583))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.80.1
  ([`13a2a34`](https://github.com/MountainGod2/cb-events/commit/13a2a34dcb1b5b4197d4d5c5926bd3e364e331f6))

- **pre-commit**: Update renovatebot hooks to v42.76.5
  ([`0b5bf2d`](https://github.com/MountainGod2/cb-events/commit/0b5bf2d43cae753f5039831673853596d9cc1095))

- **python-dev-tools**: Update dependency pyrefly to v0.48.0
  ([`c422977`](https://github.com/MountainGod2/cb-events/commit/c422977485e680ce8b51efa36fcec88cc2693114))

- **python-dev-tools**: Update dependency pyright to v1.1.408
  ([`32c40e5`](https://github.com/MountainGod2/cb-events/commit/32c40e588382b30f54b70d0e6c3a71c3c813062f))

- **python-dev-tools**: Update dependency ty to v0.0.10
  ([`906efa3`](https://github.com/MountainGod2/cb-events/commit/906efa3d86b8a8b2d61aafb15d5c85941e9bf2ec))

- **python-dev-tools**: Update python-dev-tools
  ([#50](https://github.com/MountainGod2/cb-events/pull/50),
  [`8fae012`](https://github.com/MountainGod2/cb-events/commit/8fae012dd4ef66124fef71b48a492dd295c1ce57))

### Features

- **client**: Recreate retry logic with tenacity
  ([`34437e3`](https://github.com/MountainGod2/cb-events/commit/34437e318e514eec5993513568bd2757dba15be6))

### Refactoring

- **client**: Move _TransientError class outside EventClient
  ([`6734f53`](https://github.com/MountainGod2/cb-events/commit/6734f5323cc20f9bb49494aea091fb552bdd0b7b))

- **client**: Remove unused functions
  ([`52322d1`](https://github.com/MountainGod2/cb-events/commit/52322d12e05edfba82ae7567093e22875b0c8f74))

- **config**: Adjust message type assignment
  ([`07f6f8c`](https://github.com/MountainGod2/cb-events/commit/07f6f8cb2e62d1e55d591d5a3de8ff2aed329c9e))

- **exceptions**: Simplify attribute assignment in EventsError
  ([`94e8334`](https://github.com/MountainGod2/cb-events/commit/94e833473b5d01151dee775634ec38c17c3c553e))

- **models**: Remove unnecessary type casting in Event class
  ([`0438d18`](https://github.com/MountainGod2/cb-events/commit/0438d183b284fbc7dccbeda7c7819b8b6ae227f5))

- **router**: Simplify docstrings and variable assignments
  ([`5ff4c13`](https://github.com/MountainGod2/cb-events/commit/5ff4c13e6a4ee321cd1ba6466ea874e1aafc19db))

- **tests**: Remove unused _compose_message test
  ([`150ed63`](https://github.com/MountainGod2/cb-events/commit/150ed63b938cd8bbb0ca8d5f4c662f93a845a5d4))

- **version**: Move version logic to separate file
  ([`42a6f12`](https://github.com/MountainGod2/cb-events/commit/42a6f121e237e03aae92d166a4e8073a9d6b08fe))


## v5.8.2 (2026-01-07)

### Bug Fixes

- **python-runtime**: Update dependency aiohttp to v3.13.3
  ([#49](https://github.com/MountainGod2/cb-events/pull/49),
  [`17ce240`](https://github.com/MountainGod2/cb-events/commit/17ce240b1f92914e8bf1e8e05f0076ff433bf044))

### Chores

- **ci-github-actions**: Update astral-sh/setup-uv digest to 61cb8a9
  ([`4eeaa09`](https://github.com/MountainGod2/cb-events/commit/4eeaa09b941f08d7fa8a71c99cbebcee01d38198))

- **deps**: Lock file maintenance
  ([`fe692d3`](https://github.com/MountainGod2/cb-events/commit/fe692d39772ebe6ef1fd23de85c6f219a1551ac9))

- **deps**: Lock file maintenance
  ([`58d75a7`](https://github.com/MountainGod2/cb-events/commit/58d75a723b2ba033c9a547c083a98b6e7e17ef9b))

- **deps**: Pin dependencies ([#48](https://github.com/MountainGod2/cb-events/pull/48),
  [`785f3ca`](https://github.com/MountainGod2/cb-events/commit/785f3ca63c985b9be594c25fe323fb949b8d009f))

- **dev**: Update dependency pyrefly to v0.46.3
  ([`1e301ff`](https://github.com/MountainGod2/cb-events/commit/1e301ff38c0770d386aea14506bca16e3da1f427))

- **dev**: Update dev
  ([`5d16033`](https://github.com/MountainGod2/cb-events/commit/5d1603302dc54a9deffef581634f8fa64a74b596))

- **Dockerfile**: Update base image to alpine3.23
  ([`6650d01`](https://github.com/MountainGod2/cb-events/commit/6650d010a7a82d550540afcf22066532a4bb5bf2))

- **docs**: Update dependency sphinx to v9.1.0
  ([`05b2682`](https://github.com/MountainGod2/cb-events/commit/05b2682aa95f040dda323c7c39a07ef5824e087e))

- **examples**: Update dependency cb-events to v5.8.1
  ([`baaed85`](https://github.com/MountainGod2/cb-events/commit/baaed85251816e195060c90d3738e0b1d1c7893f))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.10
  ([`01f211d`](https://github.com/MountainGod2/cb-events/commit/01f211d6ecc865dc02677f97e913aa1188dc5ca5))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.11
  ([`4d47ec6`](https://github.com/MountainGod2/cb-events/commit/4d47ec6c47dd850378c2ccada8de9f9d5ea19466))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.14
  ([`d7d5e11`](https://github.com/MountainGod2/cb-events/commit/d7d5e1153f0c0b003f66a7e4997c012062d23356))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.8
  ([#47](https://github.com/MountainGod2/cb-events/pull/47),
  [`85d99f3`](https://github.com/MountainGod2/cb-events/commit/85d99f31ad9d2c2e98cb53058630cba6d12bd809))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.9
  ([`cd72a72`](https://github.com/MountainGod2/cb-events/commit/cd72a7223e2cbf51193575803d9b20e761ecc7af))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.70.2
  ([`8f3c227`](https://github.com/MountainGod2/cb-events/commit/8f3c2276cc2f220ca340ccca7801117dce4ec11e))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.70.3
  ([`71f7fba`](https://github.com/MountainGod2/cb-events/commit/71f7fbaee96596a7ee5e4b4f79437a8d24692491))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.71.0
  ([`907ff25`](https://github.com/MountainGod2/cb-events/commit/907ff25840f2e1cae5da4fb86fd300e5b96b182b))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.71.2
  ([`9c30ee7`](https://github.com/MountainGod2/cb-events/commit/9c30ee7be7d6bb4381867f343dcc6207562174c7))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.71.4
  ([`72bd61b`](https://github.com/MountainGod2/cb-events/commit/72bd61bd063ba90ab5499fd6dda23b020bf6925f))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.72.0
  ([`d263c07`](https://github.com/MountainGod2/cb-events/commit/d263c070d4a309c206ec3311765434a9210e8146))

- **pre-commit**: Update pre-commit-hooks
  ([`ea0e133`](https://github.com/MountainGod2/cb-events/commit/ea0e1334e8e924e47c3f421a85e38c7c9eebe3d9))

- **pre-commit**: Update pre-commit-hooks
  ([`1adcd4a`](https://github.com/MountainGod2/cb-events/commit/1adcd4a4a999d5e8383b3c8fc5f2e9e47d458e51))

- **python-dev-tools**: Update python-dev-tools
  ([`b0704bf`](https://github.com/MountainGod2/cb-events/commit/b0704bf1a811c1d0095123dc1852c53dbbb95d52))

- **python-docs**: Update dependency sphinx-autodoc-typehints to v3.6.2
  ([`89f9f4d`](https://github.com/MountainGod2/cb-events/commit/89f9f4d66cbeea27922da076879c7f354eac33b3))

- **renovate**: Add host rules for dhi.io
  ([`d76ef7b`](https://github.com/MountainGod2/cb-events/commit/d76ef7b39e40a49780cb23a5f23aaa02f88d485a))

- **renovate**: Remove unused host rules for dhi.io
  ([`824f2c1`](https://github.com/MountainGod2/cb-events/commit/824f2c12e85a789c94952201bb70c9e4543234ce))

- **renovate**: Update configuration for dependency management
  ([`d5cdd04`](https://github.com/MountainGod2/cb-events/commit/d5cdd040bbe5a1a303ca445e83f82a8f7a5e802b))


## v5.8.1 (2025-12-26)

### Bug Fixes

- **docs**: Update html_theme_options type to include bool
  ([`9c9a3a8`](https://github.com/MountainGod2/cb-events/commit/9c9a3a894aa502ced20674336056b3342851edef))

### Chores

- **build**: Update dependency python-semantic-release to v10.5.3
  ([`53879fa`](https://github.com/MountainGod2/cb-events/commit/53879faca59426341baedcfb093594545c076959))

- **ci**: Update astral-sh/setup-uv digest to 681c641
  ([#42](https://github.com/MountainGod2/cb-events/pull/42),
  [`47c2b46`](https://github.com/MountainGod2/cb-events/commit/47c2b46a07711385d99285784dc8500779066f81))

- **ci**: Update codecov/test-results-action digest to 0fa95f0
  ([`7c5d095`](https://github.com/MountainGod2/cb-events/commit/7c5d0956220f720dcf2d2477bd6b193363b4cf80))

- **ci**: Update github-actions ([#40](https://github.com/MountainGod2/cb-events/pull/40),
  [`ed21be9`](https://github.com/MountainGod2/cb-events/commit/ed21be9f65aaaff3d022616719f269232f456ab1))

- **ci**: Update github/codeql-action digest to 5d4e8d1
  ([`1727fb6`](https://github.com/MountainGod2/cb-events/commit/1727fb69acb63946a27b628edae358513fd3b447))

- **deps**: Update dependency furo to v2025.12.19
  ([#45](https://github.com/MountainGod2/cb-events/pull/45),
  [`1c2dcda`](https://github.com/MountainGod2/cb-events/commit/1c2dcda2f1efc892612d3fcbf2011f0643db127b))

- **deps**: Update dependency pre-commit to v4.5.1
  ([#44](https://github.com/MountainGod2/cb-events/pull/44),
  [`56a3700`](https://github.com/MountainGod2/cb-events/commit/56a37001150b664f83f248d9daf8eb133461a9ab))

- **deps**: Update dependency sphinx to v9
  ([#36](https://github.com/MountainGod2/cb-events/pull/36),
  [`051875c`](https://github.com/MountainGod2/cb-events/commit/051875c59460d548dcea37f444f591c4bb692803))

- **deps**: Update furo dependency to version 2025.12.19
  ([`f77dcb3`](https://github.com/MountainGod2/cb-events/commit/f77dcb33d5e6836305de3056e96829c6a8845ed5))

- **deps**: Update ty dependency to version 0.0.5
  ([`ed4092b`](https://github.com/MountainGod2/cb-events/commit/ed4092b00db7b6093202487e77fe050437d3e7db))

- **dev**: Update dependency pyrefly to v0.46.0
  ([`d0e368e`](https://github.com/MountainGod2/cb-events/commit/d0e368e890311ab0dec4d9bcaec2a7a422277746))

- **dev**: Update dependency pyrefly to v0.46.1
  ([`651b339`](https://github.com/MountainGod2/cb-events/commit/651b339b188d9b65418bf1504ab1b43ddbfda838))

- **dev**: Update dependency ty to v0.0.1a35
  ([`b3cfda2`](https://github.com/MountainGod2/cb-events/commit/b3cfda2403a816bb65776fb31ac7008a62b2ef2c))

- **dev**: Update dependency ty to v0.0.7
  ([`9e1852c`](https://github.com/MountainGod2/cb-events/commit/9e1852c5037e790c4d7a7d97a3c8e18cbb41f097))

- **dev**: Update dev ([#43](https://github.com/MountainGod2/cb-events/pull/43),
  [`67fe4e9`](https://github.com/MountainGod2/cb-events/commit/67fe4e99b23916ea9b03d531bcbdd347bc14205d))

- **docker**: Update base image
  ([`a273350`](https://github.com/MountainGod2/cb-events/commit/a273350f788d5ddf93ed1cf43fe784becce0ca67))

- **docs**: Remove myst-parser
  ([`ca343cc`](https://github.com/MountainGod2/cb-events/commit/ca343cc823a3d2edaf3790dc0f097bfe6cbd640a))

- **docs**: Update dependency sphinx-autodoc-typehints to v3.6.0
  ([#38](https://github.com/MountainGod2/cb-events/pull/38),
  [`f825154`](https://github.com/MountainGod2/cb-events/commit/f825154b0a7dd89af5956be00da7a7bf9b0387ab))

- **examples**: Update dependency cb-events to v5.8.0
  ([`b3d4458`](https://github.com/MountainGod2/cb-events/commit/b3d44588b2efd10970355f6c9a4cc7242ed5bef7))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.52.6
  ([`d945a7d`](https://github.com/MountainGod2/cb-events/commit/d945a7d67e4481885ed285de45211b3c88183ede))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.52.8
  ([`bb257e2`](https://github.com/MountainGod2/cb-events/commit/bb257e2fd3c0b3d507a2a526c4d50755f6533f09))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.54.1
  ([`9947cae`](https://github.com/MountainGod2/cb-events/commit/9947caed0c1ebb6fbab97917a0d13915fc525a8d))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.58.3
  ([`fc0d443`](https://github.com/MountainGod2/cb-events/commit/fc0d4435581ada404d99b988b7d7b51e42527830))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.59.1
  ([`90fcf83`](https://github.com/MountainGod2/cb-events/commit/90fcf837d5702c71971473c1159b3675c9ebcdb1))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.1
  ([`0d40d1a`](https://github.com/MountainGod2/cb-events/commit/0d40d1a204a785db073ff9a59d9da82c42aa7f56))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.2
  ([`44d0101`](https://github.com/MountainGod2/cb-events/commit/44d010139f032328f4bcb34b5b57f8b64f58c391))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.66.4
  ([`88cfeb6`](https://github.com/MountainGod2/cb-events/commit/88cfeb68d80f52e0f23a79d41fa82df7ebaabf09))

- **pre-commit**: Update pre-commit-hooks
  ([`5536426`](https://github.com/MountainGod2/cb-events/commit/5536426119d8d0310966f7bb748b200d9be78300))

- **pre-commit**: Update pre-commit-hooks
  ([`00ab0c1`](https://github.com/MountainGod2/cb-events/commit/00ab0c115d6d7760f1e709567aa47653f4d341cb))

- **pre-commit**: Update pre-commit-hooks ([#39](https://github.com/MountainGod2/cb-events/pull/39),
  [`f31ce47`](https://github.com/MountainGod2/cb-events/commit/f31ce479f09d291fee6573c0a108dad6c7f753f6))

### Code Style

- **example**: Fix formatting of dependency version
  ([`d2fa8a6`](https://github.com/MountainGod2/cb-events/commit/d2fa8a6b6f80d87cb182a1e65c8518d993dbbe04))

### Refactoring

- **factory**: Change config_overrides type to object
  ([`9910083`](https://github.com/MountainGod2/cb-events/commit/99100838223692d92ac2d917191e0c0dc2c54a50))

- **models**: Cast return types for cached properties
  ([`a102e7c`](https://github.com/MountainGod2/cb-events/commit/a102e7c6b7e102ffb6156d89eda8e8d64c298dd8))

- **models**: Cast user extraction to User type
  ([`89efb87`](https://github.com/MountainGod2/cb-events/commit/89efb8775ef392475ea230330f4ac949ac0b86f2))

- **models**: Simplify user extraction logic
  ([`3991ffe`](https://github.com/MountainGod2/cb-events/commit/3991ffe3017998e61911f4eb896a9538acebe2ae))

- **router**: Update handler type
  ([`66e9c60`](https://github.com/MountainGod2/cb-events/commit/66e9c606d663ef5ce5a468c40d1dfa1124150e7f))

- **tests**: Update _FuncAttrWrapper to accept non-awaitable callable
  ([`6bfa8b9`](https://github.com/MountainGod2/cb-events/commit/6bfa8b99902caa65f6a477fee0c96d5ee735a1c8))


## v5.8.0 (2025-12-13)

### Chores

- **ci**: Update github-actions
  ([`689e99b`](https://github.com/MountainGod2/cb-events/commit/689e99be57bb3fe18bae114b581728be13f4ac2a))

- **dev**: Update dependency ty to v0.0.1a34
  ([`3bfa572`](https://github.com/MountainGod2/cb-events/commit/3bfa572469622ad4d92b6230885c3fe228b4e314))

- **dev**: Update dev
  ([`55c93fc`](https://github.com/MountainGod2/cb-events/commit/55c93fc663457679b56ac1dadbe6d9f028797dbc))

- **docker**: Update python:3.14-slim-bookworm docker digest to 404ca55
  ([`eab6054`](https://github.com/MountainGod2/cb-events/commit/eab605449d59edf7830e5742b2dc859467a380d1))

- **examples**: Update dependency cb-events to v5.7.0
  ([`7a6b370`](https://github.com/MountainGod2/cb-events/commit/7a6b37047d606734bb4351c4cc5d8ba58b3e7dee))

### Documentation

- **copilot**: Add instructions for serving documentation
  ([`a963970`](https://github.com/MountainGod2/cb-events/commit/a9639706977c932a28049b8557569508afd5bd78))

- **copilot**: Remove reference to _MISSING sentinel
  ([`db49d39`](https://github.com/MountainGod2/cb-events/commit/db49d3901a084da0c44353e3f522c3091b4044c1))

### Features

- **client**: Add response snippet and host entry sanitization
  ([`a18825b`](https://github.com/MountainGod2/cb-events/commit/a18825b805db10d18a8b1ecf1264e8bb3b101408))

### Refactoring

- **client**: Improve formatting
  ([`94cadd7`](https://github.com/MountainGod2/cb-events/commit/94cadd72202435b0b07949db015eee88e133f7ad))

- **client**: Modify retry logic
  ([`c24fbbb`](https://github.com/MountainGod2/cb-events/commit/c24fbbb648e4528ae7c724971e73f0d0c35ad976))

- **example**: Simplify event handlers
  ([`93d1894`](https://github.com/MountainGod2/cb-events/commit/93d189465768393aee631ea0e737fc6c7c4679b0))


## v5.7.0 (2025-12-09)

### Chores

- Clean up unused code and comments
  ([`43b183c`](https://github.com/MountainGod2/cb-events/commit/43b183cc9194215821d24ff169897a591208945c))

- **ci**: Update astral-sh/setup-uv digest to ed21f2f
  ([`1cefbb2`](https://github.com/MountainGod2/cb-events/commit/1cefbb2985eb865237d4e7e509300c56dc3bb38e))

- **ci**: Update github/codeql-action digest to cf1bb45
  ([`1eec59e`](https://github.com/MountainGod2/cb-events/commit/1eec59edbc9a47802fc49551dcfe49d38f92e337))

- **dependencies**: Update pyrefly to version 0.44.0
  ([`1eee619`](https://github.com/MountainGod2/cb-events/commit/1eee61950fdf33524d427ef11dfd7a0dcc863985))

- **deps**: Update dependency furo to v2025
  ([#37](https://github.com/MountainGod2/cb-events/pull/37),
  [`2a3cf3e`](https://github.com/MountainGod2/cb-events/commit/2a3cf3ed947b0f739477fbeca0ad8d7b674cdaaa))

- **dev**: Update dependency pyrefly to v0.44.0
  ([`6c61293`](https://github.com/MountainGod2/cb-events/commit/6c612937f0968e015065d08250dcd60a997841e7))

- **dev**: Update dependency pyrefly to v0.44.1
  ([`09d44f1`](https://github.com/MountainGod2/cb-events/commit/09d44f109c885a6c58a727ccd33beb86cab56681))

- **dev**: Update dependency pyrefly to v0.45.0
  ([`ad41369`](https://github.com/MountainGod2/cb-events/commit/ad4136925f9740b47cd80439cbfc5a237fba49f7))

- **dev**: Update dependency pytest to v9.0.2
  ([`389ba9c`](https://github.com/MountainGod2/cb-events/commit/389ba9c643d777dc727880d1e11a8ca3ce39838d))

- **dev**: Update dependency ruff to v0.14.8
  ([`a513786`](https://github.com/MountainGod2/cb-events/commit/a513786cf89f10ded2b7e0a0bace3e22f82d0b83))

- **dev**: Update dependency ty to v0.0.1a30
  ([`d6f7c90`](https://github.com/MountainGod2/cb-events/commit/d6f7c90551029c663ae9c9ac75eb115bb391d955))

- **dev**: Update dependency ty to v0.0.1a31
  ([`f02e2c2`](https://github.com/MountainGod2/cb-events/commit/f02e2c2efbc2316d4e42b03aebe79aa4debda911))

- **dev**: Update dependency ty to v0.0.1a31
  ([`8e3ccf4`](https://github.com/MountainGod2/cb-events/commit/8e3ccf45edac33887f613f4948d4a22f90ae4857))

- **dev**: Update dev
  ([`96f9e95`](https://github.com/MountainGod2/cb-events/commit/96f9e95b7b7cfd2072b66850090eb5e40ba1bc5c))

- **docker**: Update python:3.14-slim-bookworm docker digest to 5d17fc0
  ([`0c8f5b5`](https://github.com/MountainGod2/cb-events/commit/0c8f5b5eb922a9a8b6e6886614e5954a4834431a))

- **Dockerfile**: Update uv dependency to v0.9.16
  ([`fdf3486`](https://github.com/MountainGod2/cb-events/commit/fdf34868b581c995f18fb57a1a3105cf30e4b707))

- **examples**: Update dependency cb-events to v5.6.5
  ([`ed48848`](https://github.com/MountainGod2/cb-events/commit/ed48848df57013c73027b62fa8300d763c61fd39))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.34.0
  ([`968f21d`](https://github.com/MountainGod2/cb-events/commit/968f21d01f81e78b859ab35b876647275cec8206))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.38.0
  ([`87d6fc5`](https://github.com/MountainGod2/cb-events/commit/87d6fc5c0cf125b9fcb6ee7bbf57b5e61a9b3068))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.38.1
  ([`d20d246`](https://github.com/MountainGod2/cb-events/commit/d20d2466c263d64c20aadc9e6deb6d5e65dc744a))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.39.0
  ([`e9c9f67`](https://github.com/MountainGod2/cb-events/commit/e9c9f67710e016815ccd41c0412ecb9146ab0dc1))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.39.1
  ([`7fe5fe6`](https://github.com/MountainGod2/cb-events/commit/7fe5fe653f3e094b50656ef08f623585506a9f7d))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.39.2
  ([`370bb11`](https://github.com/MountainGod2/cb-events/commit/370bb1168594ff422012833553244ca9cf71e037))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.39.4
  ([`7b0c9a6`](https://github.com/MountainGod2/cb-events/commit/7b0c9a6d87a824b5a3182f292ccb5402d4b91c64))

- **pre-commit**: Update pre-commit-hooks
  ([`1a9d5b4`](https://github.com/MountainGod2/cb-events/commit/1a9d5b4bca952c54fae3b689c6f908b09ee5e968))

### Documentation

- Improve documentation for async client usage
  ([`1b1e5b3`](https://github.com/MountainGod2/cb-events/commit/1b1e5b37f9b1f839203c6247586542bbbd4b4c3d))

- **client**: Refactor module docstring and examples
  ([`65e581f`](https://github.com/MountainGod2/cb-events/commit/65e581f7f586bc498480ae63d49fec243cb79046))

- **config**: Refactor module docstring and examples
  ([`7b23474`](https://github.com/MountainGod2/cb-events/commit/7b23474d8ead58b95f4bd9c1c753156276cd0cea))

- **exceptions**: Refactor module docstring and examples
  ([`bf053ba`](https://github.com/MountainGod2/cb-events/commit/bf053ba60b0046af46dc9296af38de80d7675b9e))

- **models**: Refactor module docstring and examples
  ([`79bf77c`](https://github.com/MountainGod2/cb-events/commit/79bf77c8aa82dfd392c37d94b1f49c2580af9afb))

- **router**: Refactor module docstring and examples
  ([`131b8c6`](https://github.com/MountainGod2/cb-events/commit/131b8c638b426dfca00a3a80753f13c625e0730e))

### Features

- **client**: Enhance nextUrl validation and add jitter to retry delay
  ([`122e289`](https://github.com/MountainGod2/cb-events/commit/122e28913f4ca67c96b7da6678195ba035c57b44))

### Testing

- **client**: Add validation for nextUrl scheme and host
  ([`50f6b83`](https://github.com/MountainGod2/cb-events/commit/50f6b83858d08a77136590e1f60ec74611549845))


## v5.6.5 (2025-12-03)

### Bug Fixes

- **router**: Handle asyncio.CancelledError separately
  ([`8fb30bd`](https://github.com/MountainGod2/cb-events/commit/8fb30bd7a0ebd3f61b043d75107bd45252cae499))

### Chores

- **ci**: Update actions/checkout digest to 8e8c483
  ([`6173f40`](https://github.com/MountainGod2/cb-events/commit/6173f4089c1a995867c19d966507618eac6bd7db))

- **ci**: Update github/codeql-action digest to fe4161a
  ([`0c3d36f`](https://github.com/MountainGod2/cb-events/commit/0c3d36fe0a079bea67eca25257aed0e6714521e1))

- **examples**: Update dependency cb-events to v5.6.4
  ([`8c472f1`](https://github.com/MountainGod2/cb-events/commit/8c472f1169f9982c876b74a9d68c36b8cccce622))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.29.4
  ([`39dba04`](https://github.com/MountainGod2/cb-events/commit/39dba049d3e98c6a462a05e5ecc37d5cfa70f829))

### Refactoring

- **client**: Improve type casting in validation error logging
  ([`320f603`](https://github.com/MountainGod2/cb-events/commit/320f60352154b86413d8b110b54b02c61cd135a3))

- **client**: Simplify validation error logging
  ([`4b01b7e`](https://github.com/MountainGod2/cb-events/commit/4b01b7eb5c2e35423e6a1d090afa2db418772590))

- **examples**: Improve type hints and docstrings
  ([`fa734cd`](https://github.com/MountainGod2/cb-events/commit/fa734cdaf9849ca743040d3af2b02f30465a3dc8))

- **router**: Remove handling of asyncio.CancelledError in dispatch
  ([`debfffb`](https://github.com/MountainGod2/cb-events/commit/debfffb7f0d307c44c68ea4c1c554c221301854e))

- **tests**: Simplify event handling in tests
  ([`7bd97e7`](https://github.com/MountainGod2/cb-events/commit/7bd97e70c6789bb7576d2d170ff4a42231308708))


## v5.6.4 (2025-11-30)

### Bug Fixes

- **runtime**: Update dependency pydantic to v2.12.5
  ([#35](https://github.com/MountainGod2/cb-events/pull/35),
  [`fec4603`](https://github.com/MountainGod2/cb-events/commit/fec4603cc69d8d9f819c43a7f8fa12c5d38d40f8))

### Chores

- **deps**: Update dependency pre-commit to v4.5.0
  ([#34](https://github.com/MountainGod2/cb-events/pull/34),
  [`f6e72c5`](https://github.com/MountainGod2/cb-events/commit/f6e72c51134255cc30461320877352cbd4de69b5))

- **dev**: Update dependency pylint to v4.0.4
  ([`b32d33a`](https://github.com/MountainGod2/cb-events/commit/b32d33add4f8d3216c4d75dd0aa2d41104e51ce9))

- **examples**: Update dependency cb-events to v5.6.3
  ([`a0ee441`](https://github.com/MountainGod2/cb-events/commit/a0ee441b81af346142012ccc07cfae13412db47b))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.27.0
  ([`7c5cfb2`](https://github.com/MountainGod2/cb-events/commit/7c5cfb285c837b3614e56a2a77dd11ccdbaddbc1))


## v5.6.3 (2025-11-29)

### Bug Fixes

- **client**: Prevent redirects in session requests
  ([`80f7305`](https://github.com/MountainGod2/cb-events/commit/80f730521efa1e5d06187d938fd2738e395843dc))

### Chores

- **build**: Update dependency hatchling to v1.28.0
  ([`343663c`](https://github.com/MountainGod2/cb-events/commit/343663c346fb5830320112a25430d1f56e4d5ea4))

- **ci**: Update github-actions
  ([`b912c77`](https://github.com/MountainGod2/cb-events/commit/b912c77ef620584bd9594f6e3a346a58923231a2))

- **deps**: Pin python docker tag to d13fa04
  ([#33](https://github.com/MountainGod2/cb-events/pull/33),
  [`26fd239`](https://github.com/MountainGod2/cb-events/commit/26fd239cffb2587430c446f4e43c6d556538eaef))

- **dev**: Update dependency bandit to v1.9.2
  ([`9f5952e`](https://github.com/MountainGod2/cb-events/commit/9f5952eba230257905652ffae2c5dba654603ae6))

- **dev**: Update dependency pyrefly to v0.43.1
  ([`b38a590`](https://github.com/MountainGod2/cb-events/commit/b38a590d23114b8e464c55937b41b335a1cab786))

- **dev**: Update dependency ty to v0.0.1a28
  ([`fc91bdc`](https://github.com/MountainGod2/cb-events/commit/fc91bdc4d3b613834b7eff85f7cc0cb6e682fc38))

- **dev**: Update dev
  ([`163f645`](https://github.com/MountainGod2/cb-events/commit/163f64545a6a7a9cb0e1ee5dccdb75a74479e6bc))

- **dev**: Update dev
  ([`5a79a53`](https://github.com/MountainGod2/cb-events/commit/5a79a5379d855d9b1b0f9494c94636d2bd11cadb))

- **examples**: Update dependency cb-events to v5.6.2
  ([`a955d46`](https://github.com/MountainGod2/cb-events/commit/a955d46df395e5ca31bfc03c6c5fdc1004921981))

- **pre-commit**: Update pre-commit hook pycqa/bandit to v1.9.2
  ([`19970e3`](https://github.com/MountainGod2/cb-events/commit/19970e34a38b352c19915f76675b6d390454cf16))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.19.7
  ([`b1dc52e`](https://github.com/MountainGod2/cb-events/commit/b1dc52ed50cdf3ac462d2ecaa04e842810b9de73))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.20.1
  ([`6af8d9a`](https://github.com/MountainGod2/cb-events/commit/6af8d9a3bbec857a751d6629ea5951489e07fb16))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.21.1
  ([`0262924`](https://github.com/MountainGod2/cb-events/commit/026292407389e7ef3a27cf08e658a628f4add0dc))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.21.3
  ([`a6ba2f5`](https://github.com/MountainGod2/cb-events/commit/a6ba2f556ca80a15c88d772b17f36a9e07385c45))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.24.0
  ([`a8d11d1`](https://github.com/MountainGod2/cb-events/commit/a8d11d165937218577e19238ddac8fe189d14e2d))

- **pre-commit**: Update pre-commit-hooks
  ([`ab2b8ee`](https://github.com/MountainGod2/cb-events/commit/ab2b8ee01c9b621725cec1ae949ae28208316a27))

- **pre-commit**: Update pre-commit-hooks
  ([`77469ca`](https://github.com/MountainGod2/cb-events/commit/77469ca5b6dd57b6f44c1e9f13f09bf45d251745))

- **pre-commit**: Update pre-commit-hooks
  ([`b345c4e`](https://github.com/MountainGod2/cb-events/commit/b345c4e5da86abf22709ccc46d88ae7f9a3cda5c))

### Documentation

- **copilot**: Update instructions
  ([`55ef71b`](https://github.com/MountainGod2/cb-events/commit/55ef71b4e741ed9c61a2c6555b906b4af3b44c16))

### Refactoring

- **client**: Clean up comments and organization
  ([`398dadf`](https://github.com/MountainGod2/cb-events/commit/398dadf6e9fff16e25c1b006f2a431d8c6b117cb))

- **client**: Remove unused sentinel for API keys
  ([`b9126f6`](https://github.com/MountainGod2/cb-events/commit/b9126f6fc3ba84f9fe4c7a18a508b7fe8fa57456))

- **example**: Remove redundant return type annotations
  ([`87202bf`](https://github.com/MountainGod2/cb-events/commit/87202bf73ade7930e1e33ae78aa27479e8658a0f))

- **example**: Use environment variable for testbed config
  ([`832894b`](https://github.com/MountainGod2/cb-events/commit/832894b13eb2d7fe8f82630711d8c117f178e840))


## v5.6.2 (2025-11-22)

### Bug Fixes

- **deps**: Add examples group for python-dotenv and rich
  ([`07a4bfe`](https://github.com/MountainGod2/cb-events/commit/07a4bfebbd389956bc8cdcbe41deddd3014ff15c))

- **Dockerfile**: Update Python base image to 3.14
  ([`f36f456`](https://github.com/MountainGod2/cb-events/commit/f36f45655066d00a34e627e3825ea1a1c4b4308e))

- **Dockerfile**: Update uv dependency to version 0.9.11
  ([`14cfa07`](https://github.com/MountainGod2/cb-events/commit/14cfa079d8666e6cc6528679ba556f7652e6de44))

### Chores

- **deps**: Lock file maintenance
  ([`8e79db8`](https://github.com/MountainGod2/cb-events/commit/8e79db81b43e34678335282a85868c42f2ae5955))

- **deps**: Update dependency cb-events to v5.6.1
  ([`41a9b29`](https://github.com/MountainGod2/cb-events/commit/41a9b299586b89057a904e94cf6c74e592aeef4b))

- **dev**: Update dependency pyrefly to v0.41.1
  ([`e41c6b4`](https://github.com/MountainGod2/cb-events/commit/e41c6b49a55db4ddab7f4b8048124b83b2eb2e6e))

- **dev**: Update dependency pyrefly to v0.41.2
  ([`c3e2b82`](https://github.com/MountainGod2/cb-events/commit/c3e2b82683509830bba0bce939f72e2e3a13a884))

- **dev**: Update dependency pyrefly to v0.42.0
  ([`2335997`](https://github.com/MountainGod2/cb-events/commit/233599770ce0702cc022e86eb068a23441bd41fc))

- **dev**: Update dependency pytest to v9.0.1
  ([`c8af5ad`](https://github.com/MountainGod2/cb-events/commit/c8af5ad6a8abf8303be0a44cd7a2748667bd0c29))

- **dev**: Update dev
  ([`6175256`](https://github.com/MountainGod2/cb-events/commit/617525670ca73daa5d058307ac5b0777f3ecbd4f))

- **docs**: Remove autodoc-pydantic dependency
  ([`fc46038`](https://github.com/MountainGod2/cb-events/commit/fc46038044e807c3567b17ab24d24ba1a4416c6a))

- **models**: Add Media to exported items
  ([`6b91572`](https://github.com/MountainGod2/cb-events/commit/6b915729d895dd028db60f06e9127846873ad9c6))

- **pre-commit**: Update pre-commit-hooks
  ([`53ccab8`](https://github.com/MountainGod2/cb-events/commit/53ccab868d8a6043d4a967d9ed10aef4fe1a2a06))

- **pre-commit**: Update pre-commit-hooks
  ([`8e448a0`](https://github.com/MountainGod2/cb-events/commit/8e448a0c91145ce025178574071a9372e17fa337))

- **pre-commit**: Update pre-commit-hooks
  ([`07b81f9`](https://github.com/MountainGod2/cb-events/commit/07b81f9cb011773334e480e569722965ab8257b3))

- **renovate**: Add Dockerfile manager and rules
  ([`5600327`](https://github.com/MountainGod2/cb-events/commit/5600327ba88cf91684ed468ef00def24bc45e97e))

- **renovate**: Add ignorePaths to configuration
  ([`61d5fdc`](https://github.com/MountainGod2/cb-events/commit/61d5fdca48c295bf1abfa18b69c771cd516df103))

- **renovate**: Simplify managerFilePatterns regex
  ([`9096420`](https://github.com/MountainGod2/cb-events/commit/90964204f4c20dbc11e78187ea87a236d9a45091))

- **renovate**: Update configuration for dependency management
  ([`1d1951d`](https://github.com/MountainGod2/cb-events/commit/1d1951daf6f1722941ca25500ca3d9b037c2b5df))

### Documentation

- **client**: Add type hints for constants and variables
  ([`60285ec`](https://github.com/MountainGod2/cb-events/commit/60285ec87dc552ff350b80a2c86efcf0a1f5ff2a))

- **client**: Update docstrings
  ([`bc1296b`](https://github.com/MountainGod2/cb-events/commit/bc1296bf3727a62e24ccb8edf69d999c527c9556))

- **conf**: Update AutoAPI configuration and remove unused extension
  ([`a7ac8bb`](https://github.com/MountainGod2/cb-events/commit/a7ac8bb7f4562b2cf1064fd78a3bec0dbfbd32b3))

- **config**: Update class docstring for clarity
  ([`cb3d3da`](https://github.com/MountainGod2/cb-events/commit/cb3d3da4d61245c0fb642d7d5f94a21c7e7778d4))

- **config**: Update docstring for delay validation
  ([`4098dac`](https://github.com/MountainGod2/cb-events/commit/4098dac5b1ef80763216c692e5100c4de1e64348))

- **Event**: Update docstring for extract_and_validate method
  ([`51c2e42`](https://github.com/MountainGod2/cb-events/commit/51c2e426defeff7333bc47011ba87cb7082b5194))

- **exceptions**: Update docstring for EventsError class
  ([`7bc3ec6`](https://github.com/MountainGod2/cb-events/commit/7bc3ec6a21f6dc2f35b655aec6ded55c9474d468))

- **exceptions**: Update docstrings
  ([`33da795`](https://github.com/MountainGod2/cb-events/commit/33da795499ae02091b601ba930c35058c6f76fd1))

- **index**: Update API reference link to correct path
  ([`dcc18ec`](https://github.com/MountainGod2/cb-events/commit/dcc18ec7e47e7c5edf2fed984950162a24b78ca2))

- **router**: Add docstring for HandlerFunc type
  ([`e27b5b5`](https://github.com/MountainGod2/cb-events/commit/e27b5b55d0989a28658095c356d0155506ce8933))

- **router**: Update docstrings
  ([`0269bdb`](https://github.com/MountainGod2/cb-events/commit/0269bdbc2e953e29d464b61f5a3380f2f2bd97b6))

### Refactoring

- **client**: Improve type annotations
  ([`18ab44f`](https://github.com/MountainGod2/cb-events/commit/18ab44f415739dc4209dcb10870daca389f7b002))

- **client**: Improve URL handling in EventClient
  ([`ca84207`](https://github.com/MountainGod2/cb-events/commit/ca84207863b10912a0f05bb7bb29196c444fa7ed))

- **example**: Replace print statements with logging
  ([`e1a2055`](https://github.com/MountainGod2/cb-events/commit/e1a205558290986e42dbff916748bbd2366498c2))

### Testing

- **client**: Add test for resolving relative nextUrl
  ([`2de272a`](https://github.com/MountainGod2/cb-events/commit/2de272a202175355952f963c2a49368de01af4cd))


## v5.6.1 (2025-11-16)

### Bug Fixes

- **tests**: Update coverage options to include src and omit tests
  ([`d370837`](https://github.com/MountainGod2/cb-events/commit/d370837f990988d29118b52fc574ab5af80419fd))

### Refactoring

- **init**: Add pragma comment for PackageNotFoundError
  ([`a7a7672`](https://github.com/MountainGod2/cb-events/commit/a7a7672892a86cf1c2d8505756f0d5c78f0dc2c7))

- **tests**: Remove unused pytestmark import
  ([`e25409c`](https://github.com/MountainGod2/cb-events/commit/e25409c0337ba80aeb11fe3326deeef7ac4ac6b6))

### Testing

- **client**: Add tests for retry/backoff behavior
  ([`c52f6cc`](https://github.com/MountainGod2/cb-events/commit/c52f6ccaee69063b6835d829d47dadebeafe74aa))

- **client**: Add unit tests for client helper functions
  ([`efc56a4`](https://github.com/MountainGod2/cb-events/commit/efc56a441903f510f587f24f4e98e301357dea56))

- **concurrency**: Parameterize event methods in tests
  ([`c74aad3`](https://github.com/MountainGod2/cb-events/commit/c74aad3fbac41fb08af484ea6319a73c7ae56f97))

- **conftest**: Rename mock_response to aioresponses_mock
  ([`98c4fd3`](https://github.com/MountainGod2/cb-events/commit/98c4fd37c9431c5e0a452371e209ffda02602243))

- **integration**: Update tests for event handling and mocks
  ([`6604ff5`](https://github.com/MountainGod2/cb-events/commit/6604ff5069ba65854fe3b2451269a1a9673d8fea))

- **models**: Enhance event type mapping and add media tests
  ([`e1750ef`](https://github.com/MountainGod2/cb-events/commit/e1750ef11214fb65035791b38672f536c3eb13d9))

- **polling**: Parameterize event methods in tests
  ([`26b43d5`](https://github.com/MountainGod2/cb-events/commit/26b43d581ff97278ed93d1b3cb03576bb7deac16))

- **router**: Parameterize event methods in dispatch tests
  ([`24ad8a7`](https://github.com/MountainGod2/cb-events/commit/24ad8a7a4410259c26e59a9e3173e8350986d1e3))


## v5.6.0 (2025-11-15)

### Documentation

- **readme**: Fix installation command
  ([`aee4b0e`](https://github.com/MountainGod2/cb-events/commit/aee4b0e6c38a0ad32b9d931c9c09850f66fb0494))

### Features

- **config**: Add next_url_allowed_hosts to ClientConfig
  ([`acf3f4c`](https://github.com/MountainGod2/cb-events/commit/acf3f4ce213c971b5f89a14957b9e4ee56b14ad9))

### Refactoring

- **config**: Fix indentation in docstring for retry_attempts
  ([`2ec081b`](https://github.com/MountainGod2/cb-events/commit/2ec081ba9ee411d4211266d401d2887bb45a4f24))

### Testing

- **event**: Add tests for message and room subject parsing
  ([`34a98fa`](https://github.com/MountainGod2/cb-events/commit/34a98faf96ee5d2d6249934dd028e52243d1b5ba))


## v5.5.1 (2025-11-15)

### Bug Fixes

- **test**: Disable coverage for end-to-end tests
  ([`d760ef6`](https://github.com/MountainGod2/cb-events/commit/d760ef6c835d54e085f7372d5ebdbdf678e1477c))

### Chores

- **build**: Update dependency python-semantic-release to v10.5.0
  ([`9be728e`](https://github.com/MountainGod2/cb-events/commit/9be728eaaca09a4ab64096afe49c8de4a7d46b7b))

- **build**: Update dependency python-semantic-release to v10.5.1
  ([`4d0140c`](https://github.com/MountainGod2/cb-events/commit/4d0140ccdcfb9952049db8d82db636247f39e244))

- **build**: Update dependency python-semantic-release to v10.5.2
  ([`c5c408f`](https://github.com/MountainGod2/cb-events/commit/c5c408f2ad222f7047c1ff8663caaf8f1f489930))

- **ci**: Update github/codeql-action digest to 014f16e
  ([`ee7ed53`](https://github.com/MountainGod2/cb-events/commit/ee7ed539c47ab52a3acbbed2939804558a14aeaf))

- **config**: Update pytest configuration and add pyright
  ([`730f48c`](https://github.com/MountainGod2/cb-events/commit/730f48c2bd2f660f275b870adfffde3cb269826c))

- **deps**: Update dependency pytest to v9
  ([#32](https://github.com/MountainGod2/cb-events/pull/32),
  [`763184a`](https://github.com/MountainGod2/cb-events/commit/763184a4b06042d5370e2fcb16681e882c49b316))

- **dev**: Update dependency pre-commit to v4.4.0
  ([`398e218`](https://github.com/MountainGod2/cb-events/commit/398e218a71cc4dd4f9ca7d607c7221fcf4c09bfa))

- **dev**: Update dependency pyrefly to v0.41.0
  ([`bffd93c`](https://github.com/MountainGod2/cb-events/commit/bffd93ca3d9be63ba516d753422ab1cc6ee52564))

- **dev**: Update dev
  ([`34230b6`](https://github.com/MountainGod2/cb-events/commit/34230b6555fd4449d6a6ec9c858c78433821dc0c))

- **example**: Update dependencies in example script
  ([`e7401e6`](https://github.com/MountainGod2/cb-events/commit/e7401e6ec641e4dbc2b798022cbfdb5191db6253))

- **pre-commit**: Update pre-commit hook asottile/pyupgrade to v3.21.1
  ([`383a082`](https://github.com/MountainGod2/cb-events/commit/383a082abea8bb6d0503079b3f9a9a0f28bb35e7))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.2.0
  ([`22a5be7`](https://github.com/MountainGod2/cb-events/commit/22a5be7d07c25354344cfaa46223bda7442a6530))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.5.0
  ([`b42cd46`](https://github.com/MountainGod2/cb-events/commit/b42cd465a656e7c745fd99b737e45c4948e1d3c5))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.5.4
  ([`067185b`](https://github.com/MountainGod2/cb-events/commit/067185b33ac23e2eea3618f5eec088b85a8b15e3))

### Continuous Integration

- Add dependency-sync job
  ([`ffe2d52`](https://github.com/MountainGod2/cb-events/commit/ffe2d5257189b80845598431293d22233269b5cf))


## v5.5.0 (2025-11-13)

### Chores

- **deps**: Lock file maintenance
  ([`0db67b8`](https://github.com/MountainGod2/cb-events/commit/0db67b895502d30628f299ad16211838333e1716))

### Features

- **models**: Improve media purchase event handling
  ([`dc5b44b`](https://github.com/MountainGod2/cb-events/commit/dc5b44ba6655ebd90a7444fe09766b458a3a027e))

### Refactoring

- **client**: Improve type handling and logging messages
  ([`6088c22`](https://github.com/MountainGod2/cb-events/commit/6088c228c67b5021aa0bae89b92c3331ce0766b4))

- **config**: Specify model_config type annotation
  ([`ee59f20`](https://github.com/MountainGod2/cb-events/commit/ee59f203e182d90c2301a81878018c9d97cb2880))

- **exceptions**: Enhance type annotations and override usage
  ([`ef4d606`](https://github.com/MountainGod2/cb-events/commit/ef4d606c106b740394128b700ea0f7de8544e745))

- **router**: Simplify async callable checks
  ([`af35cdc`](https://github.com/MountainGod2/cb-events/commit/af35cdc68c58747f7a55317b02d7d09fd02370c3))


## v5.4.0 (2025-11-12)

### Chores

- **ci**: Update github-actions
  ([`6a407ff`](https://github.com/MountainGod2/cb-events/commit/6a407fff162ee96a3bbdaf9e9fd769475346a44a))

- **ci**: Update github/codeql-action action to v4
  ([#31](https://github.com/MountainGod2/cb-events/pull/31),
  [`8286ecf`](https://github.com/MountainGod2/cb-events/commit/8286ecf2e71188963e948982c21a636453b2587a))

- **ci**: Update pypa/gh-action-pypi-publish digest to 987f11e
  ([`2ceb20c`](https://github.com/MountainGod2/cb-events/commit/2ceb20c138ea96713b63e4c5b714461486d2908b))

- **ci**: Update pypa/gh-action-pypi-publish version
  ([`4ef5464`](https://github.com/MountainGod2/cb-events/commit/4ef5464d4c0f1c622d4d34c25d237d9303d3f9c7))

- **deps**: Lock file maintenance
  ([`3e54e18`](https://github.com/MountainGod2/cb-events/commit/3e54e18207d65a3e3783baf1a92da1f75d9aaebf))

- **dev**: Update dependency pyrefly to v0.40.1
  ([`ac5c346`](https://github.com/MountainGod2/cb-events/commit/ac5c346d0ce5b91742df330481ea625d3ee79d31))

- **dev**: Update dependency ruff to v0.14.4
  ([`f49445a`](https://github.com/MountainGod2/cb-events/commit/f49445a31c1e0b8762baed848343b6560b6ade56))

- **example**: Add script metadata and load dotenv
  ([`dcb4e92`](https://github.com/MountainGod2/cb-events/commit/dcb4e925a03eda2906eb63ac4b5415cb98638621))

- **pre-commit**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.14.4
  ([`8d8c494`](https://github.com/MountainGod2/cb-events/commit/8d8c494e69198fb4a632adf73e8268276166f021))

- **pre-commit**: Update pre-commit hook renovatebot/pre-commit-hooks to v42.1.3
  ([`b038bed`](https://github.com/MountainGod2/cb-events/commit/b038bed018f699f92db151a83f3ac6dbe03e56d5))

### Continuous Integration

- Update action versions in CI/CD workflow
  ([`887cecc`](https://github.com/MountainGod2/cb-events/commit/887cecc8bbe8260b5cec0840bea0dc25104dee64))

- Update command to fail if formatting is required
  ([`a726252`](https://github.com/MountainGod2/cb-events/commit/a726252449616f38e7297e22422943dc75c9497c))

- Update trivy-action version to v0
  ([`ec0f167`](https://github.com/MountainGod2/cb-events/commit/ec0f16711613f75536559d47ad3495c8e845061f))

### Features

- **tests**: Add live testbed polling test with env credentials
  ([`e66a7ba`](https://github.com/MountainGod2/cb-events/commit/e66a7ba713bb448916f66df6bb65ae3b2aab56f4))


## v5.3.0 (2025-11-10)

### Chores

- **deps**: Update astral-sh/setup-uv digest to 5a7eac6
  ([`35f45bb`](https://github.com/MountainGod2/cb-events/commit/35f45bb88ca418df9c9d88f714e0007e92e6a7f1))

- **deps**: Update github/codeql-action digest to 04bd5c6
  ([`0f31ab3`](https://github.com/MountainGod2/cb-events/commit/0f31ab3ecc8fa74f1a55ea1904abb720ff68d8b5))

- **deps**: Update pypa/gh-action-pypi-publish digest to 987f11e
  ([`599e126`](https://github.com/MountainGod2/cb-events/commit/599e1263a71fbb2fde8efcc3f50e110588918633))

- **renovate**: Update schedule and package names
  ([`a095400`](https://github.com/MountainGod2/cb-events/commit/a0954005c4d786d1c4dc781976be8cb5114b37a7))

### Features

- **ci**: Add grouping for GitHub Actions workflows
  ([`37646d6`](https://github.com/MountainGod2/cb-events/commit/37646d621a439484ef9e5c898ded7ff7def6c72b))

### Refactoring

- **pre-commit**: Remove doc8 rst check hook
  ([`4f2780b`](https://github.com/MountainGod2/cb-events/commit/4f2780b71ffcdfb3b2634a8e63859c8d4467512f))

- **renovate**: Adjust package rules with labels and scopes
  ([`51f690d`](https://github.com/MountainGod2/cb-events/commit/51f690db4593bf61e342d4299ffb682b3405c7ec))

- **renovate**: Remove python-semantic-release from dev group
  ([`5ad39ef`](https://github.com/MountainGod2/cb-events/commit/5ad39ef0579b691b331dbf3d750d136f7394ac7e))


## v5.2.2 (2025-11-10)

### Bug Fixes

- **renovate**: Update package name matching patterns
  ([`a4735c5`](https://github.com/MountainGod2/cb-events/commit/a4735c5dc9fb6537646df25eb7c91486d04c3df6))

### Chores

- **deps**: Lock file maintenance
  ([`de9caa2`](https://github.com/MountainGod2/cb-events/commit/de9caa2e6b8879254de7adee1d028496f369620a))

### Documentation

- **models**: Enhance docstrings
  ([`03b155c`](https://github.com/MountainGod2/cb-events/commit/03b155c3075a632a7c13052da0bc4e1e02163742))

### Refactoring

- **client**: Improve logging for event processing and authentication
  ([`835e121`](https://github.com/MountainGod2/cb-events/commit/835e121cd351ba54318ca0a9292f335cd6fa2fa3))

- **config**: Improve error message for retry settings
  ([`c64dbfc`](https://github.com/MountainGod2/cb-events/commit/c64dbfccd0079d3117de2521f142394a48166a73))

- **router**: Enhance logging for event dispatching
  ([`dcb13e2`](https://github.com/MountainGod2/cb-events/commit/dcb13e25d329ad492faed0b66d4e49073839b6ca))


## v5.2.1 (2025-11-09)

### Bug Fixes

- **deps**: Update dependency pydantic to v2.12.4
  ([`64c7750`](https://github.com/MountainGod2/cb-events/commit/64c7750173cf5612630aca788cf79980e44cca5d))


## v5.2.0 (2025-11-08)

### Bug Fixes

- **config**: Enforce minimum value for retry_attempts
  ([`4711e7f`](https://github.com/MountainGod2/cb-events/commit/4711e7f2e88191e41cbe1bdfdceed74c4a6302a0))

### Chores

- **client**: Add logger documentation comment
  ([`f976188`](https://github.com/MountainGod2/cb-events/commit/f9761883174e03ed5eec1f29bcf5cdfffdc67969))

- **deps**: Add autodoc-pydantic package
  ([`c265839`](https://github.com/MountainGod2/cb-events/commit/c2658393d250a23ecb3ab70ff2a66350fb483876))

- **deps**: Update astral-sh/setup-uv digest to b49dc9e
  ([`8c37276`](https://github.com/MountainGod2/cb-events/commit/8c3727632163fa91d9baf89060e3cecd76000761))

- **deps**: Update github/codeql-action digest to 71d0a56
  ([`bd68e54`](https://github.com/MountainGod2/cb-events/commit/bd68e542cba3181e9b540fcbf4481dd8c975f0c4))

- **docs**: Remove unused autoapi template files
  ([`5120b1c`](https://github.com/MountainGod2/cb-events/commit/5120b1c98f8bdb2886b68f31d391917d6ef4e449))

- **pre-commit**: Add renovate config validator hook
  ([`087e998`](https://github.com/MountainGod2/cb-events/commit/087e9985ae2a9e2b9b66b919422cd056a9221020))

- **router**: Add logger documentation comment
  ([`7d68187`](https://github.com/MountainGod2/cb-events/commit/7d6818738707ee51f78ca0910ddd628faa866bcc))

### Documentation

- **models**: Enhance documentation for event models
  ([`276b81b`](https://github.com/MountainGod2/cb-events/commit/276b81b6f085723c44580e1bcbc9256e35605212))

### Features

- **client**: Add validation for nextUrl in API responses
  ([`1b7e9cb`](https://github.com/MountainGod2/cb-events/commit/1b7e9cb61b4e136be0533b18d67e119418388098))

### Refactoring

- **docs**: Improve Sphinx configuration and imports
  ([`890a318`](https://github.com/MountainGod2/cb-events/commit/890a3185b045cf118830703fa11827f5ae518e8a))

### Testing

- **configuration**: Update retry attempts test
  ([`b5afb08`](https://github.com/MountainGod2/cb-events/commit/b5afb088c3b7c6387986a09b33de4b5cd2598aa9))

- **polling**: Add tests for handling invalid nextUrl values
  ([`7ec7d5e`](https://github.com/MountainGod2/cb-events/commit/7ec7d5eb3f3a67b6d6ee6c7291b6a59ce641b8ac))


## v5.1.1 (2025-11-06)

### Bug Fixes

- **client**: Handle event ID extraction for non-mapping items
  ([`96f3945`](https://github.com/MountainGod2/cb-events/commit/96f39455b8fe0459cf40f7027d33f9b88ac28301))

### Chores

- **deps**: Replace mypy with pyrefly for type checks
  ([`647ee2b`](https://github.com/MountainGod2/cb-events/commit/647ee2b6920189b35abf761ebd2926178638f6b6))

- **deps**: Update github/codeql-action digest to 320a6b6
  ([`a623144`](https://github.com/MountainGod2/cb-events/commit/a623144c09fbc9c4c772287cfe0cadf49cce2777))

- **deps**: Update pre-commit-hooks
  ([`1dda5b6`](https://github.com/MountainGod2/cb-events/commit/1dda5b6e32f5a3a200615bf6078c0c564b584b78))

- **Makefile**: Add ty check to type-check target
  ([`91e40d4`](https://github.com/MountainGod2/cb-events/commit/91e40d414aae195800b97925ba5f4d982b804483))

- **pre-commit**: Remove mypy hook and add pyrefly type check
  ([`8b793bd`](https://github.com/MountainGod2/cb-events/commit/8b793bdaf01a8f7b28bc3ac2bfc0cc70f3fd2625))

### Refactoring

- **client**: Improve JSON response handling and validation
  ([`b8cc680`](https://github.com/MountainGod2/cb-events/commit/b8cc68099ef61be7ba414f9b8a9b35849353280e))

- **client**: Remove redundant error handling comments
  ([`6e404a1`](https://github.com/MountainGod2/cb-events/commit/6e404a1ffc36f264607fe1ae8edf55c09886f665))

- **router**: Improve async handler error message
  ([`d11e77f`](https://github.com/MountainGod2/cb-events/commit/d11e77f21bd2f921a9696fbbabf147d33ad94d32))

- **router**: Improve handler name retrieval logic
  ([`d7b13e3`](https://github.com/MountainGod2/cb-events/commit/d7b13e3c864232c6d8109d8c9f7206c445a0b240))

### Testing

- **client**: Add strict and lenient validation tests
  ([`a81a88e`](https://github.com/MountainGod2/cb-events/commit/a81a88e6e4cf713ab109fac1baf5f52413a7e410))

- **client**: Add tests for timeout and non-list event payloads
  ([`b404e2a`](https://github.com/MountainGod2/cb-events/commit/b404e2acc6d116ab24dc4417a21c6e2113154d88))

- **router**: Ignore type check for partial sync handler
  ([`867a551`](https://github.com/MountainGod2/cb-events/commit/867a551153083b3ce411887622076034543391f8))

- **router**: Reject partial sync handlers in decorator
  ([`01c05b1`](https://github.com/MountainGod2/cb-events/commit/01c05b15f176f6af85ef97201ad99040c05ca798))


## v5.1.0 (2025-11-05)

### Bug Fixes

- **auth**: Improve error messages for username and token validation
  ([`a6ea8e7`](https://github.com/MountainGod2/cb-events/commit/a6ea8e703ffd36f9beb3ce6c37d756daaa1bf11b))

### Documentation

- **readme**: Clarify async handler registration and error handling
  ([`c5b254a`](https://github.com/MountainGod2/cb-events/commit/c5b254ac82d75775f58f9a849eb5fc2a4425e977))

### Features

- **router**: Enhance async handler registration and error handling
  ([`35dbe52`](https://github.com/MountainGod2/cb-events/commit/35dbe5217e521f4422fde4aa7940c2114564cfc4))

### Testing

- **polling**: Add tests for session creation and network errors
  ([`541e0e3`](https://github.com/MountainGod2/cb-events/commit/541e0e360f6219a7fce5bee1bb6ccd7f5a792b48))

- **router**: Add tests for non-async handler rejection
  ([`8fc7939`](https://github.com/MountainGod2/cb-events/commit/8fc7939ccfe5635f40926d357619186275d0236a))


## v5.0.0 (2025-11-05)

### Chores

- **deps**: Update actions/checkout digest to 71cf226
  ([`765fba5`](https://github.com/MountainGod2/cb-events/commit/765fba5df802b299eced0820c609e47d858ab9db))

- **deps**: Update astral-sh/setup-uv digest to 30ce38e
  ([`92d8488`](https://github.com/MountainGod2/cb-events/commit/92d84882f95a51753be8c8b33562bf3db0075330))

- **deps**: Update dependency ruff to v0.14.3
  ([`47e8173`](https://github.com/MountainGod2/cb-events/commit/47e817331575b9e222273c1b320de38b1d4e651b))

- **deps**: Update github/codeql-action digest to 95b1867
  ([`3048986`](https://github.com/MountainGod2/cb-events/commit/3048986282bc5be64fbf1effd5add17cf6cf5050))

### Refactoring

- **client**: Enhance type annotations
  ([`8c8d189`](https://github.com/MountainGod2/cb-events/commit/8c8d1890677c3fafd68d639272a25823ea0c5248))

- **config**: Add type annotation for message variable in validation method
  ([`1d1da0f`](https://github.com/MountainGod2/cb-events/commit/1d1da0f5abd1e46d52c30d436a4300e4d2e76440))

- **config, router**: Rename EventClientConfig to ClientConfig and EventRouter to Router
  ([`5de0bc2`](https://github.com/MountainGod2/cb-events/commit/5de0bc26b18560c3914e77e0cd1abe6199bbaf3c))

- **dependencies**: Add pyrefly package to dev dependencies and update uv.lock
  ([`a208108`](https://github.com/MountainGod2/cb-events/commit/a20810851f23f98e29dd7eaf14e3a6c907a32110))

- **docs**: Update README and example to use ClientConfig and Router
  ([`f9b59d3`](https://github.com/MountainGod2/cb-events/commit/f9b59d324d9b24795a939499332da4401dd916a2))

- **exceptions**: Clarify response_text documentation
  ([`ced8d33`](https://github.com/MountainGod2/cb-events/commit/ced8d33ef76275c015efa58640acb153df7d5b8e))

- **models**: Enhance type annotations for logger and value variables
  ([`525a19f`](https://github.com/MountainGod2/cb-events/commit/525a19fd99182a6c92c76de4b9e264d1f673e60c))

- **models**: Update field aliases
  ([`36ae5d9`](https://github.com/MountainGod2/cb-events/commit/36ae5d94ca0fd50f743190b5b085ca1d06d0f7a7))

- **router**: Enhance type annotations for logger and handlers
  ([`f058bc6`](https://github.com/MountainGod2/cb-events/commit/f058bc64c927bf647211ab520e1648aae7525de3))

- **tests**: Remove unused pyright type checking comments
  ([`7553b72`](https://github.com/MountainGod2/cb-events/commit/7553b722251689b541c683799f0d57d32d7085ab))

- **tests**: Replace EventClientConfig with ClientConfig
  ([`41aee7c`](https://github.com/MountainGod2/cb-events/commit/41aee7c7cd4105b626a66148b865e6de7daaeafc))

- **vscode**: Update extension recommendations
  ([`6b02686`](https://github.com/MountainGod2/cb-events/commit/6b02686f65653caaae9d2f81c47f30e12ca133b2))


## v4.10.1 (2025-11-04)

### Bug Fixes

- **router**: Improve handler registration and error logging in event dispatching
  ([`e42fa37`](https://github.com/MountainGod2/cb-events/commit/e42fa3778e4729695370197f5553c54f5ca13448))

- **router**: Log exceptions with handler names during event dispatching
  ([`9e37659`](https://github.com/MountainGod2/cb-events/commit/9e37659a0754abee05bc749dec774d8335526852))

### Chores

- **deps**: Lock file maintenance
  ([`b1e873c`](https://github.com/MountainGod2/cb-events/commit/b1e873cfa82b66c1efe05fd9b832b51717e98459))

- **deps**: Update actions/download-artifact digest to f093f21
  ([`e2d249d`](https://github.com/MountainGod2/cb-events/commit/e2d249dc8afc98883d74e6e2d18e123f5d4dcdb8))

### Documentation

- **README**: Update event handling and configuration details
  ([`b594faf`](https://github.com/MountainGod2/cb-events/commit/b594faf4429e4892cff499d2c8746467a5b2ea1b))

### Refactoring

- **client**: Improve token masking
  ([`0cc0d9b`](https://github.com/MountainGod2/cb-events/commit/0cc0d9b107eb0c21e35d106a836ad320181a40e5))

- **client**: Remove unused client default configurations
  ([`91aaeb5`](https://github.com/MountainGod2/cb-events/commit/91aaeb565ec512cd0ce8a9c696ca497ffbb00f55))

- **client**: Reorganize constants and improve function documentation
  ([`488a21e`](https://github.com/MountainGod2/cb-events/commit/488a21ecefa58d1e833f08e5d4ae8030e4685636))

- **config**: Improve attribute descriptions
  ([`26a2188`](https://github.com/MountainGod2/cb-events/commit/26a2188793e8fcf38c58c02a4e60c9682c79b78c))

- **config**: Move default configuration values into the config file
  ([`33d4123`](https://github.com/MountainGod2/cb-events/commit/33d4123af2decf533242c8d55080dd93e29a3d56))

- **constants**: Remove obsolete constants file
  ([`d136d42`](https://github.com/MountainGod2/cb-events/commit/d136d42aeacbf65bcd81c8b17dabf53abdb057de))

- **constants**: Remove unused variables
  ([`b3434a6`](https://github.com/MountainGod2/cb-events/commit/b3434a6b89192574b2d194015465ac1c9549ce15))

- **example**: Format print statements for better readability
  ([`e7ace63`](https://github.com/MountainGod2/cb-events/commit/e7ace637c32449d358688e894de2426bd439d25f))

- **exceptions**: Remove unused repr method
  ([`25aab94`](https://github.com/MountainGod2/cb-events/commit/25aab940249b3fd41bef5e26afb98e4273a858e4))

- **init**: Add EventCallback to __all__
  ([`978e262`](https://github.com/MountainGod2/cb-events/commit/978e262325d53234cd2450f4e663ba12e7859788))

- **models**: Improve docstrings and update field types
  ([`068cca8`](https://github.com/MountainGod2/cb-events/commit/068cca84854c5064b4969a188bce6139c7ecb084))

- **models**: Improve key handling in Event class
  ([`78ee61a`](https://github.com/MountainGod2/cb-events/commit/78ee61a4d130cf7e4ba760af55b1c02e48cdad65))

- **router**: Simplify type annotations and improve docstrings
  ([`e8c0d19`](https://github.com/MountainGod2/cb-events/commit/e8c0d1946c44c3bca8288f8a5f6f4babf69a05bd))

- **style**: Reduce line length to 80
  ([`e1de966`](https://github.com/MountainGod2/cb-events/commit/e1de9668f25ecd72de35a3d006f7a79c351a3309))

- **utils**: Remove unused utility functions
  ([`73719c4`](https://github.com/MountainGod2/cb-events/commit/73719c45fb580899ad4718d8e2e7812ee692fa1c))

### Testing

- Improve error messages and logging
  ([`1ac15dc`](https://github.com/MountainGod2/cb-events/commit/1ac15dc27b89246b6a8be0f2931d426a15f7f618))


## v4.10.0 (2025-11-03)

### Bug Fixes

- **README**: Update event streaming method in examples and improve retry attempts description
  ([`028d287`](https://github.com/MountainGod2/cb-events/commit/028d2874f51d03be75f35ffeba7cec1802be72a2))

### Chores

- **deps**: Remove aiohttp-retry dependency from project configuration
  ([`9623026`](https://github.com/MountainGod2/cb-events/commit/962302695ce49d2de9fa046b13e61d7a35cb9ecb))

- **deps**: Update dependency ty to v0.0.1a25
  ([`1b749b2`](https://github.com/MountainGod2/cb-events/commit/1b749b262e6b8ca05d93bf4e18f7f0da8b86b647))

### Documentation

- **config**: Clarify retry attempts and backoff descriptions in EventClientConfig
  ([`0a87160`](https://github.com/MountainGod2/cb-events/commit/0a87160a869b0bf0d9d0a1ee8e2a59f71ae9d73b))

### Features

- Add utility functions for masking secrets and formatting validation errors
  ([`4e7d88e`](https://github.com/MountainGod2/cb-events/commit/4e7d88e4582107f51520df93fdf9aab0795bd387))

- Implement event batch processing utilities with validation
  ([`de985e1`](https://github.com/MountainGod2/cb-events/commit/de985e1fb163dcf18a6db1467c2e1abe9a415f03))

### Refactoring

- Enhance event handling with improved validation and retry logic
  ([`56d20fe`](https://github.com/MountainGod2/cb-events/commit/56d20fe55089026bd2589dd1b162905e91a0db1b))

- Improve documentation and streamline comments across modules
  ([`88fd231`](https://github.com/MountainGod2/cb-events/commit/88fd231b7f061320627eee1544965bc99ca5ca73))

- Remove unused event parsing module
  ([`50ab429`](https://github.com/MountainGod2/cb-events/commit/50ab429173824f55cc4f87f40f4595763cc18d40))

- Simplify event model parsing with shared extraction method
  ([`bb0cac7`](https://github.com/MountainGod2/cb-events/commit/bb0cac7077f5dae84b3a25698485d190d66a6625))

- Streamline event parsing and response handling in EventClient
  ([`e768170`](https://github.com/MountainGod2/cb-events/commit/e768170ed8202093f1be5797c8be9c6be5b3dd5c))

- **router**: Enhance event handler registration with normalization for sync and async support
  ([`eb4245b`](https://github.com/MountainGod2/cb-events/commit/eb4245b28709b09291342f3fde3bb1c4d19566a6))

### Testing

- **router**: Add support for synchronous handlers in event dispatching
  ([`241c441`](https://github.com/MountainGod2/cb-events/commit/241c44195c7140a2e04df995b7f44ef0b98050f5))

- **stream**: Add test for stream method yielding events
  ([`8566d92`](https://github.com/MountainGod2/cb-events/commit/8566d9218c39c40e7d70d5a07fd5f60ed379a499))


## v4.9.2 (2025-11-02)

### Bug Fixes

- **docs**: Add new template for Python type documentation
  ([`1d34bd5`](https://github.com/MountainGod2/cb-events/commit/1d34bd5cf8f0c9dfb86d1f4f162e4135a26b9d02))

### Refactoring

- **docs**: Remove redundant error handling section and update dependencies note
  ([`9ea989f`](https://github.com/MountainGod2/cb-events/commit/9ea989f0f8c3fd01998a750c2e0191db1905c6bf))


## v4.9.1 (2025-11-02)

### Bug Fixes

- **deps**: Update dependency aiohttp to v3.13.2
  ([`b88e635`](https://github.com/MountainGod2/cb-events/commit/b88e6352c52d2d344d93dbfe9e9dcdcdd6eae2d2))


## v4.9.0 (2025-11-02)

### Bug Fixes

- **init**: Handle PackageNotFoundError when retrieving package version
  ([`b247e14`](https://github.com/MountainGod2/cb-events/commit/b247e148ca83e1d44bb11a69f5c4af6e5864c8ed))

### Features

- **tests**: Reorganize suites with typed fixtures
  ([`1ab68fd`](https://github.com/MountainGod2/cb-events/commit/1ab68fd7efc619ef2182655aeffc1b8bd597f35d))

### Refactoring

- **client**: Enhance error logging for validation failures
  ([`7bb07ae`](https://github.com/MountainGod2/cb-events/commit/7bb07ae62e9fec68559e28f3150ad54adaa334cc))

- **example**: Add exit message to main script
  ([`a11cd66`](https://github.com/MountainGod2/cb-events/commit/a11cd6646e01704e092cc50c38f9fa126c560af6))

- **models**: Improve error logging for validation failures and optimize caching
  ([`092dce2`](https://github.com/MountainGod2/cb-events/commit/092dce2105c98ee2f0fe2bc98ebd8ab52ebeaea8))

### Testing

- **models**: Add tests for error handling and logging
  ([`1207c25`](https://github.com/MountainGod2/cb-events/commit/1207c255e5af5770bdafe7e9684955b54607d3e6))


## v4.8.0 (2025-11-01)

### Bug Fixes

- **client**: Improve error handling for API requests
  ([`9799bc6`](https://github.com/MountainGod2/cb-events/commit/9799bc60cfea295ea46a94be27132711ff4306e7))

### Chores

- **deps**: Update github/codeql-action digest to 338146c
  ([`70d8c22`](https://github.com/MountainGod2/cb-events/commit/70d8c2205395d68d0c8d18aa83591cab024f200c))

### Features

- **models**: Implement caching for event data retrieval
  ([`1e9ccaa`](https://github.com/MountainGod2/cb-events/commit/1e9ccaae491696f53326c748bda0a35244ff322e))

### Refactoring

- **tests**: Enhance type hints and improve test function signatures
  ([`395c29b`](https://github.com/MountainGod2/cb-events/commit/395c29b3a510920879e65e89aacefe61b77f692d))


## v4.7.1 (2025-10-31)

### Bug Fixes

- **docs**: Clarify behavior of event properties and update version import
  ([`35df062`](https://github.com/MountainGod2/cb-events/commit/35df062181ed21c5d764107a6b2fd17b07f2da5a))

- **models**: Enhance error handling for data validation
  ([`d24bd84`](https://github.com/MountainGod2/cb-events/commit/d24bd84f2a2d89dacfd3f45648fa32db14415214))

### Chores

- **deps**: Update astral-sh/setup-uv digest to 0d20755
  ([`b7e8fa2`](https://github.com/MountainGod2/cb-events/commit/b7e8fa28f4ee2802fb5bc67f10ea8384fd7e8b65))

- **deps**: Update dependency pylint-pydantic to v0.4.1
  ([`79c9314`](https://github.com/MountainGod2/cb-events/commit/79c9314180332536c7e47235e85f47449e4efa5b))

### Refactoring

- **client**: Remove unused ResponseStatus enum and simplify response handling
  ([`05cfec5`](https://github.com/MountainGod2/cb-events/commit/05cfec573a0bf13b74cba4a4301c504a7c91f062))

- **constants**: Simplify Cloudflare error handling
  ([`f650ce8`](https://github.com/MountainGod2/cb-events/commit/f650ce84b52f8bb9afec5d8dae241610abf5836c))


## v4.7.0 (2025-10-31)

### Features

- **validation**: Introduce strict validation for event data and update error handling
  ([`ef2fe99`](https://github.com/MountainGod2/cb-events/commit/ef2fe995d10b406aa6b69ab26c73cb1a7f75b700))

### Refactoring

- Improve field handling and logging
  ([`455099e`](https://github.com/MountainGod2/cb-events/commit/455099e35bb19f0a284d6965e2f94f6833135cab))

- **pyproject**: Remove unused pyright configuration
  ([`de12bb2`](https://github.com/MountainGod2/cb-events/commit/de12bb2699793af2f5578b0f39b527e00d72b753))


## v4.6.1 (2025-10-30)

### Bug Fixes

- **constants**: Correct initialization of CLOUDFLARE_ERROR_CODES set
  ([`3120e80`](https://github.com/MountainGod2/cb-events/commit/3120e804ed876b68144ed3af6b9fc7ccb5bb3d54))

- **event**: Handle ValidationError when retrieving user, tip, message, and room subject data
  ([`27a1c9d`](https://github.com/MountainGod2/cb-events/commit/27a1c9dfb20c715f1bd424cc56bf921a932003c6))

- **router**: Correct type hint for _handlers in EventRouter initialization
  ([`0e6dcc5`](https://github.com/MountainGod2/cb-events/commit/0e6dcc50dc3d234967d3ed12cd725bb6501858f3))

### Chores

- **deps**: Update astral-sh/setup-uv digest to 8491d1d
  ([`8aa4870`](https://github.com/MountainGod2/cb-events/commit/8aa4870e5be2531545f3a0b1029a952eb3592077))

- **deps**: Update github/codeql-action digest to 9bd8638
  ([`d5ff4f1`](https://github.com/MountainGod2/cb-events/commit/d5ff4f1ea345467bdf74c55f0290e4cd02024548))

- **docs**: Add logger documentation for EventClient and EventRouter
  ([`e932a7b`](https://github.com/MountainGod2/cb-events/commit/e932a7b9212581d92658fe0ce13aa89c944a7b4e))

### Refactoring

- **exceptions**: Improve response_text representation in EventsError
  ([`5309193`](https://github.com/MountainGod2/cb-events/commit/53091931b11e82215a2d921e157b2d2840b254f9))


## v4.6.0 (2025-10-30)

### Bug Fixes

- **docs**: Exclude autoapi templates from doc8 rst check
  ([`f1b423e`](https://github.com/MountainGod2/cb-events/commit/f1b423e4494a2dcae1b91b32d76eaacb7f8f4ea9))

### Chores

- **deps**: Update dependency pyright to v1.1.407
  ([`8b8a73b`](https://github.com/MountainGod2/cb-events/commit/8b8a73b287503e4913cefe2eb4dbf6d4d8663aae))

- **deps**: Update github/codeql-action digest to ac9aeee
  ([`8ecac5f`](https://github.com/MountainGod2/cb-events/commit/8ecac5f6bbac3777d8656c707fe39bbd6402919f))

### Features

- **docs**: Add autoapi template for class documentation and update Sphinx configuration
  ([`21422fb`](https://github.com/MountainGod2/cb-events/commit/21422fb5a4df0a0362295c0a9701e55f14ae13e5))


## v4.5.2 (2025-10-28)

### Bug Fixes

- **client**: Ensure polling lock is initialized and handle uninitialized state
  ([`7216340`](https://github.com/MountainGod2/cb-events/commit/72163403ea123da786d8d89d029c8f0484489c95))

- **coverage**: Remove omitted files from coverage report
  ([`646e481`](https://github.com/MountainGod2/cb-events/commit/646e48161e50b5bdbac173eb571f213527398ebe))

### Chores

- **deps**: Update dependency ruff to v0.14.2
  ([`28f42da`](https://github.com/MountainGod2/cb-events/commit/28f42da752c74c3e7266f91a17f5ac55e7d6a575))

- **deps**: Update dependency ty to v0.0.1a24
  ([`4ab277c`](https://github.com/MountainGod2/cb-events/commit/4ab277cfb5a8e324013c66e90e235e9f096416bf))

- **deps**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.14.2
  ([`2c953d8`](https://github.com/MountainGod2/cb-events/commit/2c953d8fe500465903a3f588ef0961d773847e9d))

### Refactoring

- **docs**: Update module docstrings
  ([`d8189d1`](https://github.com/MountainGod2/cb-events/commit/d8189d1f36e56244c19891dc5f0906a4a3e93ae3))


## v4.5.1 (2025-10-28)

### Bug Fixes

- **pyproject**: Update documentation URL to point to Read the Docs
  ([`8d2a5bc`](https://github.com/MountainGod2/cb-events/commit/8d2a5bc2bb436a116eca964d18b9c1cb75b6cdb3))


## v4.5.0 (2025-10-28)

### Features

- **pyproject**: Add fancy-pypi-readme metadata hooks for README processing
  ([`50da09d`](https://github.com/MountainGod2/cb-events/commit/50da09df0c10b57a5c153e5b959cddd4bd055702))


## v4.4.3 (2025-10-28)

### Bug Fixes

- **Dockerfile**: Update uv package version to 0.9.5
  ([`b9bb24d`](https://github.com/MountainGod2/cb-events/commit/b9bb24d27f98324531c7f769ecb6c59896c1d2c4))

### Refactoring

- **pyproject**: Remove unused dependencies and clean up metadata hooks
  ([`28bb948`](https://github.com/MountainGod2/cb-events/commit/28bb9481750dcf5ca50361a9b91f790ac2946b7d))

- **router**: Remove RouterError and update error handling in tests and documentation
  ([`cfa3510`](https://github.com/MountainGod2/cb-events/commit/cfa3510ca80d58bb142c36d3266c540a79c9d390))


## v4.4.2 (2025-10-27)

### Bug Fixes

- **client**: Add thread safety with asyncio lock for polling method
  ([`212b8d1`](https://github.com/MountainGod2/cb-events/commit/212b8d1c187ec7a4a4d992ac6c7015ff97579a7e))

- **config**: Update validation method for retry delays in EventClientConfig
  ([`e9bbe8d`](https://github.com/MountainGod2/cb-events/commit/e9bbe8d6d3af3b04a01dbbec5ca4ac5a278f1c3d))

### Chores

- **deps**: Update github/codeql-action digest to 8d77149
  ([`fc79cb1`](https://github.com/MountainGod2/cb-events/commit/fc79cb1d479d2e424e9a96f7c27bcb76ea0df709))

### Refactoring

- **tests**: Enhance test descriptions and structure
  ([`fb88608`](https://github.com/MountainGod2/cb-events/commit/fb88608baa2297564fd59b682f0a2410094fd4e8))


## v4.4.1 (2025-10-26)

### Bug Fixes

- **docs**: Update links and titles for consistency
  ([`623fb25`](https://github.com/MountainGod2/cb-events/commit/623fb25d7fd832105e66d7ead110523c5de961fe))


## v4.4.0 (2025-10-26)

### Bug Fixes

- **docs**: Update description in README and pyproject.toml for consistency
  ([`03fc31d`](https://github.com/MountainGod2/cb-events/commit/03fc31d4dc23bbbc5d8b16bf99889e3851be6e6b))

### Documentation

- Update index.md to include README content and remove outdated sections
  ([`3aeb9d5`](https://github.com/MountainGod2/cb-events/commit/3aeb9d5d25216f595dd41b7bc060f668c2dafa5e))

### Features

- **docs**: Add html_extra_path to include LICENSE and pyproject.toml in build output
  ([`8da1ac6`](https://github.com/MountainGod2/cb-events/commit/8da1ac60bf378415284e56c8747f1e4c8d930cba))


## v4.3.0 (2025-10-26)

### Bug Fixes

- **client**: Raise EventsError on session initialization failure
  ([`449e1e8`](https://github.com/MountainGod2/cb-events/commit/449e1e89d7ebd59ced164c9d76adc26001384162))

### Features

- **exceptions**: Add detailed __repr__ methods for EventsError and RouterError
  ([`3852ccd`](https://github.com/MountainGod2/cb-events/commit/3852ccd3dfd7f8f80e75d3764f05d1053fcc35cf))

### Testing

- **exceptions**: Add tests for __repr__ methods in EventsError and RouterError
  ([`67a1572`](https://github.com/MountainGod2/cb-events/commit/67a157284d9f8075f15561d07c80aad6856ed257))


## v4.2.1 (2025-10-26)

### Bug Fixes

- **router**: Log exceptions in event handlers to improve error tracking
  ([`8c1aa7a`](https://github.com/MountainGod2/cb-events/commit/8c1aa7a8a5616b3daacf82d2729fb74220b610ba))

### Chores

- **deps**: Update astral-sh/setup-uv digest to 8585678
  ([`dd7bbb5`](https://github.com/MountainGod2/cb-events/commit/dd7bbb5134ab780aa438ec44ef15a5b9132eb54d))

### Documentation

- **client**: Enhance docstring to clarify rate limiting behavior
  ([`ff0d0aa`](https://github.com/MountainGod2/cb-events/commit/ff0d0aacfd06e1570602e5606b84f903a2b8c2c7))

- **config**: Clarify immutability and improve error message in validation
  ([`8042e1b`](https://github.com/MountainGod2/cb-events/commit/8042e1b6a48855a3f91a8c55f477860ecd71d926))

- **models**: Enhance documentation for BaseEventModel and Event classes
  ([`2121499`](https://github.com/MountainGod2/cb-events/commit/2121499d90071007292d8cc1eaaaeb2678f2cb52))

- **README**: Update installation, usage, and configuration sections
  ([`be5631e`](https://github.com/MountainGod2/cb-events/commit/be5631eab49c1ee6d543e9afd2ca65a382723412))

- **router**: Update dispatch logic to ensure all handlers run despite errors
  ([`b846d1c`](https://github.com/MountainGod2/cb-events/commit/b846d1c88c1995b8ba59fc13301fdf33097b07c3))


## v4.2.0 (2025-10-26)

### Chores

- **deps**: Update actions/download-artifact digest to 018cc2c
  ([`e6d54b3`](https://github.com/MountainGod2/cb-events/commit/e6d54b3e77a24821377db6c04080e3264128dd7e))

- **deps**: Update actions/upload-artifact digest to 2d9f9cd
  ([`8c3a852`](https://github.com/MountainGod2/cb-events/commit/8c3a8527508092a0bd201418c4d479bdd1cd3593))

- **deps**: Update actions/upload-artifact digest to 330a01c
  ([`3f3df1a`](https://github.com/MountainGod2/cb-events/commit/3f3df1a1eb076dd324e94d3d7eb0968fc8cde419))

- **deps**: Update astral-sh/setup-uv digest to 22d500a
  ([`8b4c262`](https://github.com/MountainGod2/cb-events/commit/8b4c262682b56bd05076f4d664f181ddd9b6418f))

- **deps**: Update dependency pylint to v4.0.2
  ([`8ffa0d1`](https://github.com/MountainGod2/cb-events/commit/8ffa0d12d0c28ab89d6c66e8713cb0507f230ba1))

- **deps**: Update github/codeql-action digest to 4264208
  ([`c246f1c`](https://github.com/MountainGod2/cb-events/commit/c246f1ca0ea97bc43284e7af414b482ef89d4310))

- **deps**: Update github/codeql-action digest to 9625890
  ([`bb6693c`](https://github.com/MountainGod2/cb-events/commit/bb6693cf2017170da05932792d7656d35b8832e0))

- **deps**: Update github/codeql-action digest to ae78991
  ([`3fda5e2`](https://github.com/MountainGod2/cb-events/commit/3fda5e2d8f0c69270adade323ab815e4738a2c7d))

### Features

- **client**: Remove global rate limiter and use instance-based limiter
  ([`b20b42c`](https://github.com/MountainGod2/cb-events/commit/b20b42cbeab6cf12254b074c7218a773491f373f))

### Refactoring

- **router**: Replace EventHandler type alias with Protocol for better type safety
  ([`73faf5c`](https://github.com/MountainGod2/cb-events/commit/73faf5cd9a62e0caf14ddc45671bad68b2264a67))


## v4.1.1 (2025-10-22)

### Bug Fixes

- **deps**: Update runtime
  ([`38d51aa`](https://github.com/MountainGod2/cb-events/commit/38d51aadeffd064756a4be9a35201850b95eef0d))

### Chores

- **deps**: Update dependency ruff to v0.14.1
  ([`39508be`](https://github.com/MountainGod2/cb-events/commit/39508be5cd44c229fd70fcbee48befc381113fa2))

- **deps**: Update dependency ty to v0.0.1a23
  ([`9a16c89`](https://github.com/MountainGod2/cb-events/commit/9a16c8980d17455cce85792f1e9273d1b00cc924))

- **deps**: Update github/codeql-action digest to 0c5185d
  ([`13c4991`](https://github.com/MountainGod2/cb-events/commit/13c4991535b65703f8561939a2fa933ca0452f23))

- **deps**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.14.1
  ([`02c3529`](https://github.com/MountainGod2/cb-events/commit/02c3529e4330e9afd3011ef918ee148b4ee10bf6))


## v4.1.0 (2025-10-21)

### Bug Fixes

- **client**: Mask authentication token in logs and adjust session timeout
  ([`108b033`](https://github.com/MountainGod2/cb-events/commit/108b033b8b0ae04d0131fbafe9aff71616db1656))

- **exceptions**: Remove redundant message attribute documentation from exception classes
  ([`3a99235`](https://github.com/MountainGod2/cb-events/commit/3a992359c3ab7304efd9b8736989b08ae03c8f85))

### Features

- **constants**: Add SESSION_TIMEOUT_BUFFER
  ([`e124271`](https://github.com/MountainGod2/cb-events/commit/e1242716aae4f5cdf9715da609c850af0ce5eff9))


## v4.0.4 (2025-10-21)

### Bug Fixes

- Enhance error messages for empty and whitespace credentials in EventClient
  ([`2a3544b`](https://github.com/MountainGod2/cb-events/commit/2a3544bcab1ab18c80b29a0439ae3e33dd6c1368))

- Update __all__ declaration to use type hinting
  ([`3814db5`](https://github.com/MountainGod2/cb-events/commit/3814db5a78013f99bc63ab19c99a155a51822455))

### Chores

- **deps**: Lock file maintenance
  ([`ae45463`](https://github.com/MountainGod2/cb-events/commit/ae454636d15e8866152252b4af9fb6ff981af394))

- **deps**: Update dependency sphinx-autodoc-typehints to v3.5.2
  ([`1089d86`](https://github.com/MountainGod2/cb-events/commit/1089d86b01128a8fbda7e1b34c34cfde8c21b5c4))

- **deps**: Update github/codeql-action digest to 9b0ac1c
  ([`f1cab73`](https://github.com/MountainGod2/cb-events/commit/f1cab737b9c9f8e69a4e5633bff1e304380bba9f))

### Refactoring

- Adjust rate limiter and improve authentication checks in EventClient
  ([`60ccbf8`](https://github.com/MountainGod2/cb-events/commit/60ccbf89315ff474a9bcf91e5c7ceaa162618806))

- Refactor error message handling in EventsError and RouterError classes
  ([`78b757e`](https://github.com/MountainGod2/cb-events/commit/78b757ece1270d518f42db62c1e621c6e1ee2840))

- **models**: Replace cached_property with property for event model attributes
  ([`ed0abe0`](https://github.com/MountainGod2/cb-events/commit/ed0abe029e6a3078951b85c07fcba9dc41c977a7))


## v4.0.3 (2025-10-20)

### Bug Fixes

- Change ValueError to AuthError for empty username and token in EventClient
  ([`d159944`](https://github.com/MountainGod2/cb-events/commit/d159944e17e0fefd88ace55c5361b7615ab96b80))

- **docs**: Improve error handling for authentication in README and index
  ([`527846c`](https://github.com/MountainGod2/cb-events/commit/527846c338af7c7a9d1f6e868526c5a2627dfe29))

### Refactoring

- **example**: Remove unused AuthError handling in main
  ([`2c70673`](https://github.com/MountainGod2/cb-events/commit/2c70673ba7db0e20160744ad1ac51afd2845d588))

- **example**: Reorganize example file layout
  ([`5e379ee`](https://github.com/MountainGod2/cb-events/commit/5e379eec2ed98be0b79a8ccdd554f6d5147c060e))


## v4.0.2 (2025-10-20)

### Bug Fixes

- **docs**: Update linked files in README and index
  ([`41e111c`](https://github.com/MountainGod2/cb-events/commit/41e111c53c5628818de6f853e51fc941c88486e2))

### Chores

- **deps**: Update astral-sh/setup-uv digest to 2ddd2b9
  ([`ece265b`](https://github.com/MountainGod2/cb-events/commit/ece265b22af2f269126f7e3aa812f2c12938386c))

- **deps**: Update dependency pylint to v4.0.1
  ([#28](https://github.com/MountainGod2/cb-events/pull/28),
  [`b7d8dc0`](https://github.com/MountainGod2/cb-events/commit/b7d8dc035e6d67f7ce05737a7a36519071ac47ec))

### Documentation

- Add additional commit message guidelines
  ([`2818125`](https://github.com/MountainGod2/cb-events/commit/2818125febda7d34c7d668f7849a64a9f5f90654))

- Update Copilot instructions to align with Google Python Style Guide
  ([`58c5eab`](https://github.com/MountainGod2/cb-events/commit/58c5eab69768fbf02fcb62a79afd3ff495f420b9))

### Refactoring

- **client**: Simplify username and token validation and improve nextUrl extraction
  ([`55d8c77`](https://github.com/MountainGod2/cb-events/commit/55d8c777f064c88f3e9c5007e266a496b1d7c397))

- **config**: Replace model_validator with field_validator for retry_max_delay validation
  ([`9f1a488`](https://github.com/MountainGod2/cb-events/commit/9f1a488d945d0afad964ded12e5328b658929bdb))

- **constants**: Remove outdated constant
  ([`6c50842`](https://github.com/MountainGod2/cb-events/commit/6c50842d5b0643e68160dbb87bf98d3d5dad415a))

- **models**: Improve private message check
  ([`d89ca9f`](https://github.com/MountainGod2/cb-events/commit/d89ca9f5ffa609948327a48250874524e0163cc1))

- **router**: Improve error handling in event handler dispatch
  ([`c7b5372`](https://github.com/MountainGod2/cb-events/commit/c7b53725b63834bb57f446c772967bc7dfcdc273))

- **tests**: Simplify test fixtures and remove unused parameters
  ([`c2fe968`](https://github.com/MountainGod2/cb-events/commit/c2fe9681d32687e1fefec5187d07724060c5a648))


## v4.0.1 (2025-10-18)

### Bug Fixes

- **deps**: Update dependency pydantic to v2.12.2
  ([`a9c1ad3`](https://github.com/MountainGod2/cb-events/commit/a9c1ad32071690b58ea5bc5daa7d3712e9854229))


## v4.0.0 (2025-10-18)

### Chores

- **deps**: Update actions/attest-build-provenance digest to ba965ac
  ([`ec9e112`](https://github.com/MountainGod2/cb-events/commit/ec9e1125077a9feadd01008cccda91885720a5f7))

- **deps**: Update github/codeql-action digest to d88a554
  ([`7afa34e`](https://github.com/MountainGod2/cb-events/commit/7afa34e8abde15ed461687a1a50106ed82d3ba04))

### Refactoring

- **python-version**: Update minimum python version to 3.12
  ([`45a344e`](https://github.com/MountainGod2/cb-events/commit/45a344e8108f57bec9d109ef9d9e98db0a8b7185))


## v3.1.2 (2025-10-17)

### Bug Fixes

- **client**: Improve error handling in _parse_response_data method to raise JSONDecodeError on
  invalid JSON
  ([`1679a78`](https://github.com/MountainGod2/cb-events/commit/1679a780d42a5df179c1286748acec9eaf28005c))

- **router**: Enhance dispatch method error handling with context for RouterError
  ([`e74e5c5`](https://github.com/MountainGod2/cb-events/commit/e74e5c5f01e492d46aa2d711d3a290572887ad6b))

### Chores

- **deps**: Update github/codeql-action digest to ee753b4
  ([`630ff4b`](https://github.com/MountainGod2/cb-events/commit/630ff4b4b6464417a8d7b5df62f8b61469bb42dd))

- **deps**: Update pre-commit hook python-jsonschema/check-jsonschema to v0.34.1
  ([`18d1f98`](https://github.com/MountainGod2/cb-events/commit/18d1f98342ec80f6d8787fa30dfc58507d18e63f))

### Refactoring

- **exceptions**: Remove __repr__ methods from EventsError and RouterError classes
  ([`1e83de3`](https://github.com/MountainGod2/cb-events/commit/1e83de32198c76d352bc3ddba2dac9671e2c16c0))

- **models**: Replace @property with @cached_property for improved performance in Event class
  ([`af3b311`](https://github.com/MountainGod2/cb-events/commit/af3b311b8b0b9f4a98481364c779d466f6864f6e))

- **tests**: Remove repr tests for EventsError, AuthError, and RouterError classes
  ([`4ebeaf1`](https://github.com/MountainGod2/cb-events/commit/4ebeaf1bafc0b5fb89e6a6cc210d833a1f57a58a))


## v3.1.1 (2025-10-17)

### Bug Fixes

- **models**: Ensure user, tip, and message data checks are explicit for None
  ([`81830c9`](https://github.com/MountainGod2/cb-events/commit/81830c9df7b2619df10f2c4764e08cd1a5fa7f32))

- **router**: Simplify exception handling in dispatch method documentation
  ([`47a302f`](https://github.com/MountainGod2/cb-events/commit/47a302f1ba46685dc147388bd9cac86a6c3ff5a0))

### Chores

- **deps**: Pin codecov/test-results-action action to 47f89e9
  ([#27](https://github.com/MountainGod2/cb-events/pull/27),
  [`93bc44e`](https://github.com/MountainGod2/cb-events/commit/93bc44ee14d5997dbd74d4b309a750c6e536a1c4))

- **deps**: Update astral-sh/setup-uv digest to b7bf789
  ([`6988c13`](https://github.com/MountainGod2/cb-events/commit/6988c13262b172b12a66f1d9e02e420577592104))

- **deps**: Update dependency sphinx-autodoc-typehints to v3.5.1
  ([`99f506d`](https://github.com/MountainGod2/cb-events/commit/99f506d928e4397745309f4ce3dd1b55dd949878))

### Refactoring

- **client**: Consolidate rate limiter management
  ([`edd891d`](https://github.com/MountainGod2/cb-events/commit/edd891d2e755c4371568a8ff7025183809362923))

- **client**: Move rate limiter initialization to instance level and remove class-level reset
  fixture
  ([`352c04a`](https://github.com/MountainGod2/cb-events/commit/352c04a1ea0a4958c05b748569e1255db87b88a9))

- **Makefile**: Remove redundant docs-clean target
  ([`7786698`](https://github.com/MountainGod2/cb-events/commit/7786698740385b3a5765862dad47dc41e6ea7305))

- **tests**: Rename and simplify rate limiter fixture
  ([`7c3a38a`](https://github.com/MountainGod2/cb-events/commit/7c3a38a7a6dcb3ea4a0a6fbcaa58bbe3c9ce555c))


## v3.1.0 (2025-10-14)

### Chores

- Add junit.xml output to test coverage reports
  ([`999f029`](https://github.com/MountainGod2/cb-events/commit/999f029d4342fde889eba90970618181ad341824))

- Add junit.xml to .gitignore
  ([`7630ed3`](https://github.com/MountainGod2/cb-events/commit/7630ed3cec3aba4f2933680aa326d2d7c3d88810))

- **deps**: Reduce minimum release age from 7 days to 4 days
  ([`c6bcf49`](https://github.com/MountainGod2/cb-events/commit/c6bcf49d2b087fce928294cf2cdb1df47029a288))

- **deps**: Reorganize renovate package rules
  ([`a63da64`](https://github.com/MountainGod2/cb-events/commit/a63da64de9267dd364761b990b77d13c8486fdc6))

- **deps**: Tighten constraints for pylint versions
  ([`de3a18b`](https://github.com/MountainGod2/cb-events/commit/de3a18b6356ef8824f8ecc55a030226fdeb68b29))

- **deps**: Update dependency ruff to v0.14.0
  ([`074b7cb`](https://github.com/MountainGod2/cb-events/commit/074b7cb4a7a0f8bc679c37a9cd9aebe2d7b7a115))

- **deps**: Update dependency sphinx-autoapi to v3.6.1
  ([#22](https://github.com/MountainGod2/cb-events/pull/22),
  [`bb2d5c9`](https://github.com/MountainGod2/cb-events/commit/bb2d5c981b1df1ef759c2b74802e5f0bb447c753))

- **deps**: Update pre-commit
  ([`0151055`](https://github.com/MountainGod2/cb-events/commit/0151055968e0372333f50e6e9326eddf4ea16148))

- **deps**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.14.0
  ([`6c3cca5`](https://github.com/MountainGod2/cb-events/commit/6c3cca5640497b795389d936d57e7f5f4ef1b54a))

- **deps**: Update pre-commit package rules
  ([`cb41f5e`](https://github.com/MountainGod2/cb-events/commit/cb41f5e0068892919f19d3c4d0c0c81aef6ba3b3))

- **deps**: Update pylint versioning constraints
  ([`0d7394e`](https://github.com/MountainGod2/cb-events/commit/0d7394eaf7866f5f5242a4dbc733542cab224d52))

- **deps**: Update uv dependency to version 0.9.2 in Dockerfile
  ([`d956ee6`](https://github.com/MountainGod2/cb-events/commit/d956ee6324d915b1612018139269839a9aca3d61))

### Features

- Add Codecov test results action to CI workflow
  ([`915386d`](https://github.com/MountainGod2/cb-events/commit/915386d159069129186a0418f04d357aceddfade))

### Refactoring

- **renovate**: Rename pre-commit group to pre-commit-hooks
  ([`3e2f51a`](https://github.com/MountainGod2/cb-events/commit/3e2f51abadc891c510f635abb7b9d45dadd1d680))


## v3.0.5 (2025-10-14)

### Bug Fixes

- **deps**: Update dependency pydantic to v2.12.0
  ([#24](https://github.com/MountainGod2/cb-events/pull/24),
  [`f8e50e7`](https://github.com/MountainGod2/cb-events/commit/f8e50e7a8e1fa6d585d7e49a9cbaf7659a24c8a2))

### Chores

- **deps**: Update astral-sh/setup-uv digest to 3ccd0fd
  ([`c412300`](https://github.com/MountainGod2/cb-events/commit/c412300deed9fe4abf4933d0b31f6682ea60a8f5))

- **deps**: Update dependency pylint to v4
  ([#23](https://github.com/MountainGod2/cb-events/pull/23),
  [`8e8577b`](https://github.com/MountainGod2/cb-events/commit/8e8577be4d03fc48feeab10c0f3fc93350aa2683))

- **deps**: Update dependency pylint-pydantic to v0.4.0
  ([#25](https://github.com/MountainGod2/cb-events/pull/25),
  [`b2b0e6e`](https://github.com/MountainGod2/cb-events/commit/b2b0e6e33480559a38e62d69a4189462280a0fa8))

- **deps**: Update pre-commit hook adhtruong/mirrors-typos to v1.38.0
  ([`cc6ea5e`](https://github.com/MountainGod2/cb-events/commit/cc6ea5e6f86978ffd8696f750e9f003de614bb2c))


## v3.0.4 (2025-10-13)

### Bug Fixes

- **deps**: Update dependency aiohttp to v3.13.0
  ([`e035676`](https://github.com/MountainGod2/cb-events/commit/e035676aa192ff96869a62d26083fa2b1e980007))

### Chores

- **deps**: Lock file maintenance
  ([`001bbe6`](https://github.com/MountainGod2/cb-events/commit/001bbe62d6cf1e9cf3720c0a8d39c0b35fd92fee))

- **deps**: Update astral-sh/setup-uv digest to 2382069
  ([`67616f4`](https://github.com/MountainGod2/cb-events/commit/67616f4206a5f3c4bc492280986aa91088c8d399))

- **deps**: Update astral-sh/setup-uv digest to 3259c62
  ([`22e9405`](https://github.com/MountainGod2/cb-events/commit/22e9405514ab060cee073829822390662b2073e8))

- **deps**: Update dependency pylint to v3.3.9
  ([`65b746d`](https://github.com/MountainGod2/cb-events/commit/65b746d89debead3de57468282be0ac83af91dc2))


## v3.0.3 (2025-10-12)

### Bug Fixes

- **deps**: Update dependency pydantic to v2.11.10
  ([`e436274`](https://github.com/MountainGod2/cb-events/commit/e4362744b9e36cb4c8345f66582fa484b1f48b05))

### Chores

- **deps**: Update astral-sh/setup-uv digest to 9c6b5e9
  ([`ef54921`](https://github.com/MountainGod2/cb-events/commit/ef549215905ada16018af963c0aa779c732f5ac7))


## v3.0.2 (2025-10-11)

### Bug Fixes

- **client**: Improve JSON parsing error handling in EventClient
  ([`2f4572e`](https://github.com/MountainGod2/cb-events/commit/2f4572e5d4d7267e3b3016fff45f55514e08a55a))

### Chores

- **deps**: Add 'ty' package version 0.0.1a22 to dev dependencies
  ([`bc36a9d`](https://github.com/MountainGod2/cb-events/commit/bc36a9ddaa104f4d3063ab3e3e02759e92f441f0))

- **deps**: Update astral-sh/setup-uv digest to 1a91c38
  ([`63160be`](https://github.com/MountainGod2/cb-events/commit/63160be95a31da8c8948d6aa996fdd2bd7f23344))

- **deps**: Update dependency ruff to v0.13.3
  ([`f578eca`](https://github.com/MountainGod2/cb-events/commit/f578eca009328edd862354e960707bf74e302b1f))

- **deps**: Update github/codeql-action digest to 17783bf
  ([`de93a9c`](https://github.com/MountainGod2/cb-events/commit/de93a9cde26df999820c9143eac2924de1e2ba50))

- **deps**: Update pre-commit hook adhtruong/mirrors-typos to v1.37.2
  ([`0293300`](https://github.com/MountainGod2/cb-events/commit/029330025cd80c3b2b4b531892d3a4580c8f4ff2))

- **deps**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.13.3
  ([`6aa5514`](https://github.com/MountainGod2/cb-events/commit/6aa55140f0f1275815e42940685b370482f527ec))

- **example**: Remove unnecessary docstring from main function
  ([`6fb644b`](https://github.com/MountainGod2/cb-events/commit/6fb644bc710e550a101fe7ad08bcb61c22cb1e4b))

### Documentation

- **__init__**: Update example to include config parameter as a keyword argument
  ([`ec18d4b`](https://github.com/MountainGod2/cb-events/commit/ec18d4bdcd4de258cb6585f8c2ed68cc3b3643ce))

- **constants**: Add additional docstrings
  ([`829f40b`](https://github.com/MountainGod2/cb-events/commit/829f40be5c117c3cf2b4ac2f4a21dfb9fe178684))

- **copilot**: Refine Chaturbate Events API instructions
  ([`c8b584f`](https://github.com/MountainGod2/cb-events/commit/c8b584f13bd3cd47340358b27240ca674dc7aad6))

- **README**: Clarify that the config parameter must be passed as a keyword argument
  ([`e243099`](https://github.com/MountainGod2/cb-events/commit/e243099a5354b569ea563d6165a532260e36da16))

### Refactoring

- **client**: Simplify return logic in data handling
  ([`37726d2`](https://github.com/MountainGod2/cb-events/commit/37726d253339bbe4b4bb721dd9ff190b8bff428d))

- **config**: Use Self type hint in validate_retry_delays method
  ([`b9bf527`](https://github.com/MountainGod2/cb-events/commit/b9bf52773e9c8c9cce62d34180bc70f70258a20e))

- **exceptions**: Enhance error messages and add string representations
  ([`62278a2`](https://github.com/MountainGod2/cb-events/commit/62278a299b313de4e0cc7a9a630c4a3d1a6e6c3a))

- **router**: Enhance error handling in dispatch method and improve docstrings
  ([`5502196`](https://github.com/MountainGod2/cb-events/commit/5502196ebedbb555ead8f2d08a0ce7843398ddee))

- **router**: Remove handling of SystemExit and KeyboardInterrupt in dispatch method
  ([`fc8a98a`](https://github.com/MountainGod2/cb-events/commit/fc8a98ac2b07433aa15f1935d1d8fc1387dc9322))

### Testing

- Enhance error handling in EventClient tests and add new exception tests
  ([`ba0ceb1`](https://github.com/MountainGod2/cb-events/commit/ba0ceb1336f562558b1035a89f159fbcbb0e2407))


## v3.0.1 (2025-10-10)

### Bug Fixes

- **docs**: Corrected event handling examples and descriptions
  ([`82c148f`](https://github.com/MountainGod2/cb-events/commit/82c148f10aa5b65e30c6e300c42c614d186cfb7c))

### Chores

- **deps**: Update astral-sh/setup-uv digest to 3495667
  ([`88dfaf1`](https://github.com/MountainGod2/cb-events/commit/88dfaf1331ae3b7be696e91b1c9daf0a4e597f82))

- **deps**: Update astral-sh/setup-uv digest to 6d2eb15
  ([`43e466f`](https://github.com/MountainGod2/cb-events/commit/43e466f8cf8f612cb9167bbef2c5bd1e76a8d39b))

- **deps**: Update dependency pyright to v1.1.406
  ([`d3c6a54`](https://github.com/MountainGod2/cb-events/commit/d3c6a54d52c9d6fd6e649ae3bb692e690f0f2d67))

- **deps**: Update github/codeql-action digest to 6fd4ceb
  ([#20](https://github.com/MountainGod2/cb-events/pull/20),
  [`143f801`](https://github.com/MountainGod2/cb-events/commit/143f801eef6ff35252a5cafed2da5652c718a1ec))

- **deps**: Update pre-commit hook adhtruong/mirrors-typos to v1.37.0
  ([#21](https://github.com/MountainGod2/cb-events/pull/21),
  [`c4370ac`](https://github.com/MountainGod2/cb-events/commit/c4370accde13abd74494645534340cc72504e8c3))

- **deps**: Update pre-commit hook adhtruong/mirrors-typos to v1.37.1
  ([`d4e1d3d`](https://github.com/MountainGod2/cb-events/commit/d4e1d3d96edb26345987862a301124c44d40dfb7))


## v3.0.0 (2025-10-09)

### Bug Fixes

- **config**: Add validation for retry max delay against retry backoff
  ([`58bd2b2`](https://github.com/MountainGod2/cb-events/commit/58bd2b277569f9ed085b7707d94cebc15c4b3083))

### Chores

- **deps**: Update astral-sh/setup-uv digest to eb1897b
  ([#19](https://github.com/MountainGod2/cb-events/pull/19),
  [`a6b30e0`](https://github.com/MountainGod2/cb-events/commit/a6b30e0da3e82d01a1fa5285bd354b8285d9fa38))

### Refactoring

- **client**: Implement shared rate limiters for event handling and clear them before tests
  ([`f8ae923`](https://github.com/MountainGod2/cb-events/commit/f8ae923cd1a815b554635ba8a0ebd9b59787dae5))

- **client**: Remove redundant comments and streamline initialization in EventClient
  ([`724271a`](https://github.com/MountainGod2/cb-events/commit/724271a4cf7ae18ea8b20f5f23ac35039fd0caf2))

- **client**: Streamline error handling by consolidating response status checks and utilizing
  CLOUDFLARE_ERROR_CODES
  ([`966bbe4`](https://github.com/MountainGod2/cb-events/commit/966bbe48f01fde52ffc4f723ad237f888d58e971))

- **config**: Migrate EventClientConfig to use Pydantic for improved validation and configuration
  management
  ([`2e6ba15`](https://github.com/MountainGod2/cb-events/commit/2e6ba15bd20eb07d7c097d656ed92de89242c92c))

- **constants**: Remove unnecessary comments and streamline constant definitions
  ([`0931794`](https://github.com/MountainGod2/cb-events/commit/09317943079e0c729049c564dc7a26cee815f782))

- **example**: Simplify event dispatching by removing error handling logic
  ([`247287d`](https://github.com/MountainGod2/cb-events/commit/247287d0b2ce0e3abb31689a2bbc2852173637a4))

- **exceptions**: Simplify RouterError class by removing unnecessary attributes and improving
  documentation
  ([`1f97a21`](https://github.com/MountainGod2/cb-events/commit/1f97a21af60bd1db9fee7ff1181760304545d3b2))

- **models**: Remove redundant comments in EventType and Message classes
  ([`d189568`](https://github.com/MountainGod2/cb-events/commit/d1895684e784ff99902ffc87283e385b32f99506))

- **models**: Simplify boolean checks and optimize membership testing in Message and Event classes
  ([`809af39`](https://github.com/MountainGod2/cb-events/commit/809af39ebf2d6786546e3b86bc4f6805399edffd))

- **router**: Remove unnecessary comments
  ([`bad3bad`](https://github.com/MountainGod2/cb-events/commit/bad3bad7bae43beb8dd6e84c6f638271fcd55d6e))

- **router**: Simplify event dispatching and improve error handling with RouterError
  ([`c7b5318`](https://github.com/MountainGod2/cb-events/commit/c7b5318b627a016af852718af8ed46d00292a634))

- **router**: Unify handler registry and improve event dispatching logic
  ([`64386cf`](https://github.com/MountainGod2/cb-events/commit/64386cf65c4a06ed579f94203824f6f196acf4bc))

- **tests**: Enhance validation error handling in EventClientConfig tests
  ([`0665c8e`](https://github.com/MountainGod2/cb-events/commit/0665c8e0333fae463f5a6061f521236c9b2cc11c))

- **tests**: Update global handler assertion to use None key in EventRouter tests
  ([`20cfbce`](https://github.com/MountainGod2/cb-events/commit/20cfbce297216012924742196d1d09737f4b2017))

- **tests**: Update RouterError tests to use EventType constants and remove redundant cases
  ([`4a0f7fb`](https://github.com/MountainGod2/cb-events/commit/4a0f7fb2b4d2721b8c44eb80151e5996aa175799))


## v2.5.0 (2025-10-08)

### Chores

- **deps**: Update astral-sh/setup-uv digest to f610be5
  ([`192a753`](https://github.com/MountainGod2/cb-events/commit/192a7530152f33c03cbd4e13d74f4e0e121fdad6))

- **deps**: Update github/codeql-action digest to 5528384
  ([`d9e86d7`](https://github.com/MountainGod2/cb-events/commit/d9e86d755c80ab6be6b19e90ddaac28e556af47a))

### Features

- Add error handling modes and RouterError for event dispatching
  ([`e1999cc`](https://github.com/MountainGod2/cb-events/commit/e1999ccb0cf5f48de3e2b7e3ec88e2dbc0a0782b))

### Refactoring

- Enhance event router documentation and improve error handling logic
  ([`d98aabd`](https://github.com/MountainGod2/cb-events/commit/d98aabdca1ffe1336cd024d09b74d0de697c156c))


## v2.4.3 (2025-10-07)

### Bug Fixes

- **docs**: Suppress duplicate object warnings in AutoAPI configuration
  ([`65c5978`](https://github.com/MountainGod2/cb-events/commit/65c597844ba13b69cc3e077a8c53edc8bac89992))


## v2.4.2 (2025-10-07)

### Bug Fixes

- **docs**: Update build command to allow AutoAPI duplicate warnings
  ([`caf9c15`](https://github.com/MountainGod2/cb-events/commit/caf9c1511cf9bcb06f6959b233a3e42a7c76af8f))

### Refactoring

- **docs**: Enhance documentation across modules with detailed descriptions and examples
  ([`b63effe`](https://github.com/MountainGod2/cb-events/commit/b63effe8af7943a5e6fe93783c3ff055fac6d326))

- **docs**: Suppress duplicate object warnings and additional autoapi warnings
  ([`2688f95`](https://github.com/MountainGod2/cb-events/commit/2688f95c932c481bd7a3c58e6b83a1a939356dc1))


## v2.4.1 (2025-10-07)

### Bug Fixes

- **client**: Improve resource cleanup in close method with locking mechanism
  ([`ff71761`](https://github.com/MountainGod2/cb-events/commit/ff71761ba2443347c3d71cd44fffc0b3bbe1ec75))

- **pylint**: Increase max attributes limit from 10 to 12
  ([`f26817e`](https://github.com/MountainGod2/cb-events/commit/f26817e514f2c31686a396d1a7fbf14420d1cbf8))

### Chores

- **clean**: Remove SARIF files during cleanup
  ([`aae48a6`](https://github.com/MountainGod2/cb-events/commit/aae48a6727eb4321a1d28a52b8e1fa8e2da6e862))

- **deps**: Lock file maintenance
  ([`3c57df3`](https://github.com/MountainGod2/cb-events/commit/3c57df3724ffeafe1c54397530b441efadf1f97d))

- **deps**: Update actions/attest-build-provenance digest to 3752c92
  ([`87804c2`](https://github.com/MountainGod2/cb-events/commit/87804c2a100003a7f63c5d17077fa13372fc29ed))

- **deps**: Update actions/attest-build-provenance digest to bed76f6
  ([`6809828`](https://github.com/MountainGod2/cb-events/commit/6809828480e9799fc56edec7256370578d1bb0f5))

### Refactoring

- **imports**: Consolidate exception imports
  ([`04fa725`](https://github.com/MountainGod2/cb-events/commit/04fa725e1ec65d3456acd7f76d6e2b4f8b5f4172))


## v2.4.0 (2025-10-05)

### Chores

- **deps**: Update actions/checkout digest to ff7abcd
  ([#14](https://github.com/MountainGod2/cb-events/pull/14),
  [`0ae19ac`](https://github.com/MountainGod2/cb-events/commit/0ae19acf5603ab9f9e88e32dcc25b98ff6ebd5da))

- **deps**: Update actions/download-artifact digest to 4a24838
  ([#15](https://github.com/MountainGod2/cb-events/pull/15),
  [`538a229`](https://github.com/MountainGod2/cb-events/commit/538a2290b92bba27e306a72a02ac854ac2b1903b))

- **deps**: Update actions/upload-artifact digest to 2848b2c
  ([#16](https://github.com/MountainGod2/cb-events/pull/16),
  [`28852d3`](https://github.com/MountainGod2/cb-events/commit/28852d39e9ded40d80a9520340583d7ee3f6f54c))

- **deps**: Update astral-sh/setup-uv digest to d9ee7e2
  ([#17](https://github.com/MountainGod2/cb-events/pull/17),
  [`61a4db0`](https://github.com/MountainGod2/cb-events/commit/61a4db0cf493292e8a98c5a547d26b03956779b7))

- **deps**: Update github/codeql-action digest to 065c6cf
  ([#18](https://github.com/MountainGod2/cb-events/pull/18),
  [`5a97c5f`](https://github.com/MountainGod2/cb-events/commit/5a97c5f5e29f95277739ae2ca52107eaa1c74c04))

- **deps**: Update pypa/gh-action-pypi-publish digest to ab69e43
  ([`db639b9`](https://github.com/MountainGod2/cb-events/commit/db639b91d61db0bf603b792fdb3f9de69638ad48))

### Documentation

- **copilot**: Enhance commit message guidelines with specific examples and actionable verbs
  ([`518dd5e`](https://github.com/MountainGod2/cb-events/commit/518dd5e0c76c2f8062faefeab16396e4ace2989b))

- **copilot**: Enhance documentation with development standards and usage patterns
  ([`44d88e3`](https://github.com/MountainGod2/cb-events/commit/44d88e3277bf56d744fc483af3f7b7d5077bf1ca))

- **copilot**: Refine commit message guidelines to discourage vague terms
  ([`7565a8a`](https://github.com/MountainGod2/cb-events/commit/7565a8a64a9a901789fc6c0c61c6396329c58942))

- **copilot**: Update commit message guidelines to avoid vague terms
  ([`3932231`](https://github.com/MountainGod2/cb-events/commit/3932231cb86774fbf49f338f6f170af2fb1216fb))

- **copilot**: Update commit message guidelines to specify language usage
  ([`155a803`](https://github.com/MountainGod2/cb-events/commit/155a803f1fdc96e986cd3a5e641322c0845809d1))

### Features

- **ci-cd**: Add attestations permissions and step for build provenance
  ([`e3a58c0`](https://github.com/MountainGod2/cb-events/commit/e3a58c03144b80cd50f2e67c8d37eab32f9e3967))

### Refactoring

- **ci-cd**: Improve job descriptions and steps
  ([`5698980`](https://github.com/MountainGod2/cb-events/commit/56989807b9083a123c132978f0d9f8816b00e5af))

- **ci-cd**: Modify workflow structure and update job definitions
  ([`bb1d04a`](https://github.com/MountainGod2/cb-events/commit/bb1d04a651f1360086a4f304db6ed25a8fe491cc))

- **ci-cd**: Streamline workflow jobs and improve naming conventions
  ([`4702b90`](https://github.com/MountainGod2/cb-events/commit/4702b9069f8aadcd3ff612e412c82b58437b65dc))


## v2.3.7 (2025-10-04)

### Bug Fixes

- **docs**: Update license links to use absolute URLs
  ([`d1da265`](https://github.com/MountainGod2/cb-events/commit/d1da26582b61b97eb1679d124317057220f6d1b4))

### Chores

- **docs**: Remove unused autodoc Pydantic configuration
  ([`b0da7e8`](https://github.com/MountainGod2/cb-events/commit/b0da7e8bd9f3a3317049219e7236df81f13ea55b))

### Documentation

- **conf**: Remove unused sphinxcontrib.autodoc_pydantic extension
  ([`377f3d4`](https://github.com/MountainGod2/cb-events/commit/377f3d49c19efb106e4988d0f6c607234a611d5c))

### Refactoring

- **config**: Simplify EventClientConfig docstring
  ([`ccc7fb5`](https://github.com/MountainGod2/cb-events/commit/ccc7fb59fe5c241ade6e827a6daf87bd2ca666d0))


## v2.3.6 (2025-10-03)

### Bug Fixes

- Update project URLs to reflect the correct repository name
  ([`d45d2e9`](https://github.com/MountainGod2/cb-events/commit/d45d2e98626f009b096c21fe3cbc613df8b0e503))


## v2.3.5 (2025-10-03)

### Bug Fixes

- **ci/cd**: Update SARIF upload action to a newer version
  ([`5fd1e0a`](https://github.com/MountainGod2/cb-events/commit/5fd1e0a9fc3197969cf17e33fedafd307014fbcc))


## v2.3.4 (2025-10-03)

### Bug Fixes

- **ci/cd**: Remove unnecessary setup and conditions
  ([`c5df60b`](https://github.com/MountainGod2/cb-events/commit/c5df60be6a99c160a674f7dfa61db1c904a5ece1))

- **ci/cd**: Update SARIF upload action and improve artifact handling
  ([`7706b3b`](https://github.com/MountainGod2/cb-events/commit/7706b3be0a464857ac9b70d4d6b8970109fd3369))


## v2.3.3 (2025-10-03)

### Bug Fixes

- **ci/cd**: Remove environment variables for package and wheel names in deployment steps
  ([`f95180d`](https://github.com/MountainGod2/cb-events/commit/f95180d4a586d82414dacf92b00ac60106f8ff23))


## v2.3.2 (2025-10-03)

### Bug Fixes

- **ci/cd**: Use environment variables for package and wheel names in install and deploy steps
  ([`ab2a7b4`](https://github.com/MountainGod2/cb-events/commit/ab2a7b4760ad5da274cecdb07130f9030e8aaf81))

### Chores

- **deps**: Update github/codeql-action digest to 64d10c1
  ([`35272ec`](https://github.com/MountainGod2/cb-events/commit/35272ec6e51a6c16738d92af16231e55caccfc2c))

- **deps**: Update pre-commit hook adhtruong/mirrors-typos to v1.36.3
  ([`60a84b5`](https://github.com/MountainGod2/cb-events/commit/60a84b56b45884f15b60664d11cf5c97966c180d))


## v2.3.1 (2025-10-03)

### Bug Fixes

- **ci/cd**: Add read permission for actions in security scan job
  ([`07b5cd0`](https://github.com/MountainGod2/cb-events/commit/07b5cd046ae8b34b6f03a40665a8a45c6ddd2f26))


## v2.3.0 (2025-10-03)

### Bug Fixes

- **ci/cd**: Consolidate permissions for security events and contents in CI/CD workflow
  ([`96e5f4e`](https://github.com/MountainGod2/cb-events/commit/96e5f4ecfa74b140dcbe624a486d8ddf9abb0483))

- **ci/cd**: Update permissions and enhance security scanning steps in CI/CD workflow
  ([`000ad71`](https://github.com/MountainGod2/cb-events/commit/000ad71f0172cd24a49a78f5117453a5dd36fc47))

- **ci/cd**: Update permissions to allow write access for contents and security events
  ([`3f88370`](https://github.com/MountainGod2/cb-events/commit/3f883702fc3329af2619b0fce976b799a80075f3))

### Chores

- **deps**: Remove autodoc-pydantic dependency from docs requirements
  ([`9eafc61`](https://github.com/MountainGod2/cb-events/commit/9eafc61ea81d67514633b112740a66e7f008ea12))

- **deps**: Update dependency furo to v2025.9.25
  ([`349c50b`](https://github.com/MountainGod2/cb-events/commit/349c50b606896af43cd3b81614030bd25ed8f168))

### Features

- **security**: Add Trivy vulnerability scanning to CI/CD pipeline and Makefile
  ([`d36299d`](https://github.com/MountainGod2/cb-events/commit/d36299d4e5a90d00a572a94ba20e0c895b53710a))

- **security**: Integrate Bandit for security scanning and upload SARIF results
  ([`0d9a319`](https://github.com/MountainGod2/cb-events/commit/0d9a3199fe7bd537efefc7433814b0905b378663))

### Refactoring

- **lint**: Remove specific ruff ignores from example script and update per-file ignores
  ([`5cffc8e`](https://github.com/MountainGod2/cb-events/commit/5cffc8ee887aba17b1d04e59f2cf3b3f0c1a2d87))


## v2.2.0 (2025-10-02)

### Features

- **security**: Add bandit for security scanning
  ([`67ac009`](https://github.com/MountainGod2/cb-events/commit/67ac009f48ea9d0076cc0ba32a5fb09f7fba612c))


## v2.1.0 (2025-10-02)

### Chores

- **deps**: Update dependency ruff to v0.13.2
  ([`4c13ae1`](https://github.com/MountainGod2/cb-events/commit/4c13ae18dd96cb93c8867d5ac9d36b6fdffa9a05))

- **deps**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.13.2
  ([`12af5ca`](https://github.com/MountainGod2/cb-events/commit/12af5ca78f449d00381a0570c27fdd36dd6147e5))

### Features

- **deps**: Add pylint-pydantic for enhanced linting support
  ([`93daedb`](https://github.com/MountainGod2/cb-events/commit/93daedb79010f40b81c02068d4d048054cc8627b))

### Refactoring

- **models**: Remove pylint disable comments for user data access
  ([`60cee53`](https://github.com/MountainGod2/cb-events/commit/60cee53242180c40081928ebe339e9303d96fc62))

- **pylint**: Remove unused message control settings and adjust max attributes
  ([`1045f54`](https://github.com/MountainGod2/cb-events/commit/1045f54079e27e480b9402be76445ad9b088939a))


## v2.0.0 (2025-10-02)

### Chores

- **deps**: Update astral-sh/setup-uv digest to d0cc045
  ([`bc47524`](https://github.com/MountainGod2/cb-events/commit/bc4752451746e5994b7c029a41280110d463f613))

### Documentation

- **example**: Update docstring
  ([`29aa02e`](https://github.com/MountainGod2/cb-events/commit/29aa02ebd190361c7c7ebbbd989ee9227aba76a1))

- **index**: Updated to match README
  ([`a8a4c52`](https://github.com/MountainGod2/cb-events/commit/a8a4c52b0e36047b57147ffe9d62663b27abbe65))

- **pyproject**: Increase max-attributes limit
  ([`a67407d`](https://github.com/MountainGod2/cb-events/commit/a67407d64d41d174843fb0aa1a58463d044fce35))

### Refactoring

- **client**: Improve error handling in EventClient response processing
  ([`ee104ab`](https://github.com/MountainGod2/cb-events/commit/ee104abd409562202724492fde52153e8767d220))

- **client**: Improve logging configuration
  ([`2e270c6`](https://github.com/MountainGod2/cb-events/commit/2e270c6460499dfe6388eb0ad53c461030731a76))

- **client**: Improve logging configuration
  ([`eacbf8c`](https://github.com/MountainGod2/cb-events/commit/eacbf8c1478ec1c1eecdbc2072e1658795504a8d))

- **client**: Simplify error handling and JSON parsing in EventClient
  ([`de72f0d`](https://github.com/MountainGod2/cb-events/commit/de72f0d55ca5ec6a15f7855edf568bfa16038093))

- **config**: Make EventClientConfig dataclass immutable
  ([`cd63846`](https://github.com/MountainGod2/cb-events/commit/cd63846db0cd2ef456ef08b72ac88646d411170c))

- **constants**: Update HTTP status codes for error handling
  ([`dfd3f4a`](https://github.com/MountainGod2/cb-events/commit/dfd3f4a89e20b572135ad2560aa2af82525ce31b))

- **example**: Enhance event handling and improve documentation in example.py
  ([`f3bc6d0`](https://github.com/MountainGod2/cb-events/commit/f3bc6d07320de2f7283b06e9685ff1290038c91a))

- **init**: Add EventHandler to module exports
  ([`56c7388`](https://github.com/MountainGod2/cb-events/commit/56c7388bd2b4155968de1f9748f733a8e7788702))

- **logging**: Standardize logger usage in EventClient and EventRouter
  ([`496a8b0`](https://github.com/MountainGod2/cb-events/commit/496a8b0bf81fbf3bc581835a2957556b8ed7ac17))

- **models**: Remove pylint disable comments for member access
  ([`9447fa2`](https://github.com/MountainGod2/cb-events/commit/9447fa2b33913623d5caf7e5918a322af0c748ff))

- **pre-commit**: Replace pip-audit repo with local configuration
  ([`9693f8f`](https://github.com/MountainGod2/cb-events/commit/9693f8f931f1061023933897719608332373bab2))

- **router**: Add stricter event type handling
  ([`1998d65`](https://github.com/MountainGod2/cb-events/commit/1998d65a510465c13325f08808b67bd526e36db8))

- **tests**: Add e2e marker to TestIntegration class
  ([`ed0a919`](https://github.com/MountainGod2/cb-events/commit/ed0a919dc7d4d46da02afd0515ca014c722daf99))

- **tests**: Remove obsolete test_config.py, enhance test_e2e.py, add test_exceptions.py, and
  streamline model tests
  ([`abf4538`](https://github.com/MountainGod2/cb-events/commit/abf45380b483ef395e5e94ea4373623f5332440e))

- **tests**: Remove redundant server error handling test from TestEventClient
  ([`7428912`](https://github.com/MountainGod2/cb-events/commit/7428912c4711784cf238836989dea9fadf55f1b2))

- **tests**: Remove redundant tests from TestEventClientConfig
  ([`d451a9a`](https://github.com/MountainGod2/cb-events/commit/d451a9a643b877595fb4b874bfed67bbe96ab6c1))

- **tests**: Update per-file ignores and adjust coverage fail threshold
  ([`bbdf5aa`](https://github.com/MountainGod2/cb-events/commit/bbdf5aa0119170fff80c36b61b7cc061e6195555))

- **tests**: Update rate limit handling test
  ([`4e1cee3`](https://github.com/MountainGod2/cb-events/commit/4e1cee3191b7a2767b6853ee16d9520557029c4a))


## v1.13.0 (2025-09-29)

### Chores

- **deps**: Lock file maintenance
  ([`23e82c5`](https://github.com/MountainGod2/cb-events/commit/23e82c5c7edff080423ea458c277d047c05e6c82))

### Documentation

- **config**: Update docstring to clarify attributes of EventClientConfig
  ([`678ed15`](https://github.com/MountainGod2/cb-events/commit/678ed158295048e58f342929c856d02cee24298e))

- **README**: Update usage instructions
  ([`8a67c9e`](https://github.com/MountainGod2/cb-events/commit/8a67c9e208c5cb922c63aae3dbb69d18f8675331))

### Features

- **router**: Add logging for event dispatching
  ([`47754e9`](https://github.com/MountainGod2/cb-events/commit/47754e9f5a1b0d95948da5033282f4575b79ed4a))

### Refactoring

- **constants**: Reorganize retry attributes
  ([`cd7eabb`](https://github.com/MountainGod2/cb-events/commit/cd7eabb067e80e5d1c33c3eac2bd8f6568c2417a))

### Testing

- **client**: Add tests for session management and timeout response handling
  ([`7b6b5f2`](https://github.com/MountainGod2/cb-events/commit/7b6b5f225c38c19b2768786daac244e366ffa80c))


## v1.12.0 (2025-09-29)

### Features

- **models**: Add is_private property to determine message type
  ([`ae04d36`](https://github.com/MountainGod2/cb-events/commit/ae04d366f2efc2a9ce7d5a36a7bd1ebdb47c9b7d))


## v1.11.1 (2025-09-28)

### Bug Fixes

- Update references from 'chaturbate-events' to 'cb-events'
  ([`bdcb541`](https://github.com/MountainGod2/cb-events/commit/bdcb54126c5bb8187b794a91dc80abb5026dc41e))

- **semantic-release**: Add patterns for docs and initial commit to exclude commit patterns
  ([`859dd31`](https://github.com/MountainGod2/cb-events/commit/859dd3114c696a9a9b93e52615b9e650c41c865f))

### Refactoring

- **all**: Change project name from 'chaturbate-events' to 'cb-events'
  ([`877355a`](https://github.com/MountainGod2/cb-events/commit/877355a8d4f7b756cc44ad25665f1eec8b5ff3c9))


## v1.11.0 (2025-09-27)

### Bug Fixes

- **Dockerfile**: Add '-u' flag to python entrypoint for unbuffered output
  ([`8984894`](https://github.com/MountainGod2/chaturbate-events/commit/898489447b3c941767c49c45fb441d8e965c812b))

### Chores

- **pyproject**: Update organization
  ([`8c3a264`](https://github.com/MountainGod2/chaturbate-events/commit/8c3a26491ebf989a79128b75a2f473d414c355cf))

### Features

- **config**: Add example environment file for Chaturbate API credentials
  ([`c607eda`](https://github.com/MountainGod2/chaturbate-events/commit/c607eda015f0ce40bf0dbfcd381545ddf51d9f74))

### Refactoring

- **client**: Remove redundant asterisk in EventClient constructor parameters
  ([`2376cdd`](https://github.com/MountainGod2/chaturbate-events/commit/2376cdd8c557c7cffe68795c610a2a916c82d3f9))


## v1.10.0 (2025-09-26)

### Chores

- **deps**: Update dev-tools
  ([`50adc7e`](https://github.com/MountainGod2/chaturbate-events/commit/50adc7e8cc6a9c18f3efce3b3153bd8d0b321d25))

### Documentation

- Add autodoc-pydantic and settings
  ([`7972be7`](https://github.com/MountainGod2/chaturbate-events/commit/7972be7ab233aaee2a300b6faae12756c94b0d6f))

- **README**: Refactor error handling in example
  ([`867bd48`](https://github.com/MountainGod2/chaturbate-events/commit/867bd48d7bce3358aad824fc2606d14dcdd45134))

### Features

- Add Cloudflare error handling and retry tests in EventClient
  ([`4025f06`](https://github.com/MountainGod2/chaturbate-events/commit/4025f06f313c368c023e7d071de7c1a2e55ce878))

- Introduce EventClientConfig for improved configuration management
  ([`d72090f`](https://github.com/MountainGod2/chaturbate-events/commit/d72090f33489ed026437eec1b97b4129a4e3b655))

- Refactor EventClient initialization to use EventClientConfig for improved configuration management
  ([`6047035`](https://github.com/MountainGod2/chaturbate-events/commit/60470353be78730b198392a69211be9171dae6f1))

### Testing

- Add tests for EventClientConfig validation
  ([`9d2eb63`](https://github.com/MountainGod2/chaturbate-events/commit/9d2eb63408485e2ac1f0ad3fba30ee5ab92157d6))


## v1.9.0 (2025-09-24)

### Bug Fixes

- Update uv dependency to version 0.8.22 in Dockerfile
  ([`b7356c0`](https://github.com/MountainGod2/chaturbate-events/commit/b7356c023bfd6b1c555abd84c8eb8224e2a9e27d))

### Chores

- **deps**: Update dependency pytest-mock to v3.15.1
  ([`47b38c5`](https://github.com/MountainGod2/chaturbate-events/commit/47b38c5a49094f36836427a0aca0ee70511bbb4c))

- **deps**: Update pre-commit hook versions for ruff, mypy, and check-jsonschema
  ([`6f9476a`](https://github.com/MountainGod2/chaturbate-events/commit/6f9476abe3c636413b5872e38dc1cc0ddc2d9b03))

### Features

- Add Dockerfile and .dockerignore for containerization
  ([`60b691b`](https://github.com/MountainGod2/chaturbate-events/commit/60b691bfa9607e90ff2d8843ceb5804c6d89e247))

- Add python-version configuration for pyrefly tool
  ([`6abab23`](https://github.com/MountainGod2/chaturbate-events/commit/6abab23d4da331b99452265e3be044708099b875))

### Refactoring

- Enhance test coverage for Event models and EventRouter functionality
  ([`24878f1`](https://github.com/MountainGod2/chaturbate-events/commit/24878f1316d36291ed006f69a56727bdb3537182))

- Improve graceful shutdown handling in example script
  ([`df5d02f`](https://github.com/MountainGod2/chaturbate-events/commit/df5d02f766f4f708fe087ef4229442323e0a94b4))

- Move create_url_pattern function to test_client.py and remove unused import from conftest.py
  ([`32c7ab3`](https://github.com/MountainGod2/chaturbate-events/commit/32c7ab3aef339875334526b0a1d737aa51f2b59c))

- Remove is_private property from Message model
  ([`0bf2fb0`](https://github.com/MountainGod2/chaturbate-events/commit/0bf2fb07855306b6fc2f542d90ef7858664ba954))

- Update default retry attempts to 8 and adjust documentation accordingly
  ([`a878d1c`](https://github.com/MountainGod2/chaturbate-events/commit/a878d1c13a97953a1e3a19556698f6188f0c98d1))


## v1.8.0 (2025-09-22)

### Chores

- **deps**: Lock file maintenance
  ([`5a20dea`](https://github.com/MountainGod2/chaturbate-events/commit/5a20dea6cf61fba522e06b7b0654f1955a5720e0))

### Features

- Enhance EventClient with configurable retry logic for network errors
  ([`bcd4b38`](https://github.com/MountainGod2/chaturbate-events/commit/bcd4b384ee148a99abb900038e8fc0ca482d6de9))

### Refactoring

- Formatted to conform with updated line length settings
  ([`2240311`](https://github.com/MountainGod2/chaturbate-events/commit/224031147e6ca5af764f2d3ee5006b2ac7eba062))

- Improve event handling messages and clarify credential validation
  ([`05af4c6`](https://github.com/MountainGod2/chaturbate-events/commit/05af4c60fe4353f891221bd9cbbfce040f2ccac4))

- Remove obsolete Python version and funding link from pyproject.toml
  ([`b84da0a`](https://github.com/MountainGod2/chaturbate-events/commit/b84da0adf3e8327eabb9134a19965c7fe812b502))


## v1.7.0 (2025-09-20)

### Bug Fixes

- Update CI/CD workflow and Makefile to use 'make test-e2e' for end-to-end tests
  ([`f5e3379`](https://github.com/MountainGod2/chaturbate-events/commit/f5e3379e7312791d895e4f274730abd582f44404))

### Features

- Refactor EventClient and introduce constants for improved configuration and error handling
  ([`0c6576d`](https://github.com/MountainGod2/chaturbate-events/commit/0c6576d7d2b7b2b44d27687b23884cf2c4f4b72c))

### Refactoring

- Remove test_config.py
  ([`0918753`](https://github.com/MountainGod2/chaturbate-events/commit/091875360a4491641b6145f81dfdc285b9ed48ca))

- **tests**: Move e2e tests into main test module
  ([`d390688`](https://github.com/MountainGod2/chaturbate-events/commit/d390688b2c15746f54906cd99f4cd3faa2183603))

### Testing

- **lint**: Add rules for logging exceptions and hardcoded credentials in tests
  ([`e13cb6c`](https://github.com/MountainGod2/chaturbate-events/commit/e13cb6c007e3e8273e53a7b3eefea6334feed83f))


## v1.6.1 (2025-09-20)

### Bug Fixes

- **deps**: Update dependency pydantic to v2.11.9
  ([#13](https://github.com/MountainGod2/chaturbate-events/pull/13),
  [`87459bd`](https://github.com/MountainGod2/chaturbate-events/commit/87459bd6d00ff585cbd3dd63a3fc31c2ebc5c20d))

### Chores

- **deps**: Lock file maintenance
  ([`bcb49da`](https://github.com/MountainGod2/chaturbate-events/commit/bcb49da0b71f061d1111aa8e446d7bdacb11283f))

- **deps**: Update dependency mypy to v1.18.1
  ([`c3fe901`](https://github.com/MountainGod2/chaturbate-events/commit/c3fe901241590323f172e52535243baf689e5a63))

- **deps**: Update dependency pytest-asyncio to v1.2.0
  ([`56971c7`](https://github.com/MountainGod2/chaturbate-events/commit/56971c72cd63a96d320fb2e797d4977c6de77e86))

- **deps**: Update dependency python-semantic-release to v10.4.1
  ([`1f2cad7`](https://github.com/MountainGod2/chaturbate-events/commit/1f2cad7ebd0fc656ec9d1fbc8f08b2be15ddc5d6))

- **deps**: Update dependency ruff to v0.13.0
  ([`ea9f0da`](https://github.com/MountainGod2/chaturbate-events/commit/ea9f0da5ea21ff1dcd748ac79d56c9299db44153))

- **deps**: Update pre-commit hook pre-commit/mirrors-mypy to v1.18.1
  ([`b48f664`](https://github.com/MountainGod2/chaturbate-events/commit/b48f6640b861df1b7f1e81e282dc5e01ea8e2ab0))

- **docs**: Remove unused sphinx-copybutton and sphinx-design dependencies
  ([`fe12847`](https://github.com/MountainGod2/chaturbate-events/commit/fe12847d69f6f1e05fc976d210cf59c60717be1d))

### Refactoring

- **ci-cd**: Update end-to-end test command to filter by e2e marker
  ([`4f13743`](https://github.com/MountainGod2/chaturbate-events/commit/4f137433f5a0844e40b47a097fed441d6a618ad6))

- **client**: Include event types in debug output
  ([`01b9dbd`](https://github.com/MountainGod2/chaturbate-events/commit/01b9dbd187cca76962226d86f2d232c5576f7de9))

- **client**: Replace aiohttp references with specific imports and add rate limiter to polling
  ([`49fda32`](https://github.com/MountainGod2/chaturbate-events/commit/49fda328bd31843de46c85234bca37ce7fc45ad6))

- **example**: Remove unused __init__.py file from examples directory
  ([`9c58f84`](https://github.com/MountainGod2/chaturbate-events/commit/9c58f8401804a6108d174a9d1cdffe42c8123281))

- **example**: Simplify tip event handler and remove message handlers
  ([`314085e`](https://github.com/MountainGod2/chaturbate-events/commit/314085e02c75ff2e5f4b7a8746fee1556b325bc7))

- **exceptions**: Remove extra_info parameter from EventsError initialization
  ([`cacb857`](https://github.com/MountainGod2/chaturbate-events/commit/cacb8575bdda43b631c714fbf1f1522f412c7937))

- **pyproject**: Update Python classifiers and ruff linting rules, enhance pytest options
  ([`566d270`](https://github.com/MountainGod2/chaturbate-events/commit/566d270083d270d54645b65f4b4fd3e011d2b621))

- **tests**: Add missing e2e marker to test functions in test_e2e.py
  ([`2e0e41e`](https://github.com/MountainGod2/chaturbate-events/commit/2e0e41e926ac2969b853a6364e660585d0671104))

- **tests**: Remove obsolete integration test for EventClient and EventRouter
  ([`74187df`](https://github.com/MountainGod2/chaturbate-events/commit/74187dfffa02ae91e5203062e4209d51cde429ee))


## v1.6.0 (2025-09-16)

### Bug Fixes

- Reorganize imports for consistency across test files
  ([`f0fd75c`](https://github.com/MountainGod2/chaturbate-events/commit/f0fd75c11b7e9f666e48bf20ed180901dfa0ee86))

- **docs**: Update deployment environment name to match GitHub Pages convention
  ([`c3709c6`](https://github.com/MountainGod2/chaturbate-events/commit/c3709c69355f2bdcadb29fcc5e15ec3cfd8028b0))

### Chores

- Remove obsolete documentation workflow
  ([`b44b425`](https://github.com/MountainGod2/chaturbate-events/commit/b44b4258fbc3c5bd01fb915e08ebd26939af055a))

- **deps**: Update astral-sh/setup-uv digest to b75a909
  ([`cc10b6d`](https://github.com/MountainGod2/chaturbate-events/commit/cc10b6d70864d9eab33fa9f0d8ccdfc0d886b94e))

- **deps**: Update dependency pytest-cov to v6.3.0
  ([`81696dc`](https://github.com/MountainGod2/chaturbate-events/commit/81696dcec549e99fdc4e62dff183afea89916488))

- **deps**: Update dependency pytest-cov to v7
  ([#10](https://github.com/MountainGod2/chaturbate-events/pull/10),
  [`96be89f`](https://github.com/MountainGod2/chaturbate-events/commit/96be89fa75f0179e57832f8a6366258beeb24100))

- **deps**: Update dependency python-semantic-release to v10.3.2
  ([`06a7995`](https://github.com/MountainGod2/chaturbate-events/commit/06a79950012963f417fd2c8d38b20911cd8f9aec))

- **deps**: Update dependency python-semantic-release to v10.4.0
  ([`4ae3c90`](https://github.com/MountainGod2/chaturbate-events/commit/4ae3c90234eca1ed0cd51472087b388e803c7f1b))

- **gitignore**: Expanded ignored files
  ([`5e09024`](https://github.com/MountainGod2/chaturbate-events/commit/5e09024e166525c3fe66b1b368495f3b17813c7b))

### Features

- **docs**: Added sphinx auto-doc pipeline
  ([`da2ddf4`](https://github.com/MountainGod2/chaturbate-events/commit/da2ddf4f7677377503a153cc988fdf26754c5464))

### Refactoring

- **client**: Simplify error handling in nextUrl extraction
  ([`06887e4`](https://github.com/MountainGod2/chaturbate-events/commit/06887e4f47b98d54c3ec30a6e96ef034b2b9abbf))

- **exceptions**: Simplify exception class documentation and imports
  ([`76653d7`](https://github.com/MountainGod2/chaturbate-events/commit/76653d7276a5be54fc64ad3d9dc550cc6b070d77))

- **tests**: Improve test function names and remove unused tests
  ([`81ca969`](https://github.com/MountainGod2/chaturbate-events/commit/81ca969717110a90462302261c3b47b252f18fd7))


## v1.5.0 (2025-09-13)

### Features

- **pyproject**: Update project metadata with additional keywords and URLs
  ([`daa2dbb`](https://github.com/MountainGod2/chaturbate-events/commit/daa2dbb33a6309994bb9c830b0a2928745561971))


## v1.4.1 (2025-09-13)

### Bug Fixes

- **pyproject**: Add additional classifiers for improved package metadata
  ([`2cebae1`](https://github.com/MountainGod2/chaturbate-events/commit/2cebae14f1ce754727c2f2ce701831b826d337e6))


## v1.4.0 (2025-09-13)

### Chores

- **deps**: Update dependency pyright to v1.1.405
  ([`9c31fff`](https://github.com/MountainGod2/chaturbate-events/commit/9c31fff16ed6f416e1414effdfc5d87608a24317))

- **deps**: Update dependency pytest-mock to v3.15.0
  ([`d6e8016`](https://github.com/MountainGod2/chaturbate-events/commit/d6e80163e00f43849d295afd50517c3fe5751572))

- **deps**: Update dependency ruff to v0.12.11
  ([`645e8ca`](https://github.com/MountainGod2/chaturbate-events/commit/645e8ca74f9f6f1057b6987f07199166773cf774))

- **deps**: Update dev-tools
  ([`651dc2e`](https://github.com/MountainGod2/chaturbate-events/commit/651dc2eb2b4c47e4879f2beb29c4640ed898e52c))

### Documentation

- **README**: Add environment variable setup and error handling sections
  ([`45d5b79`](https://github.com/MountainGod2/chaturbate-events/commit/45d5b79dc60c6041feb858580634e8ade0354e3d))

### Features

- **pyproject**: Add classifiers and project URLs for better package metadata
  ([`fed8e20`](https://github.com/MountainGod2/chaturbate-events/commit/fed8e20a2104c802eaf11b8399e4dbc064e7d18f))

### Refactoring

- **ci-cd**: Update runner version from ubuntu-latest to ubuntu-24.04
  ([`ae30cf3`](https://github.com/MountainGod2/chaturbate-events/commit/ae30cf3409ccdc125decc99c36056bee3461b18e))

- **tests**: Split and reorganize test cases
  ([`7776d0d`](https://github.com/MountainGod2/chaturbate-events/commit/7776d0d12b0a3f10990aea352611a5b084a33a76))


## v1.3.2 (2025-09-11)

### Bug Fixes

- **renovate**: Update minimum release age from 14 days to 7 days
  ([`7923a7d`](https://github.com/MountainGod2/chaturbate-events/commit/7923a7d956a12a982311d50d06efc8b1dae67887))

### Chores

- **deps**: Remove outdated 'ty' dependency from development requirements
  ([`2ca470a`](https://github.com/MountainGod2/chaturbate-events/commit/2ca470a5918339fdbfeac476715bba090a1aec68))

- **deps**: Remove outdated dependency from dev requirements
  ([`2b69943`](https://github.com/MountainGod2/chaturbate-events/commit/2b699437e22e818b4be500656d3c0e7d01eeb694))

- **deps**: Update dependency aioresponses to v0.7.8
  ([`46c64a8`](https://github.com/MountainGod2/chaturbate-events/commit/46c64a8b8f5c164eb687c5143e3f23bafcb526e9))

- **instructions**: Remove trailing whitespace in custom exceptions guideline
  ([`9d597ec`](https://github.com/MountainGod2/chaturbate-events/commit/9d597ece666e1ca5111dda2290764e4cf8fe821f))

- **pre-commit**: Update configuration and add new hooks for additional checks
  ([`9f3b181`](https://github.com/MountainGod2/chaturbate-events/commit/9f3b18174161ad2c7615afe03db6cab8581e1866))

- **pyproject**: Add Bandit configuration to exclude directories and skip specific checks
  ([`4d6a7d8`](https://github.com/MountainGod2/chaturbate-events/commit/4d6a7d811e48e775ba0f9ebdab25b05bfa3054ac))

### Refactoring

- **.gitignore**: Refine IDE settings and ensure ruff cache is ignored
  ([`89faec8`](https://github.com/MountainGod2/chaturbate-events/commit/89faec83d27bd1c9e28f9ffdb43c0bba3b980791))

- **extensions**: Add newline at end of file
  ([`ff6c9e6`](https://github.com/MountainGod2/chaturbate-events/commit/ff6c9e61218118f229c52c8ed1dbeb303864328c))

- **Makefile**: Enhance organization and improve help output
  ([`4b32f94`](https://github.com/MountainGod2/chaturbate-events/commit/4b32f94d446abcb4695483c09153830c99498723))

- **renovate**: Add 'pyright' to dev tools package grouping
  ([`e71957a`](https://github.com/MountainGod2/chaturbate-events/commit/e71957a9ee8faf04b1e60affad83a56ec4aa220d))

- **renovate**: Update schedule and descriptions in package rules
  ([`eb40292`](https://github.com/MountainGod2/chaturbate-events/commit/eb4029287ab5486c01543ea847c0d0c1dbe0ca3e))

- **verify_upstream**: Ensure newline at end of file
  ([`b84df2b`](https://github.com/MountainGod2/chaturbate-events/commit/b84df2bd8aa22bf7a124929965f3ad994a0efc77))


## v1.3.1 (2025-09-09)

### Bug Fixes

- **client**: Correct syntax for aiohttp.ClientSession and logging error message
  ([`62b92d7`](https://github.com/MountainGod2/chaturbate-events/commit/62b92d75cb4de11c9d85c13705a8520929dbb6fb))

- **example**: Add type hints to event handler functions
  ([`0429c45`](https://github.com/MountainGod2/chaturbate-events/commit/0429c451b94747f4bb331092a9651264c2a5d868))

### Documentation

- **README**: Add license section to README.md
  ([`849421c`](https://github.com/MountainGod2/chaturbate-events/commit/849421c3cecac3bdd4112706790cd37b4c43f3df))

### Refactoring

- **dependencies**: Add aioresponses to development dependencies
  ([`de28201`](https://github.com/MountainGod2/chaturbate-events/commit/de28201cd0a0b43186073de0188accb52658fcde))

- **lint**: Expand per-file ignores for test files
  ([`16cca90`](https://github.com/MountainGod2/chaturbate-events/commit/16cca9074daf0416719648f87e95caf8e83ddb90))

- **pyproject**: Clean up lint ignore rules and remove unnecessary mypy override
  ([`ba15efb`](https://github.com/MountainGod2/chaturbate-events/commit/ba15efb85d98eef31a2bd5cb0fb56902d808ecc9))

- **tests**: Add tests for additional scenarios
  ([`b11ff73`](https://github.com/MountainGod2/chaturbate-events/commit/b11ff735d3b4dabc2ac7be429938ce05fc1db1c4))

- **tests**: Correct URL pattern usage in client error handling test
  ([`c1ba9f2`](https://github.com/MountainGod2/chaturbate-events/commit/c1ba9f2e2b4b8e691443ed2f4e11745232866061))

- **tests**: Improve readability by formatting function parameters and return values
  ([`5e44f83`](https://github.com/MountainGod2/chaturbate-events/commit/5e44f83ec33f2c554079f9f3f9a14a5b133365ff))

- **tests**: Remove noqa comments from assertions in test_router_registration
  ([`4e1f4b3`](https://github.com/MountainGod2/chaturbate-events/commit/4e1f4b35613930fc221133645ffbc8303c4a1bb8))

### Testing

- Consolidate and refactor tests to use aioresponses
  ([`16cd577`](https://github.com/MountainGod2/chaturbate-events/commit/16cd5778245d1ee19ee98f51ad9082498054cc5f))

- Reformat parameterized test cases for improved readability
  ([`5c89365`](https://github.com/MountainGod2/chaturbate-events/commit/5c89365b12f4a9d4bf7295166662f113900adb74))

- **conftest**: Update mock_http_get to use aioresponses for HTTP interactions
  ([`f679c76`](https://github.com/MountainGod2/chaturbate-events/commit/f679c76d06b4978c05baddd9fb6417fec290738e))


## v1.3.0 (2025-09-09)

### Features

- **vscode**: Add extensions.json for recommended VS Code extensions
  ([`80ae65c`](https://github.com/MountainGod2/chaturbate-events/commit/80ae65c166bf06cc7de40d89c35cc5bc4bbb84b5))

### Refactoring

- **example**: Simplify example file
  ([`124472b`](https://github.com/MountainGod2/chaturbate-events/commit/124472b14e0bf030d4124446aa08886804b344f7))

- **lint**: Streamline per-file ignores for examples and tests, add Pyright overrides
  ([`3f45237`](https://github.com/MountainGod2/chaturbate-events/commit/3f452370151ca747e593061fba113851b14e4f39))

- **tests**: Enhance type hints and docstrings in test fixtures and functions
  ([`e8fe2f2`](https://github.com/MountainGod2/chaturbate-events/commit/e8fe2f20f29b3e2e7db0f8f01be529381534d619))


## v1.2.0 (2025-09-07)

### Bug Fixes

- **example**: Add credential validation in main function
  ([`a387849`](https://github.com/MountainGod2/chaturbate-events/commit/a38784920d232d5a948206b504695f710b3b1a60))

### Chores

- **deps**: Lock file maintenance
  ([`6b66eeb`](https://github.com/MountainGod2/chaturbate-events/commit/6b66eeb57763ddb9127a7f4776b1bde6b27b3f2f))

- **deps**: Update codecov/codecov-action digest to 5a10915
  ([#9](https://github.com/MountainGod2/chaturbate-events/pull/9),
  [`c03cfda`](https://github.com/MountainGod2/chaturbate-events/commit/c03cfdacce18e8a072ef2aa57299349da7d15295))

- **deps**: Update setup-uv action version
  ([`7606372`](https://github.com/MountainGod2/chaturbate-events/commit/760637203649cbd68fb5b6be2794b691c4dc628e))

- **docs**: Refactor README.md layout
  ([`9d022c3`](https://github.com/MountainGod2/chaturbate-events/commit/9d022c31026f8fd83efc9b3f04c321fbe0d0a16d))

- **workflows**: Remove legacy CI and CD workflow files
  ([`c65dc18`](https://github.com/MountainGod2/chaturbate-events/commit/c65dc18c800e4cadd1815ac76c68a9fe9e520a9c))

### Documentation

- Consolidate and update Copilot instructions
  ([`d585411`](https://github.com/MountainGod2/chaturbate-events/commit/d58541153c680794955c62f52fd0567d15e27b0a))

### Features

- **client**: Enhance error logging and handling for authentication and JSON response
  ([`4725aab`](https://github.com/MountainGod2/chaturbate-events/commit/4725aab592d7bbedd24b8094c511258cd0390ff0))

### Refactoring

- **client**: Improve session initialization for EventClient
  ([`3859630`](https://github.com/MountainGod2/chaturbate-events/commit/38596302110385ff40e55b3b349d740cba4d3cb1))

- **exceptions**: Enhance EventsError class with detailed attributes and representation
  ([`59001ac`](https://github.com/MountainGod2/chaturbate-events/commit/59001acb1c94f02673c40acca56f268229a56ce2))

- **renovate**: Update description to include digest updates for automerge
  ([`ec19380`](https://github.com/MountainGod2/chaturbate-events/commit/ec193802e384f32602bf6783867214c7a42e9d77))

- **router**: Simplify event handler type definitions
  ([`ec5f4ba`](https://github.com/MountainGod2/chaturbate-events/commit/ec5f4baf77038d6683cfa7a3c4cfd0c85ff7b457))

### Testing

- **e2e**: Update end-to-end tests for EventClient functionality and validation
  ([`c3f009f`](https://github.com/MountainGod2/chaturbate-events/commit/c3f009fc8e5779c4767e5ddd1a41658e7cf2d061))


## v1.1.4 (2025-09-04)

### Bug Fixes

- **lint**: Add new ignore patterns for examples and tests
  ([`0efaa4f`](https://github.com/MountainGod2/chaturbate-events/commit/0efaa4fd5db80e758d0f626a725827cf685ed188))

### Chores

- **deps**: Update dependency chaturbate-events to v1.1.3
  ([`d093519`](https://github.com/MountainGod2/chaturbate-events/commit/d093519834eab7afc8c4821eb616119bb81eaee5))

### Refactoring

- **ci**: Improve job naming conventions
  ([`124fd8d`](https://github.com/MountainGod2/chaturbate-events/commit/124fd8d5d36a4f4b08474d8b8132138120cb3461))

- **ci**: Update uv cache references in workflow
  ([`14e1935`](https://github.com/MountainGod2/chaturbate-events/commit/14e19352fb8fae9639aaafa3606f7553d3485157))

- **docs**: Update docstrings across modules
  ([`339299b`](https://github.com/MountainGod2/chaturbate-events/commit/339299bc6fd2edb9c814f139f5ee5195842e6b0e))

- **example**: Remove imports and use standard library tools instead
  ([`7e28d36`](https://github.com/MountainGod2/chaturbate-events/commit/7e28d365afe254941cfadfe24c08200b5a543ef0))


## v1.1.3 (2025-09-04)

### Bug Fixes

- **ci**: Ensure 'build' job is a dependency for 'deploy to PyPI'
  ([`0aa98c5`](https://github.com/MountainGod2/chaturbate-events/commit/0aa98c5eba68bca31763c017f3ba6452a5db53e6))


## v1.1.2 (2025-09-04)

### Bug Fixes

- **ci**: Enhance CI/CD workflow structure and naming conventions
  ([`177c65b`](https://github.com/MountainGod2/chaturbate-events/commit/177c65b35630b3ae377e9eb43dc969e56d8bb2e7))


## v1.1.1 (2025-09-04)

### Bug Fixes

- **ci**: Update artifact download path for PyPI publishing
  ([`330c1ba`](https://github.com/MountainGod2/chaturbate-events/commit/330c1ba9af1f52d29c2cc16ab80b77ba8813dd4d))


## v1.1.0 (2025-09-04)

### Chores

- **ci**: Enhance lint-and-test workflow with permissions and step clarifications
  ([`c32be1f`](https://github.com/MountainGod2/chaturbate-events/commit/c32be1fd7a90e9c37b25098703f2963199b4f868))

- **ci**: Merge CI and CD workflows into a single file
  ([`bb9f5bf`](https://github.com/MountainGod2/chaturbate-events/commit/bb9f5bf9045719890b9573f55ba71b0620311a0f))

- **ci**: Update workflow name
  ([`1bfdfff`](https://github.com/MountainGod2/chaturbate-events/commit/1bfdfff90ad4c58c83b18890130b2ee5bf05b57b))

- **deps**: Lock file maintenance
  ([`bfbbc02`](https://github.com/MountainGod2/chaturbate-events/commit/bfbbc024de4bd4d7a3d696d9ebf69954803b7d7e))

- **deps**: Lock file maintenance
  ([`9d6b7f8`](https://github.com/MountainGod2/chaturbate-events/commit/9d6b7f86495d9938dd0a9e6d8938313bfad23b47))

- **deps**: Pin codecov/codecov-action action to b9fd7d1
  ([#5](https://github.com/MountainGod2/chaturbate-events/pull/5),
  [`db0c723`](https://github.com/MountainGod2/chaturbate-events/commit/db0c7230c423bd56185383d5f434f59fea8e7d1e))

- **deps**: Update astral-sh/setup-uv digest to 557e51d
  ([#7](https://github.com/MountainGod2/chaturbate-events/pull/7),
  [`e02df5d`](https://github.com/MountainGod2/chaturbate-events/commit/e02df5d09416d2afa473f2c0738c35df1bbfd686))

- **deps**: Update codecov/codecov-action action to v5
  ([#6](https://github.com/MountainGod2/chaturbate-events/pull/6),
  [`9b93cf5`](https://github.com/MountainGod2/chaturbate-events/commit/9b93cf5831f36807274b03c1492596467e769d9a))

- **deps**: Update dependency chaturbate-events to v1.0.3
  ([`e3e5047`](https://github.com/MountainGod2/chaturbate-events/commit/e3e50478d2f46e8d0b4c9b7c9a1b60e4b5f4528e))

- **examples**: Update example.py dependencies
  ([`34eee53`](https://github.com/MountainGod2/chaturbate-events/commit/34eee53afed2a59a8fb654df732167f61620174e))

- **pyproject**: Update fancy-pypi-readme substitutions to use correct pattern and replacement
  ([`f4ad9a2`](https://github.com/MountainGod2/chaturbate-events/commit/f4ad9a25aec3f6a44eb92f324a7e68e90ec009a9))

- **renovate**: Add ignorePaths for dependency management
  ([`ae17812`](https://github.com/MountainGod2/chaturbate-events/commit/ae178128a6dae6ea86a86e76c8dc9be2878738e8))

- **renovate**: Enable pep723 manager for dependency management
  ([`06e5a6f`](https://github.com/MountainGod2/chaturbate-events/commit/06e5a6fd919cac02264367ef38ee895ece52ca55))

- **renovate**: Refine configuration and update package rules
  ([`2a7b4cb`](https://github.com/MountainGod2/chaturbate-events/commit/2a7b4cbdb2b01a39f10dcce46a3e685fcfea3019))

- **renovate**: Update managerFilePatterns for pep723 to use regex format
  ([`2fe9c26`](https://github.com/MountainGod2/chaturbate-events/commit/2fe9c26e65cd7cc7d544c6be6976d6fcd3aae79a))

- **renovate**: Update pep723 configuration to use fileMatch instead of managerFilePatterns
  ([`c445e68`](https://github.com/MountainGod2/chaturbate-events/commit/c445e680937fc930e073d2079514a40906759313))

- **renovate**: Update pep723 configuration to use managerFilePatterns for Python files
  ([`b544a90`](https://github.com/MountainGod2/chaturbate-events/commit/b544a909ec6a6a3c2f56b8edec1b19f1bdd78461))

### Features

- **client**: Enhance logging and token masking in EventClient
  ([`ba225ed`](https://github.com/MountainGod2/chaturbate-events/commit/ba225ed41c5fb80617a8371d2d499c8a1a6d8d49))

### Refactoring

- **ci**: Update naming throughout CI/CD workflow
  ([`d56f5af`](https://github.com/MountainGod2/chaturbate-events/commit/d56f5af20bb7c3d501d8f3120703aca9a2b3c695))


## v1.0.3 (2025-08-27)

### Bug Fixes

- **renovate**: Format schedule and managerFilePatterns for consistency
  ([`33568cd`](https://github.com/MountainGod2/chaturbate-events/commit/33568cdb94486ed5347b900dabde08759ab92dea))

### Build System

- **cd**: Ensure build job runs only on successful workflow completion
  ([`68f5f97`](https://github.com/MountainGod2/chaturbate-events/commit/68f5f970512db0aacd1d12bdab91ffe3be8f5604))

### Chores

- **deps**: Lock file maintenance
  ([`d9bff53`](https://github.com/MountainGod2/chaturbate-events/commit/d9bff53b27da3cf468f370274f509aab7586cee9))

- **deps**: Update actions/checkout action to v5
  ([#3](https://github.com/MountainGod2/chaturbate-events/pull/3),
  [`2184e34`](https://github.com/MountainGod2/chaturbate-events/commit/2184e34719474b25f9f8fe2ee298c65de2850910))

- **deps**: Update dependency ruff to v0.12.10
  ([`3cbadc1`](https://github.com/MountainGod2/chaturbate-events/commit/3cbadc1e4684ec659c8ce08ef11824665cb95b28))

- **deps**: Update pre-commit hook astral-sh/ruff-pre-commit to v0.12.10
  ([`e781044`](https://github.com/MountainGod2/chaturbate-events/commit/e78104464cdc3fb8c4a3ebcae2295eb150ac3669))

### Refactoring

- **renovate**: Update merge schedule
  ([`3126de1`](https://github.com/MountainGod2/chaturbate-events/commit/3126de1ec91aa87ae8653ffe0471b5e6139607b2))


## v1.0.2 (2025-08-27)

### Bug Fixes

- **example**: Add mypy override to ignore errors in example module
  ([`c74cc44`](https://github.com/MountainGod2/chaturbate-events/commit/c74cc44b72f47aadce21f479bce4d1bf215da477))


## v1.0.1 (2025-08-27)

### Bug Fixes

- **example**: Replace logging with print statements and add PEP 723 inline deps
  ([`ab90396`](https://github.com/MountainGod2/chaturbate-events/commit/ab90396aa5a3f16b9ded5511f7b4f243fcb25949))

### Chores

- **renovate**: Update minimum release age to 4 days
  ([`2e97d19`](https://github.com/MountainGod2/chaturbate-events/commit/2e97d198aa7f6d8485b7403e571efa22b2823e2c))

### Refactoring

- **pyproject**: Remove unused examples dependency and update lint ignores
  ([`e8e8ae4`](https://github.com/MountainGod2/chaturbate-events/commit/e8e8ae4b60f91a844a7651c07c0e234a68add8d1))

- **router**: Improve type annotations and enhance handler registration logic
  ([`37a61bf`](https://github.com/MountainGod2/chaturbate-events/commit/37a61bfe132b6b2fd2654b3b270408faded31f89))


## v1.0.0 (2025-08-26)

- Initial Release
